## Study site maps 
## By: Mary Clinton
## Date created: March 25, 2023
## Date last modified: March 31, 2023

# Load packages

#library(devtools)
#devtools::install_github("ropenscilabs/rnaturalearthdata")
#install.packages("rnaturalearthhires",
#                 repos = "http://packages.ropensci.org",
#                 type = "source")

library(tidyverse)
library(ggplot2)
library(sf)
library(rnaturalearth)
library(rnaturalearthdata)
library(rnaturalearthhires)
library(rgeos)
library(ggspatial)
library(ggrepel)
library(cowplot)   # Draw additional labels etc. on an existing plot with ggdraw


# Load data for North America 
north_america <- ne_countries(continent = "north america", returnclass = "sf")
north_america_points <- st_centroid(north_america)
north_america_points <- cbind(north_america, st_coordinates(st_centroid(north_america$geometry)))

# Map of North America
NorthAmerica_map <- ggplot(data = north_america) +
  geom_sf(aes(sf_use_s2(FALSE))) +
  labs( x = "Longitude", y = "Latitude") +
  coord_sf(xlim = c(-150.00, -45.00), ylim = c(22.00, 85.00), expand = FALSE) +
  annotation_scale(location = "bl", width_hint = 0.3, text_cex = 1) +
  annotate("text", x = -103, y = 55, label = "Canada", size = 8) +
  annotate('text', x= -103, y = 40, label = "USA", size = 8) +
  theme_bw(base_size = 15) + 
  theme(axis.text = element_blank(),
        axis.title = element_blank(), 
        axis.ticks = element_blank())

# Load data for Canada 
canada <- ne_states(country = "canada", returnclass = "sf")
canada_points <- st_centroid(canada)
canada_points <- cbind(canada, st_coordinates(st_centroid(canada$geometry)))


# Set coordinates and names for study sites 
lat <- c(49.86426, 49.524195, 48.557143)
long <- c(-57.815792, -57.815792, -53.965427)
site_name <- c("St. Paul's", "Neddie's Harbour", "Newman Sound")
site_label <- c("A", "B", "C")

lat_df <- as.data.frame(lat)
long_df <- as.data.frame(long)
site_name_df <- as.data.frame(site_name)
site_label_df <- as.data.frame(site_label)
study_sites <- cbind(lat, long, site_name_df, site_label_df)

# Map of Newfoundland 
NL_map <- ggplot(data = canada) +
  geom_sf(aes(sf_use_s2(FALSE))) +
  labs( x = "Longitude", y = "Latitude") +
  coord_sf(xlim = c(-61.00, -52.00), ylim = c(46.00, 52.00), expand = FALSE) +
  annotation_scale(location = "bl", width_hint = 0.3, text_cex = 1) +
  annotation_north_arrow(location = "bl", which_north = "true",
                         pad_x = unit(0.4, "in"), pad_y = unit(0.3, "in"),
                         style = north_arrow_fancy_orienteering) +
  annotate("text", x = -56, y = 48.5, label = "Newfoundland", size = 6) +
  annotate('text', x= -59.7, y = 51.5, label = 'Mainland\nCanada', size = 4) +
  theme_bw(base_size = 15) +
  geom_point(data = study_sites, aes(x = long, y = lat), colour = "#0392BA",
             size = 4, shape = 25, fill = "#0392BA") +
  geom_label(data = study_sites, aes(x = long, y = lat + 0.16, label = site_name))

# Save maps
tiff("figures/study_sites_map.tiff", width = 8, height = 8, units = "in", res = 300)
NL_map
dev.off()

tiff("figures/NorthAmerica_inset_map.tiff", width = 5, height = 5, units = "in", res = 300)
NorthAmerica_map
dev.off()
