## Taxonomic data prep 
## By: Mary Clinton
## Date created: July 26, 2021
## Date last modified: February 11, 2024


# Load libraries
library(tidyverse) # Data wrangling 

# Load data
# Change depth layer column so that it's not a date
abundances <- read.csv("data/raw/Abundances_AllTaxa_SP_NS.csv", header = TRUE)
abundances$depth_layer <- factor(abundances$depth_layer, levels = c("0-2", "05-Feb", "10-May"),
                                 labels = c("0-2", "2-5", "5-10"))

NH_abundances <- read.csv("data/raw/Abundances_AllTaxa_NH.csv", header = TRUE)

# All taxa ----

#Remove unneeded columns 
abundances <- abundances %>% 
  dplyr::select(-Fragments, -Unknown.sp.1, -Unknown.sp.2...Pygospio.elegans,
                -Unknown) %>% 
  mutate(sample_number = as.factor(sample_number)) %>% 
  # Limecola is not longer an accepted taxonomic grouping. Update name to Macoma
  rename(Macoma.sp = Limecola.sp,
         Macoma.balthica = Limecola.balthica)

# Repeat for Neddie's Harbour (NH) data set - which was received later than the other sites
NH_abundances_clean <- NH_abundances %>% 
  # Remove unneeded columns
  dplyr::select(-notes) %>% 
  # Add columns for core ID and depth layer (labeled correctly)
  mutate(core_id = str_remove(sample_id, "_[^_]+$"),
         depth_layer = str_extract(sample_id, "_[^_]+$") %>% str_remove(., "_")) %>% 
  mutate(depth_layer = case_when(
    depth_layer == "top" ~ "0-2", 
    depth_layer == "mid" ~ "2-5",
    depth_layer == "bottom" ~ "5-10"
  )) %>% 
  # Fix spelling of Eteone longa complex to match data frame for SP & NS
  mutate(taxon = replace(taxon, taxon == "Eteone longa complex", "Eteone longacomplex")) %>% 
  dplyr::select(-sample_id) %>% 
  filter(abundance != "n/a") %>%
  mutate(abundance = as.numeric(abundance)) %>% 
  # Add . between genus & species names, to match data frame for SP & NS
  mutate(taxon = str_replace_all(taxon, " ", ".") %>% 
           str_remove_all(., "[.]$"))

# Convert to wide format so that it matches abundances data frame for other two sites
NH_abundances_wide <- NH_abundances_clean %>% 
  group_by(sample_number, core_id, depth_layer, taxon) %>% 
  summarise(abundance = sum(abundance)) %>% 
  pivot_wider(id_cols = c(sample_number, core_id, depth_layer), 
              names_from = taxon, 
              values_from = abundance) %>% 
  mutate(sample_number = as.factor(sample_number)) %>% 
  mutate(across(where(is.numeric), ~if_else(is.na(.), 0, .)))

NH_abundances_wide <- as.data.frame(NH_abundances_wide)

# Now convert each data frame to long format so they can be joined together
abund_long <- gather(abundances, key = "taxon", value = "abundance", Alitta.virens:Tellinidae.indet)
NH_abund_long <- gather(NH_abundances_wide, key = "taxon", value = "abundance", Bivalvia.indet:Pectinariidae.indet) %>% 
  mutate(depth_layer = as.factor(depth_layer))

# Join them together!
all_abund_long <- rbind(abund_long, NH_abund_long)

# Arrange data by core rather than by depth layer
by_core <- all_abund_long %>% 
  dplyr::filter(!is.na(sample_number)) %>% 
  group_by(core_id, taxon) %>% #makes it by core rather than by depth layer
  summarize(abundance = sum(abundance, na.rm = TRUE))

# Convert both data frames (by core & by depth layer) back to long format 
by_core_matrix <- spread(by_core, key = "taxon", value = "abundance")
by_depth_layer_matrix <- spread(all_abund_long, key = "taxon", value = "abundance")

# Finally, convert all NAs in data frame to zeroes :)
by_core_matrix <- by_core_matrix %>% 
  mutate(across(where(is.numeric), ~if_else(is.na(.), 0, .)))

by_depth_layer_matrix <- by_depth_layer_matrix %>% 
  mutate(across(where(is.numeric), ~if_else(is.na(.), 0, .)))

# Remove any taxa that are not macrofauna from the analysis 
by_core_macrofauna <- by_core_matrix %>% 
  # Remove copepods
  select(-Acartia.sp, -Copepoda.indet, -Harpacticoida.indet, -Metridia.sp,
         # Other plankton
         -Mysida.indet,
         # And other meiofauna
         -Foraminifera.indet, -Nematoda.indet, -Ostracoda.indet, -Platyhelminthes.indet) %>% 
  # Correct spelling for Rissooidea indet. superfamily 
  rename(Rissooidea.indet = Rissooidae.indet) %>% 
  # And rename Eteone lactea to Hypereteone lactea (was re-classified) 
  rename(Hypereteone.lactea = Eteone.lactea)

by_depth_layer_macrofauna <- by_depth_layer_matrix %>% 
  # Remove copepods
  select(-Acartia.sp, -Copepoda.indet, -Harpacticoida.indet, -Metridia.sp,
         # Other plankton
         -Mysida.indet,
         # And other meiofauna
         -Foraminifera.indet, -Nematoda.indet, -Ostracoda.indet, -Platyhelminthes.indet) %>% 
  # And correct spelling for Rissooidea indet. superfamily 
  rename(Rissooidea.indet = Rissooidae.indet) %>% 
  # And rename Eteone lactea to Hypereteone lactea (was re-classified) 
  rename(Hypereteone.lactea = Eteone.lactea)


# Save data frames
write.csv(by_core_macrofauna, "data/processed/abundances_by_core.csv")
write.csv(by_depth_layer_macrofauna, "data/processed/abundances_by_depthlayer.csv")


# Condensed taxa for calculation of diversity indices ----

# In some cases, taxonomic resolution differed between sites for a given taxonomic unit
# This introduces biases when calculating diversity indices. To account for this, certain taxonomic groups
# were combined and/or removed when calculating diversity indices. For more detail, 
# please see Methods section of Ch 2 - Community Analysis 

by_core_for_indices <- by_core_macrofauna %>% 
  # Remove high abundance, high-level grouping representing many mixed taxa
  select(-Bivalvia.indet, -Gastropoda.indet) %>% 
  # Remove high-level individuals OR high-level small groups of juveniles 
  select(-Amphipoda.indet, -Capitellidae.indet, -Corophiidae.indet, -Crustacea.indet, -Enteropneusta.indet, 
         -Gammaroidea.indet, -Macominae.indet, -Nereididae.indet, -Spionidae.indet) %>% 
  # Group taxa to a higher taxonomic level if resolution differs between sites:
  # Add Macoma balthica to Macoma sp. column
  mutate(Macoma.sp = rowSums(across(c(Macoma.sp, Macoma.balthica)))) %>% 
  select(-Macoma.balthica) %>% 
  # Add Heteromastus filiformis to Heteromastus sp. column 
  mutate(Heteromastus.sp = rowSums(across(c(Heteromastus.filiformis, Heteromastus.sp)))) %>% 
  select(-Heteromastus.filiformis) %>% 
  # Add Mya arenaria to Mya sp. column 
  mutate(Mya.sp = rowSums(across(c(Mya.arenaria, Mya.sp)))) %>% 
  select(-Mya.arenaria) %>% 
  # Add Pectinaria gouldii to Pectinariidae indet. column 
  mutate(Pectinariidae.indet = rowSums(across(c(Pectinaria.gouldii, Pectinariidae.indet)))) %>% 
  select(-Pectinaria.gouldii) %>% 
  # Add Spio setosa to Spio sp. column 
  mutate(Spio.sp = rowSums(across(c(Spio.setosa, Spio.sp)))) %>% 
  select(-Spio.setosa) %>% 
  # Add Monocorophium acherusicum and Monocorophium insidiosum to Monocorophium sp. column
  mutate(Monocorophium.sp = rowSums(across(c(Monocorophium.acherusicum, Monocorophium.insidiosum, Monocorophium.sp)))) %>% 
  select(-Monocorophium.acherusicum, -Monocorophium.insidiosum) %>% 
  # Add Tellina sp. to Tellinidae indet. column 
  mutate(Tellinidae.indet = rowSums(across(c(Tellina.sp, Tellinidae.indet)))) %>% 
  select(-Tellina.sp) %>% 
  # Add Lineidae indet. to Nemertea indet. column
  mutate(Nemertea.indet = rowSums(across(c(Lineidae.indet, Nemertea.indet)))) %>% 
  select(-Lineidae.indet) %>% 
  # Add Paranais litoralis, Paranais sp. and Amphichaeta sp. to Naididae indet. column 
  mutate(Naididae.indet = rowSums(across(c(Paranais.litoralis, Paranais.sp, Amphichaeta.sp, Naididae.indet)))) %>% 
  select(-Paranais.litoralis, -Paranais.sp, -Amphichaeta.sp)


by_depth_layer_for_indices <- by_depth_layer_macrofauna %>% 
  # Remove high abundance, high-level grouping representing many mixed taxa
  select(-Bivalvia.indet, -Gastropoda.indet) %>% 
  # Remove high-level individuals OR high-level small groups of juveniles 
  select(-Amphipoda.indet, -Capitellidae.indet, -Corophiidae.indet, -Crustacea.indet, -Enteropneusta.indet, 
         -Gammaroidea.indet, -Macominae.indet, -Nereididae.indet, -Spionidae.indet) %>% 
  # Group taxa to a higher taxonomic level if resolution differs between sites:
  # Add Macoma balthica to Macoma sp. column
  mutate(Macoma.sp = rowSums(across(c(Macoma.sp, Macoma.balthica)))) %>% 
  select(-Macoma.balthica) %>% 
  # Add Heteromastus filiformis to Heteromastus sp. column 
  mutate(Heteromastus.sp = rowSums(across(c(Heteromastus.filiformis, Heteromastus.sp)))) %>% 
  select(-Heteromastus.filiformis) %>% 
  # Add Mya arenaria to Mya sp. column 
  mutate(Mya.sp = rowSums(across(c(Mya.arenaria, Mya.sp)))) %>% 
  select(-Mya.arenaria) %>% 
  # Add Pectinaria gouldii to Pectinariidae indet. column 
  mutate(Pectinariidae.indet = rowSums(across(c(Pectinaria.gouldii, Pectinariidae.indet)))) %>% 
  select(-Pectinaria.gouldii) %>% 
  # Add Spio setosa to Spio sp. column 
  mutate(Spio.sp = rowSums(across(c(Spio.setosa, Spio.sp)))) %>% 
  select(-Spio.setosa) %>% 
  # Add Monocorophium acherusicum and Monocorophium insidiosum to Monocorophium sp. column
  mutate(Monocorophium.sp = rowSums(across(c(Monocorophium.acherusicum, Monocorophium.insidiosum, Monocorophium.sp)))) %>% 
  select(-Monocorophium.acherusicum, -Monocorophium.insidiosum) %>% 
  # Add Tellina sp. to Tellinidae indet. column 
  mutate(Tellinidae.indet = rowSums(across(c(Tellina.sp, Tellinidae.indet)))) %>% 
  select(-Tellina.sp) %>% 
  # Add Lineidae indet. to Nemertea indet. column
  mutate(Nemertea.indet = rowSums(across(c(Lineidae.indet, Nemertea.indet)))) %>% 
  select(-Lineidae.indet) %>% 
  # Add Paranais litoralis, Paranais sp. and Amphichaeta sp. to Naididae indet. column 
  mutate(Naididae.indet = rowSums(across(c(Paranais.litoralis, Paranais.sp, Amphichaeta.sp, Naididae.indet)))) %>% 
  select(-Paranais.litoralis, -Paranais.sp, -Amphichaeta.sp)

# Save data frame
write.csv(by_core_for_indices, "data/processed/abundances_by_core_for_calculation_of_indices.csv")
write.csv(by_depth_layer_for_indices, "data/processed/abundances_by_depth_layer_for_calculation_of_indices.csv")
