## Taxonomic diversity analyses 
## By: Mary Clinton
## Date created: July 28, 2021
## Date last modified: February 2, 2024

# Load libraries
library(tidyverse)    # Data wrangling/cleaning
library(vegan)        # Species accumulation curves, nMDS plots, PERMANOVA, ANOSIM & SIMPER
library(glmmTMB)      # Beta regression 
library(lme4)         # Mixed effects models (normal and non-normal)
library(DHARMa)       # Model diagnostics & model fitting
library(effects)      # Display model results
library(flextable)    # Create tables that can be copied directly to word documents 
library(RColorBrewer) # Colours for plots
library(ggrepel)      # Shifting text on nMDS plots to avoid overlap
library(wesanderson)  # Colour palettes for plots
library(gamlss)       # Log normal distribution (Simpson's index)
library(rstatix)      # Kruskal-Wallis test
library(worms)        # Taxonomic information from the World Register of Marine Species (WoRMS)
library(conflicted)   # Allows you to specify which package gets precedence in the case of conflicts (e.g. WoRMS vs. dplyr)

# Load functions 
source("code/src/boot-resample.R")             # Calculates diversity indices from a random sub-sample of cores 
source("code/src/pub-ready-effects-plots.R")   # Creates publication-ready plots from output of effects package

# Load data
by_core <- read.csv("data/processed/abundances_by_core.csv", header = TRUE)
by_depth_layer <- read.csv("data/processed/abundances_by_depthlayer.csv", header = TRUE)
by_core_for_indices <- read.csv("data/processed/abundances_by_core_for_calculation_of_indices.csv", header = TRUE)
by_depth_layer_for_indices <- read.csv("data/processed/abundances_by_depth_layer_for_calculation_of_indices.csv", header = TRUE)

# Set theme for plots 
theme_MEC <- function () { 
  theme_bw(base_size = 12) + 
    theme(panel.grid.major = element_blank(), panel.grid.minor = element_blank(), 
          axis.line = element_line(colour = "black"), 
          axis.text = element_text(size = 16, face = "plain"), 
          axis.title = element_text(size = 18, face = "plain"),
          legend.text = element_text(size = 16, face = "plain"), 
          legend.title = element_text(size = 18, face = "bold"))
} 
theme_set(theme_MEC())

# Prep data ----
# Remove column X from each depth layer data frames
by_depth_layer <- by_depth_layer %>% 
  dplyr::select(-X)

by_depth_layer_for_indices <- by_depth_layer_for_indices %>% 
  dplyr::select(-X)

# Create a matrix with abundances by core that includes columns for site
by_core_with_site <- by_core %>% 
  dplyr::mutate(site = str_sub(core_id, 1, 2))

by_core_with_site_for_indices <- by_core_for_indices %>% 
  dplyr::mutate(site = str_sub(core_id, 1, 2))

# Make core_id the row name for original by_core (or by_core_for_indices) data frame
rownames(by_core) <- by_core$core_id
by_core <- by_core %>% 
  dplyr::select(-core_id)

rownames(by_core_for_indices) <- by_core_for_indices$core_id
by_core_for_indices <- by_core_for_indices %>% 
  dplyr::select(-core_id)

# Species accumulation curves for each site ----
# Did we sample the majority of species present in the community?

# Subset out each site, and get data needed using specaccum (from vegan)
AC_by_core <- by_core_for_indices[1:33, ]
AC_spaccum <- specaccum(AC_by_core, method = "exact", conditioned = TRUE)

NH_by_core <- by_core_for_indices[34:57, ]
NH_spaccum <- specaccum(NH_by_core, method = "exact", conditioned = TRUE)

SP_by_core <- by_core_for_indices[58:90, ]
SP_spaccum <- specaccum(SP_by_core, method = "exact", conditioned = TRUE)

# Turn spaccum data into data frames for use in ggplot
SP_spaccum_df <- data.frame(cores = SP_spaccum$sites,
                         richness = SP_spaccum$richness,
                         sd = SP_spaccum$sd,
                         site = "SP")

AC_spaccum_df <- data.frame(cores = AC_spaccum$sites,
                            richness = AC_spaccum$richness,
                            sd = AC_spaccum$sd,
                            site = "AC")

NH_spaccum_df <- data.frame(cores = NH_spaccum$sites,
                            richness = NH_spaccum$richness,
                            sd = NH_spaccum$sd,
                            site = "NH")

# Join into one data frame
spaccum_df <- rbind(AC_spaccum_df, NH_spaccum_df, SP_spaccum_df)
spaccum_df <- spaccum_df %>% 
  mutate(site = case_when(
    site == "SP" ~ "St. Paul's",
    site == "NH" ~ "Neddie's Harbour",
    site == "AC" ~ "Newman Sound"
  ))

# Plot species accumulation curves for each site on the same plot
# Solid lines indicate the mean value, shaded ribbons represent +/- 1 standard deviation
tiff("figures/species_accumulation_curves.tiff", width = 12, height = 9, units = "in", res = 300)
ggplot(data = spaccum_df, aes(x = cores, y = richness)) + 
  scale_fill_brewer(type = "qual", palette = "Pastel2") +
  scale_colour_brewer(type = "qual", palette = "Dark2") +
  geom_line(aes(colour = site), size = 1) +
  geom_ribbon(aes(fill = site, ymin = richness - sd, ymax = richness + sd), alpha = 0.3) + 
  theme_bw(base_size = 20) +                                                 
  theme(panel.grid.major = element_blank(), 
        panel.grid.minor = element_blank(), #remove lines in background
        axis.title.y = element_text(vjust = 3), #increase distance between axes and axis labels
        axis.title.x = element_text(vjust = -1),
        legend.position = c(0.85, 0.2)) + 
  labs(x = "Number of cores collected", y = "Number of taxa observed", colour = "Site", fill = "Site") 
dev.off()

# Overview: Abundances and number of taxa ----

# Total # of individuals per site:

# There are a total of 16,357 organisms in the un-binned data frame
by_core %>% 
  dplyr::mutate(site = str_sub(rownames(by_core_for_indices), 1, 2)) %>% 
  gather(key = "taxon", value = "abundance", Alitta.sp:Tellinidae.indet) %>% 
  group_by(site) %>% 
  dplyr::summarize(total_number = sum(abundance))

# Total number of raw taxa per site:
# NS: 43
# NH: 36
# SP: 42 
by_core %>% 
  dplyr::mutate(site = str_sub(rownames(by_core_for_indices), 1, 2)) %>% 
  dplyr::select(-X) %>% 
  dplyr::group_by(site) %>% 
  dplyr::summarise(across(Alitta.sp:Tellinidae.indet, ~sum(., na.rm = TRUE))) %>% 
  dplyr::mutate(across(where(is.numeric), ~ifelse(. == 0, 0, 1))) %>% 
  dplyr::select(where(is.numeric)) %>% 
  rowSums()

# Get taxonomic information (Phylum --> species) for each taxon directly from WoRMS
worms_taxon_info_unbinned <- by_core %>% 
  dplyr::rename(Eteone.longa = Eteone.longacomplex) %>% 
  dplyr::select(-X) %>% 
  colnames() %>% 
  # Remove all indet. and sp. because WoRMS won't recognize these
  str_remove(., ".indet") %>% 
  str_remove_all(., "[.]sp") %>% 
  # And replace period with a space between genus and species names
  str_replace(., "[.]", " ") %>% 
  worms::wormsbymatchnames() %>% 
  dplyr::select(scientificname, valid_AphiaID, phylum, class, order, family)

write.csv(worms_taxon_info_unbinned, "data/processed/WoRMS_taxon_information_unbinned.csv" )


# There are a total of 10,048 organisms in the binned data frame
by_core_for_indices %>% 
  dplyr::mutate(site = str_sub(rownames(by_core_for_indices), 1, 2)) %>% 
  gather(key = "taxon", value = "abundance", Alitta.sp:Tellinidae.indet) %>% 
  dplyr::group_by(site) %>% 
  dplyr::summarize(total_number = sum(abundance))

# Total number of binned taxa per site = 32 at NS, 25 at NH, 29 at SP
by_core_for_indices %>% 
  mutate(site = str_sub(rownames(by_core_for_indices), 1, 2)) %>% 
  select(-X) %>% 
  group_by(site) %>% 
  dplyr::summarise(across(Alitta.sp:Tellinidae.indet, ~sum(., na.rm = TRUE))) %>% 
  dplyr::mutate(across(where(is.numeric), ~ifelse(. == 0, 0, 1))) %>% 
  select(where(is.numeric)) %>% 
  rowSums()

# Get taxonomic information (Phylum --> species) for each taxon directly from WoRMS
worms_taxon_info_binned <- by_core_for_indices %>% 
  dplyr::rename(Eteone.longa = Eteone.longacomplex) %>% 
  select(-X) %>% 
  colnames() %>% 
  # Remove all indet. and sp. because WoRMS won't recognize these
  str_remove(., ".indet") %>% 
  str_remove_all(., "[.]sp") %>% 
  # And replace period with a space between genus and species names
  str_replace(., "[.]", " ") %>% 
  worms::wormsbymatchnames() %>% 
  select(scientificname, valid_AphiaID, phylum, class, order, family)

# These binned taxa represent...4 phyla, 17 orders, 30 families 
unique(worms_taxon_info_binned$phylum)
unique(worms_taxon_info_binned$order)
unique(worms_taxon_info_binned$family)


# Taxa abundances at each site
SP_site_level_abundances <- by_core_for_indices %>% 
  dplyr::mutate(site = str_sub(rownames(by_core_for_indices), 1, 2)) %>% 
  dplyr::filter(site == "SP") %>% 
  dplyr::select(-site, X) %>% 
  dplyr::summarise(across(Alitta.sp:Tellinidae.indet, ~sum(., na.rm = TRUE))) %>% 
  gather(key = "taxon", value = "abundance", Alitta.sp:Tellinidae.indet)

AC_site_level_abundances <- by_core_for_indices %>% 
  dplyr::mutate(site = str_sub(rownames(by_core_for_indices), 1, 2)) %>% 
  dplyr::filter(site == "AC") %>% 
  dplyr::select(-site, X) %>% 
  dplyr::summarise(across(Alitta.sp:Tellinidae.indet, ~sum(., na.rm = TRUE))) %>% 
  gather(key = "taxon", value = "abundance", Alitta.sp:Tellinidae.indet)

NH_site_level_abundances <- by_core_for_indices %>% 
  dplyr::mutate(site = str_sub(rownames(by_core_for_indices), 1, 2)) %>% 
  dplyr::filter(site == "NH") %>% 
  dplyr::select(-site, X) %>% 
  dplyr::summarise(across(Alitta.sp:Tellinidae.indet, ~sum(., na.rm = TRUE))) %>% 
  gather(key = "taxon", value = "abundance", Alitta.sp:Tellinidae.indet)


# Density (individuals per m^2) ----

densities <- by_core %>% 
  dplyr::mutate(across(.cols = where(is.numeric), ~./((0.067^2)*pi))) 

densities_summary <- densities %>% 
  dplyr::mutate(site = str_sub(rownames(densities), 1, 2)) %>% 
  group_by(site) %>% 
  dplyr::summarise(mean = across(Alitta.sp:Tellinidae.indet, ~mean(., na.rm = TRUE)),
            sd = across(Alitta.sp:Tellinidae.indet, ~sd(., na.rm = TRUE)))

densities_summary <- as.data.frame(densities_summary)
write.csv(densities_summary, "data/processed/mean_macrofaunal_densities_by_site.csv" )


# Repeat for binned data 
binned_densities <- by_core_for_indices %>% 
  dplyr::mutate(across(.cols = where(is.numeric), ~./((0.067^2)*pi))) 

binned_densities_summary <- binned_densities %>% 
  dplyr::mutate(site = str_sub(rownames(densities), 1, 2)) %>% 
  group_by(site) %>% 
  dplyr::summarise(mean = across(Alitta.sp:Tellinidae.indet, ~mean(., na.rm = TRUE)),
                   sd = across(Alitta.sp:Tellinidae.indet, ~sd(., na.rm = TRUE)))

binned_densities_summary <- as.data.frame(binned_densities_summary)
write.csv(binned_densities_summary, "data/processed/mean_binned_macrofaunal_densities_by_site.csv" )


# Calculate taxonomic Diversity Indices (per core) -----

shannon <- diversity(by_core_for_indices, "shannon")
simpson <- diversity(by_core_for_indices, "simpson")
richness <- specnumber(by_core_for_indices)
pielous_evenness <- shannon / richness


# Create data frame containing all calculated taxonomic diversity indices for each core
site <- by_core_with_site_for_indices$site
core_id <- by_core_with_site_for_indices$core_id
TD_indices <- data.frame(site, core_id, shannon, simpson, richness, pielous_evenness)

TD_indices <- TD_indices %>% 
  dplyr::mutate(site = case_when(
    site == "SP" ~ "St. Paul's",
    site == "NH" ~ "Neddie's Harbour",
    site == "AC" ~ "Newman Sound"
  ))

write.csv(TD_indices, "data/processed/TD_indices.csv")

# Summary table for TD indices at each site (raw values)
TD_indices %>% 
  dplyr::select(site, shannon, simpson, richness, pielous_evenness) %>% 
  group_by(site) %>% 
  dplyr::summarise(mean = across(shannon:pielous_evenness, ~mean(., na.rm = TRUE)),
            sd = across(shannon:pielous_evenness, ~sd(., na.rm = TRUE)))


# Box plots comparing each index b/t sites
shannon_plot <- ggplot(TD_indices, aes(x = site, y = shannon)) + 
  geom_boxplot() +
  labs(x = "", y = "Shannon-Wiener (H')") +
  theme_bw() + 
  theme(panel.grid.major = element_blank(), 
        panel.grid.minor = element_blank())

simpson_plot <- ggplot(TD_indices, aes(x = site, y = simpson)) + 
  geom_boxplot() +
  labs(x = "", y = "Simpson's (d)") +
  theme_bw() + 
  theme(panel.grid.major = element_blank(), 
        panel.grid.minor = element_blank())

richness_plot <- ggplot(TD_indices, aes(x = site, y = richness)) + 
  geom_boxplot() +
  labs(x = "", y = "Taxonomic richness (S)") +
  theme_bw() + 
  theme(panel.grid.major = element_blank(), 
        panel.grid.minor = element_blank())

pielous_plot <- ggplot(TD_indices, aes(x = site, y = pielous_evenness)) +
  geom_boxplot() +
  labs(x = "", y = "Pielou's Evenness (J')") +
  theme_bw() + 
  theme(panel.grid.major = element_blank(), 
        panel.grid.minor = element_blank())

# Plot & save plots contrasting 4 taxonomic diversity indices (didn't include inverse Simpson's) b/t the 2 sites
tiff("figures/TD_indices_boxplots.tiff", width = 12, height = 9, units = "in", res = 300)
cowplot::plot_grid(shannon_plot, simpson_plot, richness_plot, pielous_plot,
                   labels = LETTERS[1:4],
                   align = "v", axis = "l")
dev.off()


# Test for differences between sites (GLM) ----

## Shannon-Weiner (H') ----

# First run the model
shannon_lm <- lm(shannon ~ site, data = TD_indices)

# Check model fit using DHARMa: 
# STEP 1) Calculate scaled residuals
shannon_lm_simulationOutput <- simulateResiduals(fittedModel = shannon_lm, plot = F)

# STEP 2) Plot the scaled residuals 
plot(shannon_lm_simulationOutput)  
plotResiduals(shannon_lm_simulationOutput, form = TD_indices$site) 

# STEP 3) Goodness of fit tests
testDispersion(shannon_lm_simulationOutput) 
testUniformity(shannon_lm_simulationOutput) 

# Model summary
summary(shannon_lm) 
anova(shannon_lm)

# Make an effects plot 
shannon_by_site_effects_plot <- pub_effects_plot(shannon_lm, TD_indices, "shannon", "Shannon (H')")

# Save plot
ggsave(filename = "figures/mean_shannon_by_site_effects_plot.png", plot = shannon_by_site_effects_plot, 
       width = 10, height = 10, units = "in", dpi = 300)


# Model summary table
broom::tidy(shannon_lm) %>% 
  # Specify the number of decimal places you'd like in the table
  dplyr::mutate(across(where(is.numeric), ~round(., 3))) %>% 
  # For very small p-value, replace with "<0.001" for ease of reading
  dplyr::mutate(p.value = if_else(p.value == 0.000, "< 0.001", as.character(p.value))) %>% 
  # Rename column headers for table to make them more legible
  dplyr::rename("Term" = "term",
         "Estimate" = "estimate",
         "SE" = "std.error",
         "t-statistic" = "statistic",
         "p-value" = "p.value") %>% 
  # Create table 
  flextable()


## Richness (S) ----

# Start with a linear model with normal distribution 
richness_lm <- lm(richness ~ site, data = TD_indices)

# Check model fit using DHARMa: 
# STEP 1) Calculate scaled residuals
richness_lm_simulationOutput <- simulateResiduals(fittedModel = richness_lm, plot = F)

# STEP 2) Plot the scaled residuals 
plot(richness_lm_simulationOutput) 
plotResiduals(richness_lm_simulationOutput, form = TD_indices$site) 

# STEP 3) Goodness of fit tests
testDispersion(richness_lm_simulationOutput) 
testUniformity(richness_lm_simulationOutput) 
testOutliers(richness_lm_simulationOutput)   

# Model summary 
summary(richness_lm)
anova(richness_lm)

# Use the effects package to get parameter estimates (same values as 1st column in summary(shannon_lm))
effCoef(richness_lm)

# Plot effect of site on Pielou's Evenness index
effect(term = "site", mod = richness_lm)

# Plot it!
richness_by_site_effects_plot <- pub_effects_plot(richness_lm, TD_indices, "richness", "Richness (S)")

# Save plot
ggsave(filename = "figures/mean_richness_by_site_effects_plot.png", plot = richness_by_site_effects_plot, 
       width = 10, height = 10, units = "in", dpi = 300)



## Simpson's Diversity (D) ----

# This index is bounded between 0 and 1 so start with beta regression
simpson_beta <- glmmTMB(simpson ~ site, data = TD_indices, family = beta_family(link = "logit"))

# Check model fit using DHARMa
# First, calculate the scale residuals
simpson_beta_simulationOutput <- simulateResiduals(fittedModel = simpson_beta, plot = F)

# Then plot them: 
plot(simpson_beta_simulationOutput) #
plotResiduals(simpson_beta_simulationOutput, form = TD_indices$site) 

# Test for dispersion
testDispersion(simpson_beta_simulationOutput) 
testUniformity(simpson_beta_simulationOutput) 

# Beta regression is the best fit for these data but there are some borderline violations of the model 
# so we conducted a non-parametric test as well to confirm that the biological inferences we're making are robust
kruskal_test(simpson ~ site, data = TD_indices)  # p = 0.00000016

# Plot it
simpson_by_site_effects_plot <- pub_effects_plot(simpson_beta, TD_indices, "simpson", "Simpson's", is_beta = TRUE)

# Save plot
ggsave(filename = "figures/mean_simpson_by_site_effects_plot.png", plot = simpson_by_site_effects_plot, 
       width = 10, height = 10, units = "in", dpi = 300)


## Pielou's Evenness (J') ----

# This index is bounded between 0 and 1, so start with beta regression
pielous_beta <- glmmTMB(pielous_evenness ~ site, data = TD_indices, family = beta_family(link = "logit"))

# STEP 1) Calculate scaled residuals
pielous_beta_simulationOutput <- simulateResiduals(fittedModel = pielous_beta, plot = F)

# STEP 2) Plot the scaled residuals 
plot(pielous_beta_simulationOutput)
plotResiduals(pielous_beta_simulationOutput, form = TD_indices$site) 

# STEP 3) Goodness of fit tests
testDispersion(pielous_beta_simulationOutput) 
testUniformity(pielous_beta_simulationOutput) 
testOutliers(pielous_beta_simulationOutput)   

# Model summary 
summary(pielous_beta)

# Plot it!
pielous_by_site_effects_plot <- pub_effects_plot(pielous_beta, TD_indices, "pielous_evenness", "Pielou's Evenness (J')", is_beta = TRUE)

# Save plot
ggsave(filename = "figures/mean_pielous_by_site_effects_plot.png", plot = pielous_by_site_effects_plot, 
       width = 10, height = 10, units = "in", dpi = 300)


## Summary table: All models of TD ~ site ----


# Make a list of all the fitted model objects (tibbles) you want to group into one table 
purrr::map(list(shannon_lm, simpson_beta, richness_lm, pielous_beta), broom::tidy) %>% 
  # Name each table within the large table 
  set_names(., nm = c("Shannon", "Simpson", "Richness", "Pielou's Evenness")) %>% 
  # Combine together  
  bind_rows(.id = "Index") %>% 
  # Specify the number of decimal places you want to display 
  dplyr::mutate(across(where(is.numeric), ~round(., 3))) %>% 
  # For ease of reading, rename terms, column headers and make very small p-value read "<0.001"
  dplyr::mutate(p.value = if_else(p.value == 0.000, "< 0.001", as.character(p.value))) %>% 
  dplyr::mutate(term = case_when(
    term == "siteNewman Sound" ~ "Newman Sound", 
    term == "siteSt. Paul's" ~ "St. Paul's",
    term == "(Intercept)" ~ "Intercept"
  )) %>% 
  dplyr::select(-effect, -component) %>% 
  dplyr::rename("Term" = "term",
         "Estimate" = "estimate",
         "SE" = "std.error",
         "t-statistic" = "statistic",
         "p-value" = "p.value") %>% 
  # Group so that the Index column doesn't repeat the index name in every row
  as_grouped_data(groups = "Index") %>% 
  # Make the table
  flextable()


# nMDS plots (Unbinned data) ---- 
all.nmds <- metaMDS(by_core, try = 20, trymax = 500)
data.scores <- as.data.frame(scores(all.nmds)) 

# Add core names, incubation_ID (ie. collection date), and site to data.scores
# This will allow for labeling/colouring on the plot
data.scores$core <- rownames(data.scores)

data.scores$incubation_ID <- sub("_.*","",data.scores$core)

collection_site <- c(rep("AC", 33), rep("NH", 24), rep("SP", 33))
data.scores$site <- collection_site

# Create data frame of species coordinates so they can also be plotted 
nmds.species <- as.data.frame(all.nmds$species)

# Calculate stress value 
stress <- all.nmds$stress

# nMDS plot of cores from both sites. Colours represent collection/incubation dates. Shape = site.

# Change site names so they are fully spelled out in plot legends
data.scores <- data.scores %>% 
  dplyr::mutate(site = case_when(
    site == "SP" ~ "St. Paul's",
    site == "NH" ~ "Neddie's Harbour",
    site == "AC" ~ "Newman Sound"
  ))

# nMDS plot that includes points and labels for each individual taxon
# Species shared between sites sit between the clouds of core points
ggplot(data = data.scores) + 
  stat_ellipse(aes(x = NMDS1, y = NMDS2, colour = site),level = 0.50) +
  geom_point(aes(x = NMDS1, y = NMDS2, shape = site, colour = site), size = 4) +
  # Add stress value to plot 
  geom_text(x = 0.85, y = 1.8, label = "stress = 0.166", color = "black", cex = 5) +
  geom_text(x = 0.85, y = 1.7, label = "R = 0.9117, p = 0.0001", color = "black", cex = 5) +
  geom_point(data = nmds.species, aes(x = MDS1, y = MDS2)) + 
  geom_text_repel(data = nmds.species, aes(x = MDS1, y = MDS2), label = rownames(nmds.species), size = 3, max.overlaps = 15) +
  theme_bw(base_size = 20) + 
  guides(colour = "none") +
  theme(panel.grid.major = element_blank(), 
        panel.grid.minor = element_blank(),
        axis.title.y = element_text(vjust = 3),
        axis.title.x = element_text(vjust = -1),
        legend.position = c(0.85, 0.1)) + 
  labs(x = "nMDS1", y = "nMDS2", shape = "Site", colour = "Site")


### PERMANOVA ----
# Permutational Analysis of Variance (using the vegan package)
# Tests for differences between the centroids of different groups 
abundances <- by_core

# Distance matrix
abundances_dist <- vegdist(abundances)

# PERMANOVA indicates different centroids between sites 
abundances_div <- adonis2(abundances_dist ~ site, data = by_core, permutations = 9999, method = "bray")

# Model summary table for Supplementary material 
broom::tidy(abundances_div) %>% 
  # Specify the number of decimal places you'd like in the table
  dplyr::mutate(across(where(is.numeric), ~round(., 3))) %>% 
  # For very small p-value, replace with "<0.001" for ease of reading
  dplyr::mutate(p.value = if_else(p.value == 0.000, "< 0.001", as.character(p.value))) %>% 
  # Rename column headers for table to make them more legible
  dplyr::rename("Term" = "term",
                "pseudo-F" = "statistic",
                "p-value" = "p.value") %>% 
  # Create table 
  flextable()


### ANOSIM ----
# Analysis of Similarities (using the vegan package)
# This is a non-parametric test of significant difference between 2+ groups, based on any distance measure

# Test for dissimilarity between sites
ano_dist <- vegdist(abundances)
attach(by_core_with_site)
ano_test_sites <- anosim(ano_dist, site, permutations = 9999)

# R value close to 1.0 suggests inter-group differences are greater than intra-group differences) 
# p-value represents the confidence level of the statistical analysis
summary(ano_test_sites) 


# Test for dissimilarity between collection dates 
# Add column for collection date (collection_id)

by_core_with_site <- by_core_with_site %>% 
  mutate(collection_id = str_sub(core_id, 1, 3))

# Split data frames into sites so that effect of date can be examined independently of site
NS_abundances <- abundances %>% 
  slice(1:33)
NS_by_core_with_site <- by_core_with_site %>% 
  slice(1:33)

NH_abundances <- abundances %>% 
  slice(34:57)
NH_by_core_with_site <- by_core_with_site %>% 
  slice(34:57)

SP_abundances <- abundances %>% 
  slice(58:90)
SP_by_core_with_site <- by_core_with_site %>% 
  slice(58:90)

# ANOSIM for Newman Sound collection dates
ano_dist_NS <- vegdist(NS_abundances)
attach(NS_by_core_with_site)
ano_test_dates_NS <- anosim(ano_dist_NS, collection_id, permutations = 9999)

summary(ano_test_dates_NS) 

# ANOSIM for Neddie's Harbour collection dates
ano_dist_NH <- vegdist(NH_abundances)
attach(NH_by_core_with_site)
ano_test_dates_NH <- anosim(ano_dist_NH, collection_id, permutations = 9999)

summary(ano_test_dates_NH) 

# ANOSIM for St. Paul's collection dates
ano_dist_SP <- vegdist(SP_abundances)
attach(SP_by_core_with_site)
ano_test_dates_SP <- anosim(ano_dist_SP, collection_id, permutations = 9999)

summary(ano_test_dates_SP) 


### SIMPER ----
# Supports the ANOSIM. Which taxa contribute the most to dissimilarity between the 3 sites? First compare each pair of sites: 
abundances <- abundances %>% 
  dplyr::select(-X)

simp <- with(by_core_with_site, simper(abundances, site, permutations = 9999))
summary(simp, ordered = TRUE)

# Save the SIMPER object as a list of data frames (one for each site-site comparison)
# First, get a vector of the names of all those lists 
comparisons <- names(summary(simp, ordered = TRUE))

# Then, for each element in that vector, apply the following function:
simp_dfs <- purrr::map(comparisons, function(x) {
  summary(simp, ordered = TRUE)[[x]] %>% 
    as_tibble(rownames = "taxa") %>% 
    # Only take the top 10 taxa from each comparison
    slice(1:10) %>% 
    # Create the variable "comparison" so you know where each row is from
    dplyr::mutate(comparison = x)
}) %>% 
  # Name each list as the comparison (otherwise they'll just be indexed as [1], [2] etc.)
  set_names(., nm = comparisons) %>% 
  # Then stack them all together into one long data frame (bind_rows requires the list elements to be named)
  bind_rows()

# Save result as an RDS so you don't have to re-run the code every time 
saveRDS(simp_dfs, "data/processed/top10_taxa_SIMPER.rds")
simp_saved <- read_rds("data/processed/top10_taxa_SIMPER.rds")

# Determine which taxa appear most often in the top 10
key_spp <- simp_saved %>% 
  dplyr::count(taxa) %>% 
  dplyr::arrange(-n)

key_spp$taxa <- factor(key_spp$taxa, levels = key_spp$taxa)

ggplot(data = key_spp, aes(x = taxa, y = n)) +
  geom_bar(stat = "identity") + 
  theme(axis.text.x = element_text(angle = 90, vjust = 0.5, hjust = 1)) + 
  labs(x = "Taxon", y = "Appearances in top 10 most influential taxa (#/3)")


### Plot labeled with 11 most influential taxa  ----
# Those that SIMPER found to contribute most to dissimilarity between sites
# Only these 11 will be labeled on the plot for clarity 

# First make a list of those 11 taxa 
list_dominant_taxa <- list("Gastropoda.indet", "Gemma.gemma", "Bivalvia.indet", 
                           "Pygospio.elegans", "Naididae.indet", "Polydora.cornuta",
                           "Paranais.litoralis", "Monocorophium.sp", "Mya.sp",
                           "Manayunkia.aestuarina", "Tellinidae.indet"
)
dominant_taxa_only <- subset(nmds.species, rownames(nmds.species) %in% list_dominant_taxa)

tiff("figures/nMDS_with_species_names.tiff", width = 12, height = 9, units = "in", res = 300)
ggplot(data = data.scores) + 
  stat_ellipse(aes(x = NMDS1, y = NMDS2, colour = site),level = 0.50, show.legend = FALSE) +
  geom_point(aes(x = NMDS1, y = NMDS2, colour = site, shape = site), size = 4) +
  # Add stress value to plot 
  geom_text(x = 0.8, y = 1, label = "stress = 0.157", color = "black", cex = 5) +
  geom_text(x = 0.76, y = 0.9, label = "F = 64.2, p = 0.001", color = "black", cex = 5) +
  geom_text_repel(data = dominant_taxa_only, aes(x = MDS1, y = MDS2), label = rownames(dominant_taxa_only), size = 5, max.overlaps = 15) +
  theme_bw(base_size = 20) + 
  scale_colour_brewer(palette = "Dark2") +
  theme(panel.grid.major = element_blank(), 
        panel.grid.minor = element_blank(),
        axis.title.y = element_text(vjust = 3),
        axis.title.x = element_text(vjust = -1),
        legend.position = c(0.85, 0.1)) + 
  labs(x = "nMDS1", y = "nMDS2", shape = "Site", colour = "Site")
dev.off()


# Plot with different symbols to represent each collection date
data.scores <- data.scores %>% 
  dplyr::mutate(collection_number = str_extract(incubation_ID, "\\d+"))

tiff("figures/nMDS_with_species_names_symbols_for_dates.tiff", width = 12, height = 9, units = "in", res = 300)
ggplot(data = data.scores) + 
  stat_ellipse(aes(x = NMDS1, y = NMDS2, colour = site), level = 0.50, show.legend = FALSE) +
  geom_point(aes(x = NMDS1, y = NMDS2, colour = site, shape = collection_number), size = 4) +
  # Add stress value to plot 
  geom_text(x = 0.8, y = 1, label = "stress = 0.157", color = "black", cex = 5) +
  geom_text(x = 0.76, y = 0.9, label = "F = 64.2, p < 0.001", color = "black", cex = 5) +
  geom_point(data = dominant_taxa_only, aes(x = MDS1, y = MDS2)) + 
  geom_text_repel(data = dominant_taxa_only, aes(x = MDS1, y = MDS2), label = rownames(dominant_taxa_only), size = 5, max.overlaps = 15) +
  theme_bw(base_size = 20) + 
  scale_colour_brewer(palette = "Dark2") +
  theme(panel.grid.major = element_blank(), 
        panel.grid.minor = element_blank(),
        axis.title.y = element_text(vjust = 3),
        axis.title.x = element_text(vjust = -1),
        legend.position = c(0.75, 0.1),
        legend.direction = "vertical", legend.box = "horizontal") + 
  labs(x = "nMDS1", y = "nMDS2", shape = "Collection", colour = "Site")
dev.off()


# nMDS plots (Binned data) ---- 
all.nmds.binned <- metaMDS(by_core_for_indices, try = 20, trymax = 500)
data.scores.binned <- as.data.frame(scores(all.nmds.binned)) 

# Add core names, incubation_ID (ie. collection date), and site to data.scores
# This will allow for labeling/colouring on the plot
data.scores.binned$core <- rownames(data.scores.binned)

data.scores.binned$incubation_ID <- sub("_.*","",data.scores.binned$core)

collection_site <- c(rep("AC", 33), rep("NH", 24), rep("SP", 33))
data.scores.binned$site <- collection_site

# Create data frame of species coordinates so they can also be plotted 
nmds.binned.species <- as.data.frame(all.nmds.binned$species)

# Calculate stress value
stress.binned <- all.nmds.binned$stress

# Change site names so they are fully spelled out in plot legends
data.scores.binned <- data.scores.binned %>% 
  dplyr::mutate(site = case_when(
    site == "SP" ~ "St. Paul's",
    site == "NH" ~ "Neddie's Harbour",
    site == "AC" ~ "Newman Sound"
  ))

# nMDS plot that includes points and labels for each individual taxon
# Species shared between sites sit between the clouds of core points
ggplot(data = data.scores.binned) + 
  stat_ellipse(aes(x = NMDS1, y = NMDS2, colour = site), level = 0.50) +
  geom_point(aes(x = NMDS1, y = NMDS2, shape = site, colour = site), size = 4) +
  # Add stress to the plot 
  geom_text(x = 0.85, y = 1.8, label = "stress = 0.172", color = "black", cex = 5) +
  geom_point(data = nmds.binned.species, aes(x = MDS1, y = MDS2)) + 
  geom_text_repel(data = nmds.binned.species, aes(x = MDS1, y = MDS2), label = rownames(nmds.binned.species), size = 3, max.overlaps = 15) +
  theme_bw(base_size = 20) + 
  guides(colour = "none") +
  theme(panel.grid.major = element_blank(), 
        panel.grid.minor = element_blank(),
        axis.title.y = element_text(vjust = 3),
        axis.title.x = element_text(vjust = -1),
        legend.position = c(0.85, 0.1)) + 
  labs(x = "nMDS1", y = "nMDS2", shape = "Site", colour = "Site")


### PERMANOVA (Binned) ----
# Tests for differences between the centroids of different groups 
abundances_binned <- by_core_for_indices

# Distance matrix
abundances_binned_dist <- vegdist(abundances_binned)

# PERMANOVA indicates different centroids between sites 
abundances_binned_div <- adonis2(abundances_binned_dist ~ site, data = by_core_for_indices, permutations = 9999, method = "bray")
abundances_binned_div 

# Model summary table 
broom::tidy(abundances_binned_div) %>% 
  # Specify the number of decimal places you'd like in the table
  dplyr::mutate(across(where(is.numeric), ~round(., 3))) %>% 
  # For very small p-value, replace with "<0.001" for ease of reading
  dplyr::mutate(p.value = if_else(p.value == 0.000, "< 0.001", as.character(p.value))) %>% 
  # Rename column headers for table to make them more legible
  dplyr::rename("Term" = "term",
                "pseudo-F" = "statistic",
                "p-value" = "p.value") %>% 
  # Create table 
  flextable()


### ANOSIM (Binned) ----
# Analysis of Similarities (using the vegan package)
# This is a non-parametric test of significant difference between 2+ groups, based on any distance measure

# Test for dissimilarity between sites
ano_dist_binned <- vegdist(abundances_binned)
attach(by_core_with_site_for_indices)
ano_test_sites_binned <- anosim(ano_dist_binned, site, permutations = 9999)

summary(ano_test_sites_binned) 


### SIMPER (Binned) ----
# This supports the ANOSIM 
# Which (binned) taxa contribute the most to dissimilarity between the 3 sites? First compare each pair of sites: 
abundances_binned <- abundances_binned %>% 
  dplyr::select(-X)

simp_binned <- with(by_core_with_site_for_indices, simper(abundances_binned, site, permutations = 9999))
summary(simp_binned, ordered = TRUE)

# Save the SIMPER object as a list of data frames (one for each site-site comparison)
# First, get a vector of the names of all those lists 
comparisons_binned <- names(summary(simp_binned, ordered = TRUE))

# Then, for each element in that vector, apply the following function:
binned_simp_dfs <- purrr::map(comparisons_binned, function(x) {
  summary(simp_binned, ordered = TRUE)[[x]] %>% 
    as_tibble(rownames = "taxa") %>% 
    # Only take the top 10 taxa from each comparison
    slice(1:10) %>% 
    # Create the variable "comparison" so you know where each row is from
    dplyr::mutate(comparison = x)
}) %>% 
  # Name each list as the comparison (otherwise they'll just be indexed as [1], [2] etc.)
  set_names(., nm = comparisons_binned) %>% 
  # Then stack them all together into one long data frame (bind_rows requires the list elements to be named)
  bind_rows()

# Save result as an RDS so you don't have to re-run the code every time 
saveRDS(binned_simp_dfs, "data/processed/top10_binned_taxa_SIMPER.rds")
binned_simp_saved <- read_rds("data/processed/top10_binned_taxa_SIMPER.rds")

View(binned_simp_saved)

# Determine which taxa appear most often in the top 10
key_binned_spp <- binned_simp_saved %>% 
  dplyr::count(taxa) %>% 
  dplyr::arrange(-n)

# Plot to visualize how often each taxon appears in the top 10
key_binned_spp$taxa <- factor(key_binned_spp$taxa, levels = key_binned_spp$taxa)

ggplot(data = key_binned_spp, aes(x = taxa, y = n)) +
  geom_bar(stat = "identity") + 
  theme(axis.text.x = element_text(angle = 90, vjust = 0.5, hjust = 1)) + 
  labs(x = "Taxon", y = "Appearances in top 10 most influential taxa (#/3)")


### Plot labeled with 12 most influential binned taxa ----
# Those that SIMPER found to contribute most to dissimilarity between sites
# Only these 12 will be labeled on the plot for clarity 

# First make a list of those 12 binned taxa 
list_dominant_binned_taxa <- list("Monocorophium.sp", "Naididae.indet", "Pygospio.elegans", 
                                  "Ecrobia.truncata", "Gemma.gemma", "Heteromastus.sp", 
                                  "Manayunkia.aestuarina", "Mya.sp", "Odostomia.sp", 
                                  "Polydora.cornuta", "Rissooidea.indet", "Tellinidae.indet")

dominant_binned_taxa_only <- subset(nmds.binned.species, rownames(nmds.binned.species) %in% list_dominant_binned_taxa)

# Change row names so that taxon names appear correctly in nMDS plot
rownames(dominant_binned_taxa_only) <- c("Ecrobia truncata", "Gemma gemma", "Heteromastus sp.", "Manayunkia aestuarina",
                                         "Monocorophium sp.", "Mya sp.", "Naididae indet.", "Odostomia sp.", 
                                         "Polydora cornuta", "Pygospio elegans", "Rissooidea indet.", "Tellinidae indet.")

# Plot, with different symbols to represent each collection date:

data.scores.binned <- data.scores.binned %>% 
  dplyr::mutate(collection_number = str_extract(incubation_ID, "\\d+"))

tiff("figures/nMDS_with_binned_species_names_symbols_for_dates.tiff", width = 12, height = 9, units = "in", res = 300)
ggplot(data = data.scores.binned) + 
  stat_ellipse(aes(x = NMDS1, y = NMDS2, colour = site), level = 0.50, show.legend = FALSE) +
  geom_point(aes(x = NMDS1, y = NMDS2, colour = site, shape = collection_number), size = 4) +
  # Add stress value to plot 
  geom_text(x = 0.8, y = 0.75, label = "stress = 0.172", color = "black", cex = 5) +
  geom_text(x = 0.75, y = 0.65, label = "F = 64.4, p < 0.001", color = "black", cex = 5) +
  geom_text_repel(data = dominant_binned_taxa_only, aes(x = MDS1, y = MDS2), label = rownames(dominant_binned_taxa_only), 
                  size = 5, fontface = "italic", max.overlaps = 15) +
  theme_bw(base_size = 20) + 
  scale_colour_brewer(palette = "Dark2") +
  theme(panel.grid.major = element_blank(), 
        panel.grid.minor = element_blank(),
        axis.title.y = element_text(vjust = 3),
        axis.title.x = element_text(vjust = -1),
        legend.position = c(0.75, 0.1),
        legend.direction = "vertical", legend.box = "horizontal") + 
  labs(x = "nMDS1", y = "nMDS2", shape = "Collection", colour = "Site")
dev.off()

# Also save this plot object as an RDS file so it can be combined with TD and FD indices nMDS plots in a later script
nmds_binned_composition <- ggplot(data = data.scores.binned) + 
  stat_ellipse(aes(x = NMDS1, y = NMDS2, colour = site), level = 0.50, show.legend = FALSE) +
  geom_point(aes(x = NMDS1, y = NMDS2, colour = site, shape = collection_number), size = 4) +
  # Add stress to the plot 
  geom_text(x = 0.8, y = 0.75, label = "stress = 0.172", color = "black", cex = 5) +
  geom_text(x = 0.75, y = 0.65, label = "F = 64.4, p < 0.001", color = "black", cex = 5) +
  geom_text_repel(data = dominant_binned_taxa_only, aes(x = MDS1, y = MDS2), label = rownames(dominant_binned_taxa_only), 
                  size = 5, fontface = "italic", max.overlaps = 15) +
  theme_bw(base_size = 20) + 
  scale_colour_brewer(palette = "Dark2") +
  theme(panel.grid.major = element_blank(), 
        panel.grid.minor = element_blank(),
        axis.title.y = element_text(vjust = 3),
        axis.title.x = element_text(vjust = -1),
        legend.position = c(0.80, 0.15),
        legend.direction = "vertical", legend.box = "horizontal") + 
  labs(x = "nMDS1", y = "nMDS2", shape = "Collection", colour = "Site")

saveRDS(nmds_binned_composition, "data/processed/nmds_plot_binned_composition.rds")

#### END ####
