## Functional data prep
## By: Mary Clinton
## Date created: April 5, 2022
## Date last modified: June 2, 2023

# Load libraries
library(tidyverse)  # Data wrangling 
library(FD)         # Computing functional diversity (FD) indices
library(ade4)       # Calculate Gower's distances 

# Load functions 
source("code/src/from_villeger/quality_funct_space_fromdist.R")   # Creates functional space 
source("code/src/from_villeger/plot_funct_space.R")               # Plots of the functional space (max 4 dimensions)
source("code/src/from_villeger/multidimFD.R")                     # Calculates FD indices from plots of functional space 

# Load data
abundances <- read.csv("data/processed/abundances_by_core.csv")
abundances_for_indices <- read.csv("data/processed/abundances_by_core_for_calculation_of_indices.csv", header = TRUE)
functional_data <- read.csv("data/raw/Functional_Traits_All_Macrofauna_All_Sites.csv")


# Data setup ----

# Remove extra column called X
abundances <- abundances %>%
  dplyr::select(-X)

abundances_for_indices <- abundances_for_indices %>% 
  # And re-sort columns so they are in alphabetical order
  select(core_id, sort(colnames(abundances_for_indices)[-c(1, 2)])) 

# Make core_id the row names for the matrix, then remove the column core_id
rownames(abundances) <- abundances$core_id
abundances <- abundances %>%
  dplyr::select(-core_id)

rownames(abundances_for_indices) <- abundances_for_indices$core_id
abundances_for_indices <- abundances_for_indices %>%
  dplyr::select(-core_id) 

# Add . between genus & species names, to match abundances data frame
functional_data <- functional_data %>%
  mutate(taxon = str_replace_all(taxon, " ", ".") %>% 
         str_remove_all(., "[.]$")) %>% 
  # Rename Eteone lactea to Hypereteone lactea (to match most up-to-date taxonomic classification)
  mutate(taxon = ifelse(taxon == "Eteone.lactea", "Hypereteone.lactea", taxon)) %>% 
  # Re-order so that taxa are alphabetical
  arrange(., taxon)

# Create functional data frame that only includes taxa being used for calculation of diversity indices 
functional_data_for_indices <- functional_data %>% 
  # Remove high abundance, high-level grouping representing many mixed taxa
  filter(taxon != "Bivalvia.indet", taxon != "Gastropoda.indet",
         # Remove high-level individuals OR high-level small groups of juveniles 
         taxon != "Amphipoda.indet", taxon != "Capitellidae.indet", taxon != "Corophiidae.indet",
         taxon != "Crustacea.indet", taxon != "Enteropneusta.indet", taxon != "Gammaroidea.indet",
         taxon != "Macominae.indet", taxon != "Nereididae.indet", taxon != "Spionidae.indet",
         # Remove taxa that were grouped to higher taxonomic level because resolution differed between sites
         taxon != "Macoma.balthica", taxon != "Heteromastus.filiformis", taxon != "Mya.arenaria",
         taxon != "Pectinaria.gouldii", taxon != "Spio.setosa", taxon != "Monocorophium.acherusicum", 
         taxon != "Monocorophium.insidiosum", taxon != "Tellina.sp", taxon != "Lineidae.indet", 
         taxon != "Paranais.litoralis", taxon != "Paranais.sp", taxon != "Amphichaeta.sp")

write.csv(functional_data_for_indices, "data/processed/Functional_Traits_All_Binned_Macrofauna_All_Sites.csv")

# For both traits data frames, set taxa as row names, then remove taxa column so that you're left with just a trait table
rownames(functional_data) <- functional_data$taxon
functional_data <- functional_data %>%
  dplyr::select(-taxon)

rownames(functional_data_for_indices) <- functional_data_for_indices$taxon
functional_data_for_indices <- functional_data_for_indices %>%
  dplyr::select(-taxon)

# Reorder data frames so that species names are in alphabetical order 
functional_data <- functional_data[order(row.names(functional_data)), ]
functional_data_for_indices <- functional_data_for_indices[order(row.names(functional_data_for_indices)), ]

#Look at data types - all currently listed as quantitative traits, so need to designate correct data types
summary(functional_data)
summary(functional_data_for_indices)


## Correcting data types with ktab ----
#### All taxa ----

# Specify each fuzzy coded trait as fuzzy
diet_fuzz <- prep.fuzzy(as.data.frame(functional_data[, 1:3]), col.blocks = 3, label="diet")
feeding_fuzz <- prep.fuzzy(as.data.frame(functional_data[, 4:9]), col.blocks = 6, label="feeding")


# Log transform body size, then scale body size between 0 and 1 so that it doesn't have a disproportionate impact on Gower distance
body_size <- log(functional_data$body_size)

scale_0_1 <- function(x){
  (x-min(x)) / (max(x) - min(x))
}

body_size <- scale_0_1(body_size)
names(body_size) <- rownames(functional_data)

# Specify reworking as a nominal variable
reworking <- factor(functional_data[ ,"reworking"],
                    levels = c("epi", "bd", "sm", "updown"), ordered = FALSE)
names(reworking) <- rownames(functional_data)

# Change mobility from nominal to ordinal
mobility <- factor(functional_data[ ,"mobility"], 
                   levels = c(0, 0.3, 0.6, 1), ordered = TRUE)
names(mobility) <- rownames(functional_data)

# Join all traits together into a new dataframe (by listing all 6 traits as an object of type "ktab")
all_traits_ktab <- ktab.list.df(list(diet_fuzz, feeding_fuzz, as.data.frame(body_size), 
                                     as.data.frame(reworking), as.data.frame(mobility)))

# Compute Gower's distance between all species using function from Pavoine et al (2009)
Gower_traits <- dist.ktab(all_traits_ktab, type = c("F","F","Q", "N", "O"), option = c("noscale"))
Gower_traits # View distance matrix 


#### Binned taxa for indices ----
# Repeat above for the subset of taxa that will be used to compute FD indices 

# Specify each fuzzy coded trait as fuzzy
diet_fuzz_for_indices <- prep.fuzzy(as.data.frame(functional_data_for_indices[, 1:3]), col.blocks = 3, label = "diet")
feeding_fuzz_for_indices <- prep.fuzzy(as.data.frame(functional_data_for_indices[, 4:9]), col.blocks = 6, label = "feeding")


# Log transform body size, then scale body size between 0 and 1 so that it doesn't have a disproportionate impact on Gower distance
body_size_for_indices <- log(functional_data_for_indices$body_size)
body_size_for_indices <- scale_0_1(body_size_for_indices)
names(body_size_for_indices) <- rownames(functional_data_for_indices)

# Specify reworking as a nominal variable
reworking_for_indices <- factor(functional_data_for_indices[ ,"reworking"], 
                                levels = c("epi", "bd", "sm", "updown"), ordered = FALSE)
names(reworking_for_indices) <- rownames(functional_data_for_indices)

# Change mobility from nominal to ordinal
mobility_for_indices <- factor(functional_data_for_indices[ ,"mobility"], 
                               levels = c(0, 0.3, 0.6, 1), ordered = TRUE)
names(mobility_for_indices) <- rownames(functional_data_for_indices)

# Join all traits together into a new data frame (by listing all 6 traits as an object of type "ktab")
all_traits_for_indices_ktab <- ktab.list.df(list(diet_fuzz_for_indices, feeding_fuzz_for_indices, as.data.frame(body_size_for_indices), 
                                     as.data.frame(reworking_for_indices), as.data.frame(mobility_for_indices)))

# Compute Gower's distance between all species using function from Pavoine et al (2009)
Gower_traits_for_indices <- dist.ktab(all_traits_for_indices_ktab, type = c("F","F","Q", "N", "O"), option = c("noscale"))
Gower_traits_for_indices # View distance matrix


# Create the functional space ----
### All taxa ----

functional_space <- quality_funct_space_fromdist(Gower_traits, nbdim = 10, plot = NA)
functional_space$meanSD # 5D-space has a meanSD < 0.01 so proceed with 5D

# Species coordinates in the 5D space
coord_5D <- functional_space$details_funct_space$mat_coord[,1:5] #These are your PCs
coord_4D <- functional_space$details_funct_space$mat_coord[,1:4] #This one only has 4 dimensions - for beta div later on

# Save coordinates of functional space as a csv so that it can be used later to calculate FD indices for each depth layer
coordinates_5D <- as.data.frame(coord_5D)
write.csv(coordinates_5D, "data/processed/functional_space_coordinates_all_sites.csv")


### Binned taxa for indices ----

functional_space_for_indices <- quality_funct_space_fromdist(Gower_traits_for_indices, nbdim = 10, plot = NA)
functional_space_for_indices$meanSD # 4D-space has a meanSD < 0.01 so proceed with 4D

# Species coordinates in the 4D space
coord_4D_for_indices <- functional_space_for_indices$details_funct_space$mat_coord[ ,1:4] # These are your PCs

# Save coordinates of functional space as a csv so that it can be used later to calculate FD indices for each depth layer
coordinates_4D_for_indices <- as.data.frame(coord_4D_for_indices)
write.csv(coordinates_4D_for_indices, "data/processed/functional_space_coordinates_binned_taxa_for_indices_all_sites.csv")


# Calculate FD indices ----
abundances_for_indices <- as.matrix(abundances_for_indices)

FD_indices <- multidimFD(coord_4D_for_indices, abundances_for_indices, check_species_pool = TRUE, verb = TRUE,
                         #nm_asb_plot = row.names(abundances), folder_plot = paste(""),
                         #Faxes_plot = colnames(coord_5D)[1:4], Faxes_nm_plot = colnames(coord_5D)[1:4],
                         #plot_pool = TRUE, col_bg = "grey90", col_sp_pool = "grey30",  pch_sp_pool = "+", 
                         #cex_sp_pool=1, pch_sp = 21, col_sp = "#1E90FF", transp = 50
)

# Round results to 3 decimals and save as a CSV file
FD_indices_3deci <- round(FD_indices,3)
write.csv(FD_indices_3deci, "data/processed/FD_indices.csv")

#### END ####