## Functional data analysis
## By: Mary Clinton
## Date created: July 28, 2021
## Date last modified: June 2, 2023


# Load libraries
library(tidyverse)    # Data wrangling/cleaning
library(FD)           # Calculating functional diversity indices
library(ggsignif)     # Adding significance values in ggplot
library(glmmTMB)      # Beta regression 
library(lme4)         # Mixed effects models (normal and non-normal)
library(effects)      # Display model results
library(flextable)    # Create tables that can be copied directly to word documents
library(DHARMa)       # Model diagnostics & model fitting

# Load data 
FD_indices <- read.csv("data/processed/FD_indices.csv")

# Load functions
source("code/src/from_villeger/quality_funct_space_fromdist.R")  # Creates functional space
source("code/src/from_villeger/multidimFD.R")                    # Computes FD indices
source("code/src/boot-resample.R")                               # Randomly sub-samples cores from a site
source("code/src/pub-ready-effects-plots.R")                     # Creates publication-ready plots from output of effects package

# Set theme for plots 
theme_MEC <- function () { 
  theme_bw(base_size = 12) + 
    theme(panel.grid.major = element_blank(), panel.grid.minor = element_blank(), 
          axis.line = element_line(colour = "black"), 
          axis.text = element_text(size = 16, face = "plain"), 
          axis.title = element_text(size = 18, face = "plain"),
          legend.text = element_text(size = 16, face = "plain"), 
          legend.title = element_text(size = 18, face = "bold"))
} 
theme_set(theme_MEC())


# Prep data ----

# Add column for site to FD_indices
FD_indices <- FD_indices %>% 
  mutate(site = str_sub(X, 1, 2)) %>% 
  mutate(site = case_when(
    site == "AC" ~ "Newman Sound", 
    site == "NH" ~ "Neddie's Harbour",
    site == "SP" ~ "St. Paul's"))

# FD indices (by core) ----
# Summary table (mean & SD) for FD indices at each site
FD <- as.data.frame(FD_indices)
rownames(FD) <- FD$X
FD_summary <- FD %>% 
  select(site, FRic, FDiv, FEve) %>% 
  group_by(site) %>% 
  summarise(mean = across(FRic:FEve, ~mean(., na.rm = TRUE)),
            sd = across(FRic:FEve, ~sd(., na.rm = TRUE)))


# Boxplots ----
FRic_plot <- ggplot(FD_indices, aes(x = site, y = FRic)) + 
  geom_boxplot() +
  labs(x = "", y = "Functional richness (FRic)") +
  theme_bw(base_size = 15) + 
  theme(panel.grid.major = element_blank(), 
        panel.grid.minor = element_blank(),
        axis.title.y = element_text(vjust = 3),
        axis.title.x = element_text(vjust = -1))  + 
  scale_x_discrete(labels = c("Newman Sound" = "Newman\nSound",
                              "Neddie's Harbour" = "Neddie's\nHarbour"))

FEve_plot <- ggplot(FD_indices, aes(x = site, y = FEve)) + 
  geom_boxplot() +
  labs(x = "", y = "Functional evenness (FEve)") +
  theme_bw(base_size = 15) + 
  theme(panel.grid.major = element_blank(), 
        panel.grid.minor = element_blank(),
        axis.title.y = element_text(vjust = 3),
        axis.title.x = element_text(vjust = -1)) + 
  scale_x_discrete(labels = c("Newman Sound" = "Newman\nSound",
                              "Neddie's Harbour" = "Neddie's\nHarbour")) 

FDiv_plot <- ggplot(FD_indices, aes(x = site, y = FDiv)) + 
  geom_boxplot() +
  labs(x = "", y = "Functional divergence (FDiv)") +
  theme_bw(base_size = 15) + 
  theme(panel.grid.major = element_blank(), 
        panel.grid.minor = element_blank(),
        axis.title.y = element_text(vjust = 3),
        axis.title.x = element_text(vjust = -1)) + 
  scale_x_discrete(labels = c("Newman Sound" = "Newman\nSound",
                              "Neddie's Harbour" = "Neddie's\nHarbour")) 


# Plot & save plots contrasting all 5 taxonomic diversity indices b/t the 2 sites
tiff("figures/FD_indices_boxplots.tiff", width = 12, height = 9, units = "in", res = 300)
cowplot::plot_grid(FRic_plot, FEve_plot, FDiv_plot,
                   labels = LETTERS[1:3],
                   align = "v", axis = "l")
dev.off()



# Testings for differences between sites (GLM) ----
# As all 3 FD indices are bounded between 0 and 1, we start with beta regression

## FRic ----

# First run the model
# One sample contained no taxa, so FRic is zero. An exact zero is not allowed in beta distribution, so remove that data point
FD_indices_no_0 <- FD_indices %>% 
  mutate(FRic = replace(FRic, FRic == 0.000, NA)) %>% 
  drop_na(FRic)

FRic_beta <- glmmTMB(FRic ~ site, data = FD_indices_no_0, family = beta_family(link = "logit"))

# STEP 1) Calculate scaled residuals
FRic_beta_simulationOutput <- simulateResiduals(fittedModel = FRic_beta, plot = F)

# STEP 2) Plot the scaled residuals 
plot(FRic_beta_simulationOutput)  
plotResiduals(FRic_beta_simulationOutput, form = FD_indices_no_0$site) 

# STEP 3) Goodness of fit tests
testDispersion(FRic_beta_simulationOutput) 
testUniformity(FRic_beta_simulationOutput) 
testOutliers(FRic_beta_simulationOutput)   

# Model summary 
summary(FRic_beta)

# Plot it!
FRic_by_site_effects_plot <- pub_effects_plot(FRic_beta, FD_indices, "FRic", "Functional richness (FRic)", is_beta = TRUE)

# Save plot
ggsave(filename = "figures/mean_FRic_by_site_effects_plot.png", plot = FRic_by_site_effects_plot, 
       width = 10, height = 10, units = "in", dpi = 300)


## FEve ----

# Beta regression model
FEve_beta <- glmmTMB(FEve ~ site, data = FD_indices, family = beta_family(link = "logit"))

# STEP 1) Calculate scaled residuals
FEve_beta_simulationOutput <- simulateResiduals(fittedModel = FEve_beta, plot = F)

# STEP 2) Plot the scaled residuals 
plot(FEve_beta_simulationOutput) 
plotResiduals(FEve_beta_simulationOutput, form = FD_indices$site) 

# STEP 3) Goodness of fit tests
testDispersion(FEve_beta_simulationOutput) 
testUniformity(FEve_beta_simulationOutput) 
testOutliers(FEve_beta_simulationOutput)  

# Model summary 
summary(FEve_beta)

# Plot it! 
FEve_by_site_effects_plot <- pub_effects_plot(FEve_beta, FD_indices, "FEve", "Functional evenness (FEve)", is_beta = TRUE)

# Save plot
ggsave(filename = "figures/mean_FEve_by_site_effects_plot.png", plot = FEve_by_site_effects_plot, 
       width = 10, height = 10, units = "in", dpi = 300)


## FDiv ----

# Beta regression model
FDiv_beta <- glmmTMB(FDiv ~ site, data = FD_indices, family = beta_family(link = "logit"))

# STEP 1) Calculate scaled residuals
FDiv_beta_simulationOutput <- simulateResiduals(fittedModel = FDiv_beta, plot = F)

# STEP 2) Plot the scaled residuals 
plot(FDiv_beta_simulationOutput) 
plotResiduals(FDiv_beta_simulationOutput, form = FD_indices$site) 

# STEP 3) Goodness of fit tests
testDispersion(FDiv_beta_simulationOutput) 
testUniformity(FDiv_beta_simulationOutput) 
testOutliers(FDiv_beta_simulationOutput)   

# Model summary 
summary(FDiv_beta)

# Plot it! 
FDiv_by_site_effects_plot <- pub_effects_plot(FDiv_beta, FD_indices, "FDiv", "Functional divergence (FDiv)", is_beta = TRUE)

# Save plot
ggsave(filename = "figures/mean_FDiv_by_site_effects_plot.png", plot = FDiv_by_site_effects_plot, 
       width = 10, height = 10, units = "in", dpi = 300)


## Summary table: All models of FD ~ site ----

# Make a list of all the fitted model objects (tibbles) you want to group into one table 
purrr::map(list(FRic_beta, FEve_beta, FDiv_beta), broom::tidy) %>% 
  # Name each table within the large table 
  set_names(., nm = c("FRic", "FEve", "FDiv")) %>% 
  # Combine together  
  bind_rows(.id = "Index") %>% 
  # Specify the number of decimal places you want to display 
  dplyr::mutate(across(where(is.numeric), ~round(., 3))) %>% 
  # For ease of reading, rename terms, column headers and make very small p-value read "<0.001"
  dplyr::mutate(p.value = if_else(p.value == 0.000, "< 0.001", as.character(p.value))) %>% 
  dplyr::mutate(term = case_when(
    term == "siteNewman Sound" ~ "Newman Sound", 
    term == "siteSt. Paul's" ~ "St. Paul's",
    term == "(Intercept)" ~ "Intercept"
  )) %>%
  dplyr::select(-effect, -component) %>% 
  rename("Term" = "term",
         "Estimate" = "estimate",
         "SE" = "std.error",
         "t-statistic" = "statistic",
         "p-value" = "p.value") %>% 
  # Group so that the Index column doesn't repeat the index name in every row
  as_grouped_data(groups = "Index") %>% 
  # Make the table
  flextable()


#### END ####