## Plots of TD & FD diversity indices 
## By: Mary Clinton
## Date created: March 11, 2023
## Date last modified: February 2, 2024

# Load libraries 
library(tidyverse)    # Data wrangling/cleaning & plotting
library(vegan)        # nMDS plots
library(flextable)    # Publication-ready summary tables 

# Load data
TD_indices <- read.csv("data/processed/TD_indices.csv")
FD_indices <- read.csv("data/processed/FD_indices.csv")

# Set theme for plots 
theme_MEC <- function () { 
  theme_bw(base_size = 12) + 
    theme(panel.grid.major = element_blank(), panel.grid.minor = element_blank(), 
          axis.line = element_line(colour = "black"), 
          axis.text = element_text(size = 16, face = "plain"), 
          axis.title = element_text(size = 18, face = "plain"),
          legend.text = element_text(size = 16, face = "plain"), 
          legend.title = element_text(size = 18, face = "bold"))
} 
theme_set(theme_MEC())

# Prep data
# Add column for site to FD_indices
FD_indices <- FD_indices %>% 
  mutate(site = str_sub(X, 1, 2)) %>% 
  mutate(site = case_when(
    site == "AC" ~ "Newman Sound", 
    site == "NH" ~ "Neddie's Harbour",
    site == "SP" ~ "St. Paul's")) %>% 
  select(X, site, FRic, FDiv, FEve) %>% 
  dplyr::rename(core_id = X)

TD_indices <- TD_indices %>% 
  select(-X)


# Box plots: TD & FD indices together ----

shannon_plot <- ggplot(TD_indices, aes(x = site, y = shannon, fill = site)) + 
  geom_boxplot(outlier.shape = NA) +
  geom_jitter(position = position_jitterdodge(jitter.width = 0.09), alpha = 0.4, size = 1) +
  labs(x = "", y = "Shannon-Weiner (H')") +
  scale_fill_brewer(palette = "Dark2") + 
  theme(legend.position = "none",
        axis.ticks = element_blank(),
        axis.text.x = element_blank())

simpson_plot <- ggplot(TD_indices, aes(x = site, y = simpson, fill = site)) + 
  geom_boxplot() +
  geom_jitter(position = position_jitterdodge(jitter.width = 0.09), alpha = 0.4, size = 1) +
  labs(x = "", y = "Simpson's (d)") +
  scale_fill_brewer(palette = "Dark2") + 
  theme(legend.position = "none",
        axis.ticks = element_blank(),
        axis.text.x = element_blank())

richness_plot <- ggplot(TD_indices, aes(x = site, y = richness, fill = site)) + 
  geom_boxplot(outlier.shape = NA) +
  geom_jitter(position = position_jitterdodge(jitter.width = 0.09), alpha = 0.4, size = 1) +
  labs(x = "", y = "Taxonomic richness (S)") +
  scale_fill_brewer(palette = "Dark2") + 
  theme(legend.position = "none",
        axis.ticks = element_blank(),
        axis.text.x = element_blank())

pielous_plot <- ggplot(TD_indices, aes(x = site, y = pielous_evenness, fill = site)) +
  geom_boxplot(outlier.shape = NA) +
  geom_jitter(position = position_jitterdodge(jitter.width = 0.09), alpha = 0.4, size = 1) +
  labs(x = "", y = "Pielou's Evenness (J')") +
  scale_fill_brewer(palette = "Dark2") + 
  theme(legend.position = "none",
        axis.ticks = element_blank(),
        axis.text.x = element_blank())

FRic_plot <- ggplot(FD_indices, aes(x = site, y = FRic, fill = site)) + 
  geom_boxplot(outlier.shape = NA) +
  geom_jitter(position = position_jitterdodge(jitter.width = 0.09), alpha = 0.4, size = 1) +
  labs(x = "", y = "Functional richness (FRic)") +
  scale_fill_brewer(palette = "Dark2") + 
  theme(legend.position = "none",
        axis.ticks = element_blank(),
        axis.text.x = element_blank())

FEve_plot <- ggplot(FD_indices, aes(x = site, y = FEve, fill = site)) + 
  geom_boxplot(outlier.shape = NA) +
  geom_jitter(position = position_jitterdodge(jitter.width = 0.09), alpha = 0.4, size = 1) +
  labs(x = "", y = "Functional evenness (FEve)") +
  scale_fill_brewer(palette = "Dark2") + 
  theme(legend.position = "none",
        axis.ticks = element_blank(),
        axis.text.x = element_blank())

FDiv_plot <- ggplot(FD_indices, aes(x = site, y = FDiv, fill = site)) + 
  geom_boxplot(outlier.shape = NA) +
  geom_jitter(position = position_jitterdodge(jitter.width = 0.09), alpha = 0.4, size = 1) +
  labs(x = "", y = "Functional divergence (FDiv)") +
  scale_fill_brewer(palette = "Dark2") + 
  theme(legend.position = "none",
        axis.ticks = element_blank(),
        axis.text.x = element_blank())


# Create plot that contains a legend all boxplots can share
boxplot_for_legend_purposes <- ggplot(FD_indices, aes(x = site, y = FDiv, fill = site)) + 
  geom_boxplot(outlier.shape = NA) +
  geom_jitter(position = position_jitterdodge(jitter.width = 0.09), alpha = 0.4, size = 1) +
  labs(x = "", y = "Functional divergence (FDiv)", fill = "Site") +
  scale_fill_brewer(palette = "Dark2") + 
  theme(axis.ticks = element_blank(),
        axis.text.x = element_blank(),
        legend.text = element_text(size = 14),
        legend.title = element_text(size = 16),
        legend.key.size = unit(1, "cm"))

# Extract the legend and add it to the multi-panel plot below 
boxplot_legend <- cowplot::get_legend(
  # Create some space to the left of the legend
  boxplot_for_legend_purposes + theme(legend.box.margin = margin(0, 0, 0, 12))
)

# Save plots contrasting 4 taxonomic diversity indices and 3 functional diversity indices between the 2 sites
tiff("figures/TD_and_FD_indices_boxplots.tiff", width = 12, height = 9, units = "in", res = 300)
cowplot::plot_grid(richness_plot, pielous_plot, shannon_plot, simpson_plot,
                   FRic_plot, FEve_plot, FDiv_plot, boxplot_legend,
                   labels = LETTERS[1:7],
                   align = "v", axis = "l",
                   ncol = 4)
dev.off()


# TD only ----

#### PERMANOVA ----

# Permutational Analysis of Variance (using the vegan package)
# This tests for differences between the centroids of groups

# Make core_id the rownames and then remove all columns that aren't indices 
rownames(TD_indices) <- TD_indices$core_id
TD_indices_no_site <- TD_indices %>% 
  select(-core_id, -site)

TD_dist <- vegdist(TD_indices_no_site)
TD_div <- adonis2(TD_dist ~ site, data = TD_indices, permutations = 9999, method = "bray")
TD_div 

# Make model summary table into a data frame that can be indexed
TD_PERMANOVA_results <- broom::tidy(TD_div)
TD_F_value <- round(TD_PERMANOVA_results$statistic[1], 2)
TD_p_value <- if_else(TD_div$`Pr(>F)`[1] < 0.001, "< 0.001", as.character(round(TD_PERMANOVA_results$p.value[1], 3)))

# Model summary table for Supplementary material 
TD_PERMANOVA_results %>% 
  # Specify the number of decimal places you'd like in the table
  dplyr::mutate(across(where(is.numeric), ~round(., 3))) %>% 
  # For very small p-value, replace with "<0.001" for ease of reading
  dplyr::mutate(p.value = if_else(p.value < 0.001, "< 0.001", as.character(p.value))) %>% 
  # Rename column headers for table to make them more legible
  dplyr::rename("Term" = "term",
         "pseudo-F" = "statistic",
         "p-value" = "p.value") %>% 
  # Create table 
  flextable()


#### nMDS plot ----

TD.nmds <- metaMDS(TD_indices_no_site, try = 20, trymax = 500)
TD.data.scores <- as.data.frame(scores(TD.nmds)) 

# Add core ID and site to data.scores
# This will allow for labeling/colouring on the plot
TD.data.scores$core_ID <- rownames(TD.data.scores)
collection_site <- TD_indices$site
TD.data.scores$site <- collection_site

# Stress value
TD_stress <- TD.nmds$stress

# Add column for collection date so they can be plotted using different shapes
TD.data.scores <- TD.data.scores %>% 
  dplyr::mutate(collection_id = str_sub(core_ID, 3, 3))

nmds_TD_indices <- ggplot(data = TD.data.scores) + 
  stat_ellipse(aes(x = NMDS1, y = NMDS2, colour = site),level = 0.50, show.legend = FALSE) +
  geom_point(aes(x = NMDS1, y = NMDS2, colour = site, shape = collection_id), size = 4) +
  # Add stress to the plot 
  geom_text(x = 0.2, y = 0.185, label = paste("stress =", round(TD_stress, 2)), color = "black", cex = 5) +
  geom_text(x = 0.165, y = 0.17, label = paste("F =", TD_F_value, ", p =", TD_p_value), color = "black", cex = 5) +
  theme_bw(base_size = 20) + 
  scale_colour_brewer(palette = "Dark2") +
  theme(panel.grid.major = element_blank(), 
        panel.grid.minor = element_blank(),
        axis.title.y = element_text(vjust = 3),
        axis.title.x = element_text(vjust = -1),
        legend.position = "none") + 
  labs(x = "nMDS1", y = "nMDS2", shape = "Site", colour = "Site")

tiff("figures/nMDS_TD_indices.tiff", width = 12, height = 9, units = "in", res = 300)
nmds_TD_indices 
dev.off()

#### ANOSIM ----

# This is a non-parametric test of significant difference between 2+ groups, based on any distance measure
# R value close to 1.0 suggests inter-group differences are greater than intra-group differences) 
# The P-value represents the confidence level of the statistical analysis

TD_dist <- vegdist(TD_indices_no_site)
attach(TD_indices)
TD_ano_test_sites <- anosim(TD_dist, site, permutations = 9999)

summary(TD_ano_test_sites)


# FD only ----

#### PERMANOVA ----

# Permutational Analysis of Variance (using the vegan package)
# This tests for differences between the centroids of groups

# Make core_id the rownames and then remove all columns that aren't indices 
rownames(FD_indices) <- FD_indices$core_id
FD_indices_no_site <- FD_indices %>% 
  select(-core_id, -site)
FD_dist <- vegdist(FD_indices_no_site)

FD_div <- adonis2(FD_dist ~ site, data = FD_indices, permutations = 9999, method = "bray")
FD_div 

# Make model summary table into a data frame that can be indexed
FD_PERMANOVA_results <- broom::tidy(FD_div)
FD_F_value <- round(FD_PERMANOVA_results$statistic[1], 2)
FD_p_value <- if_else(FD_div$`Pr(>F)`[1] < 0.001, "< 0.001", as.character(round(FD_PERMANOVA_results$p.value[1], 3)))

# Model summary table for Supplementary material 
FD_PERMANOVA_results %>% 
  # Specify the number of decimal places you'd like in the table
  dplyr::mutate(across(where(is.numeric), ~round(., 3))) %>% 
  # For very small p-value, replace with "<0.001" for ease of reading
  dplyr::mutate(p.value = if_else(p.value == 0.000, "< 0.001", as.character(p.value))) %>% 
  # Rename column headers for table to make them more legible
  dplyr::rename("Term" = "term",
                "pseudo-F" = "statistic",
                "p-value" = "p.value") %>% 
  # Create table 
  flextable()

#### nMDS plot ----

FD.nmds <- metaMDS(FD_indices_no_site, try = 20, trymax = 500)
FD.data.scores <- as.data.frame(scores(FD.nmds)) 

# Add core ID and site to data.scores
# This will allow for labeling/colouring on the plot
FD.data.scores$core_ID <- rownames(FD.data.scores)
collection_site <- FD_indices$site
FD.data.scores$site <- collection_site

# Stress value 
FD_stress <- FD.nmds$stress

# Add column for collection ID so they can be plotted using different shapes
FD.data.scores <- FD.data.scores %>% 
  dplyr::mutate(collection_id = str_sub(core_ID, 3, 3))


nmds_FD_indices <- ggplot(data = FD.data.scores) + 
  stat_ellipse(aes(x = NMDS1, y = NMDS2, colour = site),level = 0.50, show.legend = FALSE) +
  geom_point(aes(x = NMDS1, y = NMDS2, colour = site, shape = collection_id), size = 4) +
  # Add stress & PERMANOVA results to the plot 
  geom_text(x = 0.17, y = 0.31, label = paste("stress =", round(FD_stress, 2)), color = "black", cex = 5) +
  geom_text(x = 0.125, y = 0.275, label = paste0("F = ", FD_F_value, ", p = ", FD_p_value), color = "black", cex = 5) +
  theme_bw(base_size = 20) + 
  scale_colour_brewer(palette = "Dark2") +
  # Make some white space at the top for the text
  scale_y_continuous(limits = c(-0.2, 0.31)) +
  theme(panel.grid.major = element_blank(), 
        panel.grid.minor = element_blank(),
        axis.title.y = element_text(vjust = 3),
        axis.title.x = element_text(vjust = -1),
        legend.position = "none") + 
  labs(x = "nMDS1", y = "nMDS2", shape = "Site", colour = "Site")

tiff("figures/nMDS_FD_indices.tiff", width = 12, height = 9, units = "in", res = 300)
nmds_FD_indices
dev.off()


#### ANOSIM ----

FD_dist <- vegdist(FD_indices_no_site)
attach(FD_indices)
FD_ano_test_sites <- anosim(FD_dist, site, permutations = 9999)

summary(FD_ano_test_sites) 


# TD & FD indices together ----

#### PERMANOVA ----

# Permutational Analysis of Variance (using the vegan package)
# This tests for differences between the centroids of groups

# Join TD and FD indices into a single dataframe 
all_indices_with_site <- TD_indices %>% 
  full_join(FD_indices)

# Make core_id the rownames and then remove all columns that aren't indices 
rownames(all_indices_with_site) <- all_indices_with_site$core_id
all_indices <- all_indices_with_site %>% 
  select(-core_id, -site)
all_indices_dist <- vegdist(all_indices)

all_indices_div <- adonis2(all_indices_dist ~ site, data = all_indices_with_site, permutations = 9999, method = "bray")
all_indices_div 

# Make model summary table into a data frame that can be indexed
all_indices_PERMANOVA_results <- broom::tidy(all_indices_div)
all_indices_F_value <- round(all_indices_PERMANOVA_results$statistic[1], 2)
all_indices_p_value <- if_else(all_indices_div$`Pr(>F)`[1] < 0.001, "< 0.001", as.character(round(all_indices_PERMANOVA_results$p.value[1], 3)))

# Model summary table for Supplementary material 
all_indices_PERMANOVA_results %>% 
  # Specify the number of decimal places you'd like in the table
  dplyr::mutate(across(where(is.numeric), ~round(., 3))) %>% 
  # For very small p-value, replace with "<0.001" for ease of reading
  dplyr::mutate(p.value = if_else(p.value == 0.000, "< 0.001", as.character(p.value))) %>% 
  # Rename column headers for table to make them more legible
  dplyr::rename("Term" = "term",
                "pseudo-F" = "statistic",
                "p-value" = "p.value") %>% 
  # Create table 
  flextable()

#### nMDS plot ----

all.nmds <- metaMDS(all_indices, try = 20, trymax = 500)
data.scores <- as.data.frame(scores(all.nmds)) 

# Add core ID and site to data.scores
# This will allow for labeling/colouring on the plot
data.scores$core_ID <- rownames(data.scores)
collection_site <- all_indices_with_site$site
data.scores$site <- collection_site

# Create data frame of species coordinates so they can also be plotted 
nmds.species <- as.data.frame(all.nmds$species)

# Stress value 
all_indices_stress <- all.nmds$stress

nmds_all_indices <- ggplot(data = data.scores) + 
  stat_ellipse(aes(x = NMDS1, y = NMDS2, colour = site),level = 0.50, show.legend = FALSE) +
  geom_point(aes(x = NMDS1, y = NMDS2, colour = site, shape = site), size = 4) +
  # Add stress & PERMANOVA results to the plot 
  geom_text(x = 0.26, y = 0.16, label = paste("stress =", round(all_indices_stress, 2)), color = "black", cex = 5) +
  geom_text(x = 0.22, y = 0.135, label = paste0("F = ", all_indices_F_value, ", p = ", all_indices_p_value), color = "black", cex = 5) +
  theme_bw(base_size = 20) + 
  # Make some white space at the top for the text
  scale_y_continuous(limits = c(-0.15, 0.16)) +
  scale_colour_brewer(palette = "Dark2") +
  theme(panel.grid.major = element_blank(), 
        panel.grid.minor = element_blank(),
        axis.title.y = element_text(vjust = 3),
        axis.title.x = element_text(vjust = -1),
        legend.position = "none") + 
  labs(x = "nMDS1", y = "nMDS2", shape = "Site", colour = "Site")

tiff("figures/nMDS_all_indices.tiff", width = 12, height = 9, units = "in", res = 300)
nmds_all_indices
dev.off()

#### ANOSIM ----

all_indices_dist <- vegdist(all_indices)
attach(all_indices_with_site)
all_indices_ano_test_sites <- anosim(all_indices_dist, site, permutations = 9999)

summary(all_indices_ano_test_sites) 


# All nMDS plots together ----

# First, make a plot with a legend that can be shared by all plots 
plot_for_legend_purposes <- ggplot(data = data.scores) + 
  stat_ellipse(aes(x = NMDS1, y = NMDS2, colour = site),level = 0.50, show.legend = FALSE) +
  geom_point(aes(x = NMDS1, y = NMDS2, colour = site, shape = site), size = 4) +
  # Add stress to the plot 
  geom_text(x = 0.28, y = 0.14, label = "stress = 0.153", color = "black", cex = 5) +
  theme_bw(base_size = 20) + 
  scale_colour_brewer(palette = "Dark2") +
  theme(panel.grid.major = element_blank(), 
        panel.grid.minor = element_blank(),
        axis.title.y = element_text(vjust = 3),
        axis.title.x = element_text(vjust = -1),
        legend.position = c(0.5, 0.5)) + 
  labs(x = "nMDS1", y = "nMDS2", shape = "Site", colour = "Site")

# Extract the legend and add it to the multi-panel plot below 
legend <- cowplot::get_legend(
  # Create some space to the left of the legend
  plot_for_legend_purposes + theme(legend.box.margin = margin(0, 0, 0, 12))
)

# Save plots contrasting 4 taxonomic diversity indices and 3 functional diversity indices between the 2 sites
tiff("figures/nmds_plots_all_indices.tiff", width = 12, height = 9, units = "in", res = 300)
cowplot::plot_grid(nmds_TD_indices, nmds_FD_indices, nmds_all_indices, legend,
                   labels = LETTERS[1:3],
                   align = "v", axis = "l",
                   ncol = 2)
dev.off()



# Figure 3: nMDS of taxonomic composition, TD indices, and FD indices 

# Read in nMDS plot based on taxon composition from earlier script (004-taxonomic-data-analysis.R)
nmds_sp_composition <- read_rds("data/processed/nmds_plot_binned_composition.rds")

top_plot <- cowplot::plot_grid(nmds_sp_composition, labels = c("A"), label_size = 18)

# Stitch together bottom two panels (Figure 3b and 3c)
bottom_plots <- cowplot::plot_grid(nmds_TD_indices, nmds_FD_indices,
                                  labels = c("B", "C"), 
                                  label_size = 18,
                                  align = "h", axis = "l")

# Join all into a single figure 
tiff("figures/nmds_plots_composition_TD_FD.tiff", width = 12, height = 12, units = "in", res = 300)
cowplot::plot_grid(top_plot, bottom_plots,
                   align = "h", axis = "t",
                   nrow = 2,
                   rel_heights = c(1.75, 1))
dev.off()


#### END ####