## Community Weighted Means (CWM)
## By: Mary Clinton
## Date created: February 24, 2023
## Date last modified: June 2, 2023

# Load libraries
library(tidyverse)    # Data wrangling/cleaning
library(car)          # Levene's test for homogeneity of variance 
library(nlme)         # GLS models 
library(FD)           # Calculate CWMs (functcomp function)
  
# Load data
CWM_traits <- read.csv("data/raw/Functional_Traits_All_Macrofauna_All_Sites.csv")
abundances <- read.csv("data/processed/abundances_by_core.csv")  # All taxa (n = 77)
abund_by_DL <- read.csv("data/processed/abundances_by_depthlayer.csv", header = TRUE)


# Prep data ----
# Abundance data frames: 

# Remove extra column called X
abundances <- abundances %>%
  dplyr::select(core_id, sort(colnames(abundances)[-c(1, 2)])) 

# Make core_id the row names for each matrix, then remove the column core_id
rownames(abundances) <- abundances$core_id
abundances <- abundances %>%
  dplyr::select(-core_id)


# Traits data frame:
# Add . between genus & species names, to match abundances data frame
CWM_traits <- CWM_traits %>% 
  mutate(taxon = str_replace_all(taxon, " ", ".") %>% 
           str_remove_all(., "[.]$")) %>% 
  # Rename Eteone lactea to Hypereteone lactea (to match most up-to-date taxonomic classification)
  mutate(taxon = ifelse(taxon == "Eteone.lactea", "Hypereteone.lactea", taxon)) %>% 
  # And finally re-order so that taxa are alphabetical
  arrange(., taxon)

# Make taxon column the rowname and remove taxon column so you're left with just a trait table
rownames(CWM_traits) <- CWM_traits$taxon
CWM_traits <- CWM_traits %>%
  dplyr::select(-taxon)

# Reorder data frame so that species names are in alphabetical order 
CWM_traits <- CWM_traits[order(row.names(CWM_traits)), ]

# Log transform body size trait and re-scale it between 0 and 1 so it doesn't have a disproportionate impact on Gower distance
scale_0_1 <- function(x){
  (x-min(x)) / (max(x) - min(x))
}

CWM_traits$log_body_size <- log(CWM_traits$body_size)
CWM_traits$log_body_size_scaled <- scale_0_1(CWM_traits$log_body_size)
CWM_traits <- CWM_traits %>%
  dplyr::select(-body_size, - log_body_size)


# Compute CWM ----

#### By core ----

# Calculate CWMs for each core
abundances <- as.matrix(abundances)
CWM_by_core <- functcomp(CWM_traits, abundances, CWM.type = "all")

# Re-add core_id and site as columns
CWM_by_core <- CWM_by_core %>% 
  mutate(core_id = rownames(CWM_by_core),
         site = str_sub(rownames(CWM_by_core), 1, 2)) %>% 
  # Rename AC (Alien Cove) to NS (Newman Sound)
  mutate(site = case_when(
    site == "AC" ~ "NS",
    site == "NH" ~ "NH",
    site == "SP" ~ "SP"))

write.csv(CWM_by_core, "data/processed/CWM_by_core.csv")

#### By depth layer ----

# Create separate data frames for top (0-2cm) and bottom (2-10cm) depth layers 
abund_by_DL_top <- abund_by_DL %>% 
  # Remove columns "sample_number" and "X"
  select(-sample_number, -X) %>% 
  # Include only rows for 0-2cm depth layers
  filter(depth_layer == "0-2")

# Sum 2-5 and 5-10cm depth layers for each core to create a 2-10 cm dataset
abund_by_DL_bottom <- abund_by_DL %>% 
  # Remove columns "sample_number" and "X"
  select(-sample_number, -X) %>% 
  # Remove all rows for 0-2cm depth layers
  filter(depth_layer != "0-2") %>% 
  # Add 2-5cm and 5-10cm layers together
  group_by(core_id) %>% 
  dplyr::summarise(across(.cols = where(is.numeric), sum))
abund_by_DL_bottom <- as.data.frame(abund_by_DL_bottom)

# Set core_ID as row names 
rownames(abund_by_DL_top) <- abund_by_DL_top$core_id
rownames(abund_by_DL_bottom) <- abund_by_DL_bottom$core_id

# Remove unneeded columns 
abund_by_DL_top <- abund_by_DL_top %>% 
  select(-core_id, -depth_layer)
abund_by_DL_bottom <- abund_by_DL_bottom %>% 
  select(-core_id)

# Order columns (taxa) alphabetically
abund_by_DL_top <- abund_by_DL_top %>% 
  select(order(colnames(.)))
abund_by_DL_bottom <- abund_by_DL_bottom %>% 
  select(order(colnames(.)))

# Make data frames into matrices so that CWM can be calculated
abund_by_DL_top_matrix <- as.matrix(abund_by_DL_top)
abund_by_DL_bottom_matrix <- as.matrix(abund_by_DL_bottom)

# Calculate CWMs 
CWM_by_DL_top <- functcomp(CWM_traits, abund_by_DL_top_matrix, CWM.type = "all")
CWM_by_DL_bottom <- functcomp(CWM_traits, abund_by_DL_bottom_matrix, CWM.type = "all")

# Re-add columns for core ID and depth layer
CWM_by_DL_top <- CWM_by_DL_top %>% 
  mutate(core_id = rownames(CWM_by_DL_top),
         depth_layer = "0-2")
CWM_by_DL_bottom <- CWM_by_DL_bottom %>% 
  mutate(core_id = rownames(CWM_by_DL_bottom),
         depth_layer = "2-10")

# Join all CWMs (for both DLs) into a single data frame and save it as a CSV
CWM_by_DL_all <- CWM_by_DL_top %>% 
  full_join(CWM_by_DL_bottom) %>% 
  # Add a column for site to make plotting easier later
  mutate(site = str_sub(core_id, 1, 2)) %>% 
  mutate(site = case_when(
    site == "AC" ~ "Newman Sound",
    site == "NH" ~ "Neddie's Harbour",
    site == "SP" ~ "St. Paul's"),
    depth_layer = case_when(
      depth_layer == "0-2" ~ "0-2cm",
      depth_layer == "2-10" ~ "2-10cm"
    ))

write.csv(CWM_by_DL_all, "data/processed/CWM_by_depth_layer.csv")


# Compare CWM between depth layers ----

CWM_DL_comparisons <- CWM_by_DL_all %>% 
  pivot_longer(where(is.numeric), names_to = "index", values_to = "value") %>%
  mutate(depth_layer = str_remove(depth_layer, "cm")) %>% 
  pivot_wider(names_from = depth_layer, values_from = value) 

# Wilcoxon Rank Sign Test  ----
# This is like t-test but non-parametric because not all indices are normally distributed
df_w <- map(unique(CWM_DL_comparisons$site), function(site) {
  df <- CWM_DL_comparisons %>% 
    filter(site == {{ site }})
  
  map(unique(df$index), function(index) {
    df2 <- df %>% 
      filter(index == {{ index }})
    
    broom::tidy(wilcox.test(df2$`0-2`, df2$`2-10`))
    
  }) %>% 
    set_names(nm = unique(df$index)) %>% 
    bind_rows(.id = "index")
  
}) %>% 
  set_names(nm = unique(CWM_DL_comparisons$site)) %>% 
  bind_rows(.id = "site")

# Format table that includes p-values and test statistic outputs for each DL pair 
wilcoxon_all_CWM <- df_w %>% 
  select(site, index, statistic, p.value) %>% 
  pivot_wider(names_from = site, values_from = c(statistic, p.value)) %>% 
  mutate(across(where(is.numeric), ~ round(., 4))) %>% 
  select(index, contains("Neddie's Harbour"), contains("Newman Sound"), contains("St. Paul's"))

flextable(wilcoxon_all_CWM) %>% 
  add_header_row(top = TRUE,
                 values = c("", "Neddie's Harbour", "Newman Sound", "St. Paul's"),
                 colwidths = c(1, 2, 2, 2))

# Test for differences between sites ----
#### By core ----

# Add a column for site 
CWM_by_core <- CWM_by_core %>% 
  mutate(site = str_sub(rownames(CWM_by_core), 1, 2)) %>% 
  mutate(site = case_when(
    site == "AC" ~ "NS",
    site == "NH" ~ "NH",
    site == "SP" ~ "SP"))

## Body size
# First test for equality of variances between the three sites
bodysize_var <- leveneTest(log_body_size_scaled ~ site, CWM_by_core)
bodysize_var  

# Now run GLS of the trait against site 
bodysize_fit <- gls(log_body_size_scaled ~ site, weights = varIdent(form = ~ 1 | site), data = CWM_by_core)
summary(bodysize_fit)  

## Diet (Carnivore)
carnivore_var <- leveneTest(diet_C ~ site, CWM_by_core)
carnivore_var 

carnivore_fit <- gls(diet_C ~ site, weights = varIdent(form = ~ 1 | site), data = CWM_by_core)
summary(carnivore_fit)  

## Diet (Detritivore) 
detritivore_var <- leveneTest(diet_Dt ~ site, CWM_by_core)
detritivore_var  

detritivore_fit <- gls(diet_Dt ~ site, data = CWM_by_core)
summary(detritivore_fit) 

## Diet (Herbivore)
herbivore_var <- leveneTest(diet_Hb ~ site, CWM_by_core)
herbivore_var  # p = 0.4 

herbivore_fit <- gls(diet_Hb ~ site, data = CWM_by_core)
summary(herbivore_fit) 

## Feeding guild (Suspension feeder) 
suspension_var <- leveneTest(feeding_guild_Ff ~ site, CWM_by_core)
suspension_var  

suspension_fit <- gls(feeding_guild_Ff ~ site, weights = varIdent(form = ~ 1 | site), data = CWM_by_core)
summary(suspension_fit)  

## Feeding guild (Grazer)
grazer_var <- leveneTest(feeding_guild_Gr ~ site, CWM_by_core)
grazer_var  

grazer_fit <- gls(feeding_guild_Gr ~ site, data = CWM_by_core)
summary(grazer_fit)  

## Feeding guild (Predator)
predator_var <- leveneTest(feeding_guild_Pr ~ site, CWM_by_core)
predator_var 

predator_fit <- gls(feeding_guild_Pr ~ site, weights = varIdent(form = ~ 1 | site), data = CWM_by_core)
summary(predator_fit) 

## Feeding guild (Scavenger) 
scavenger_var <- leveneTest(feeding_guild_Sc ~ site, CWM_by_core)
scavenger_var 

scavenger_fit <- gls(feeding_guild_Sc ~ site, data = CWM_by_core)
summary(scavenger_fit)  

## Feeding guild (SD feeder) 
SD_var <- leveneTest(feeding_guild_SD ~ site, CWM_by_core)
SD_var 

SD_fit <- gls(feeding_guild_SD ~ site, weights = varIdent(form = ~ 1 | site), data = CWM_by_core)
summary(SD_fit)  

## Feeding guild (SSD feeder) 
SSD_var <- leveneTest(feeding_guild_SSD ~ site, CWM_by_core)
SSD_var  

SSD_fit <- gls(feeding_guild_SSD ~ site, weights = varIdent(form = ~ 1 | site), data = CWM_by_core)
summary(SSD_fit)  

## Mobility 
mobility_var <- leveneTest(mobility ~ site, CWM_by_core)
mobility_var  

mobility_fit <- gls(mobility ~ site, weights = varIdent(form = ~ 1 | site), data = CWM_by_core)
summary(mobility_fit) 

## Reworking (biodiffusor) 
biodiffusor_var <- leveneTest(reworking_bd ~ site, CWM_by_core)
biodiffusor_var 

biodiffusor_fit <- gls(reworking_bd ~ site, weights = varIdent(form = ~ 1 | site), data = CWM_by_core)
summary(biodiffusor_fit) 

## Reworking (surficial modifier) 
SM_var <- leveneTest(reworking_sm ~ site, CWM_by_core)
SM_var  

SM_fit <- gls(reworking_sm ~ site, data = CWM_by_core)
summary(SM_fit)

## Reworking (updown) 
updown_var <- leveneTest(reworking_updown ~ site, CWM_by_core)
updown_var 

updown_fit <- gls(reworking_updown ~ site, weights = varIdent(form = ~ 1 | site), data = CWM_by_core)
summary(updown_fit) 


#### By depth layer ----

# Model each trait against site to test for significant differences (0-2cm) 

CWM_by_DL_top <- CWM_by_DL_top %>% 
  mutate(site = str_sub(rownames(CWM_by_DL_top), 1, 2))

## Body size
# First test for equality of variances between the two sites
bodysize_var <- leveneTest(log_body_size_scaled ~ site, CWM_by_DL_top)
bodysize_var 

# Now run GLS of the trait against site 
bodysize_fit <- gls(log_body_size_scaled ~ site, weights = varIdent(form = ~ 1 | site), data = CWM_by_DL_top)
summary(bodysize_fit) 

## Diet (Carnivore)
carnivore_var <- leveneTest(diet_C ~ site, CWM_by_DL_top)
carnivore_var  

carnivore_fit <- gls(diet_C ~ site, weights = varIdent(form = ~ 1 | site), data = CWM_by_DL_top)
summary(carnivore_fit) 

## Diet (Detritivore) 
detritivore_var <- leveneTest(diet_Dt ~ site, CWM_by_DL_top)
detritivore_var  

detritivore_fit <- gls(diet_Dt ~ site, data = CWM_by_DL_top)
summary(detritivore_fit) 

## Diet (Herbivore)
herbivore_var <- leveneTest(diet_Hb ~ site, CWM_by_DL_top)
herbivore_var 

herbivore_fit <- gls(diet_Hb ~ site, data = CWM_by_DL_top)
summary(herbivore_fit) 

## Feeding guild (Suspension feeder) 
suspension_var <- leveneTest(feeding_guild_Ff ~ site, CWM_by_DL_top)
suspension_var  

suspension_fit <- gls(feeding_guild_Ff ~ site, weights = varIdent(form = ~ 1 | site), data = CWM_by_DL_top)
summary(suspension_fit) 

## Feeding guild (Grazer)
grazer_var <- leveneTest(feeding_guild_Gr ~ site, CWM_by_DL_top)
grazer_var  

grazer_fit <- gls(feeding_guild_Gr ~ site, data = CWM_by_DL_top)
summary(grazer_fit)  

## Feeding guild (Predator)
predator_var <- leveneTest(feeding_guild_Pr ~ site, CWM_by_DL_top)
predator_var 

predator_fit <- gls(feeding_guild_Pr ~ site, weights = varIdent(form = ~ 1 | site), data = CWM_by_DL_top)
summary(predator_fit)  

## Feeding guild (Scavenger) 
scavenger_var <- leveneTest(feeding_guild_Sc ~ site, CWM_by_DL_top)
scavenger_var 

scavenger_fit <- gls(feeding_guild_Sc ~ site, data = CWM_by_DL_top)
summary(scavenger_fit)  

## Feeding guild (SD feeder) 
SD_var <- leveneTest(feeding_guild_SD ~ site, CWM_by_DL_top)
SD_var 

SD_fit <- gls(feeding_guild_SD ~ site, weights = varIdent(form = ~ 1 | site), data = CWM_by_DL_top)
summary(SD_fit)  

## Feeding guild (SSD feeder) 
SSD_var <- leveneTest(feeding_guild_SSD ~ site, CWM_by_DL_top)
SSD_var 

SSD_fit <- gls(feeding_guild_SSD ~ site, weights = varIdent(form = ~ 1 | site), data = CWM_by_DL_top)
summary(SSD_fit) 

## Mobility 
mobility_var <- leveneTest(mobility ~ site, CWM_by_DL_top)
mobility_var 

mobility_fit <- gls(mobility ~ site, weights = varIdent(form = ~ 1 | site), data = CWM_by_DL_top)
summary(mobility_fit)  

## Reworking (biodiffusor) 
biodiffusor_var <- leveneTest(reworking_bd ~ site, CWM_by_DL_top)
biodiffusor_var 

biodiffusor_fit <- gls(reworking_bd ~ site, weights = varIdent(form = ~ 1 | site), data = CWM_by_DL_top)
summary(biodiffusor_fit) 

## Reworking (epipelagic) 
epi_var <- leveneTest(reworking_epi ~ site, CWM_by_DL_top)
epi_var 

epi_fit <- gls(reworking_epi ~ site, data = CWM_by_DL_top)
summary(epi_fit)  

## Reworking (surficial modifier) 
SM_var <- leveneTest(reworking_sm ~ site, CWM_by_DL_top)
SM_var  

SM_fit <- gls(reworking_sm ~ site, weights = varIdent(form = ~ 1 | site), data = CWM_by_DL_top)
summary(SM_fit)  

## Reworking (updown) 
updown_var <- leveneTest(reworking_updown ~ site, CWM_by_DL_top)
updown_var 

updown_fit <- gls(reworking_updown ~ site, weights = varIdent(form = ~ 1 | site), data = CWM_by_DL_top)
summary(updown_fit)  

# Now repeat for 2-10cm depth layer
# Model each trait against site to test for significant differences (2-10 cm)

CWM_by_DL_bottom <- CWM_by_DL_bottom %>% 
  mutate(site = str_sub(rownames(CWM_by_DL_bottom), 1, 2))

## Body size
# First test for equality of variances between the two sites
bodysize_var <- leveneTest(log_body_size_scaled ~ site, CWM_by_DL_bottom)
bodysize_var  

# Now run GLS of the trait against site 
bodysize_fit <- gls(log_body_size_scaled ~ site, varIdent(form = ~1 | site), data = CWM_by_DL_bottom)
summary(bodysize_fit) 

## Diet (Carnivore)
carnivore_var <- leveneTest(diet_C ~ site, CWM_by_DL_bottom)
carnivore_var

carnivore_fit <- gls(diet_C ~ site, varIdent(form = ~1 | site), data = CWM_by_DL_bottom)
summary(carnivore_fit) 

## Diet (Detritivore) 
detritivore_var <- leveneTest(diet_Dt ~ site, CWM_by_DL_bottom)
detritivore_var 

detritivore_fit <- gls(diet_Dt ~ site, weights = varIdent(form = ~ 1 | site), data = CWM_by_DL_bottom)
summary(detritivore_fit)  

## Diet (Herbivore)
herbivore_var <- leveneTest(diet_Hb ~ site, CWM_by_DL_bottom)
herbivore_var  

herbivore_fit <- gls(diet_Hb ~ site, data = CWM_by_DL_bottom)
summary(herbivore_fit)  

## Feeding guild (Suspension feeder) 
suspension_var <- leveneTest(feeding_guild_Ff ~ site, CWM_by_DL_bottom)
suspension_var  

suspension_fit <- gls(feeding_guild_Ff ~ site, data = CWM_by_DL_bottom)
summary(suspension_fit)  

## Feeding guild (Grazer)
grazer_var <- leveneTest(feeding_guild_Gr ~ site, CWM_by_DL_bottom)
grazer_var  

grazer_fit <- gls(feeding_guild_Gr ~ site, data = CWM_by_DL_bottom)
summary(grazer_fit) 

## Feeding guild (Predator)
predator_var <- leveneTest(feeding_guild_Pr ~ site, CWM_by_DL_bottom)
predator_var 

predator_fit <- gls(feeding_guild_Pr ~ site, data = CWM_by_DL_bottom)
summary(predator_fit)  

## Feeding guild (Scavenger) 
scavenger_var <- leveneTest(feeding_guild_Sc ~ site, CWM_by_DL_bottom)
scavenger_var  

scavenger_fit <- gls(feeding_guild_Sc ~ site, data = CWM_by_DL_bottom)
summary(scavenger_fit) 

## Feeding guild (SD feeder) 
SD_var <- leveneTest(feeding_guild_SD ~ site, CWM_by_DL_bottom)
SD_var  

SD_fit <- gls(feeding_guild_SD ~ site, weights = varIdent(form = ~ 1 | site), data = CWM_by_DL_bottom)
summary(SD_fit)  

## Feeding guild (SSD feeder) 
SSD_var <- leveneTest(feeding_guild_SSD ~ site, CWM_by_DL_bottom)
SSD_var 

SSD_fit <- gls(feeding_guild_SSD ~ site, weights = varIdent(form = ~ 1 | site), data = CWM_by_DL_bottom)
summary(SSD_fit)  

## Mobility 
mobility_var <- leveneTest(mobility ~ site, CWM_by_DL_bottom)
mobility_var 

mobility_fit <- gls(mobility ~ site, weights = varIdent(form = ~ 1 | site), data = CWM_by_DL_bottom)
summary(mobility_fit) 

## Reworking (biodiffusor) 
biodiffusor_var <- leveneTest(reworking_bd ~ site, CWM_by_DL_bottom)
biodiffusor_var  

biodiffusor_fit <- gls(reworking_bd ~ site, data = CWM_by_DL_bottom)
summary(biodiffusor_fit)  

## Reworking (epipelagic) 
epi_var <- leveneTest(reworking_epi ~ site, CWM_by_DL_bottom)
epi_var  

epi_fit <- gls(reworking_epi ~ site, data = CWM_by_DL_bottom)
summary(epi_fit)  

## Reworking (surficial modifier) 
SM_var <- leveneTest(reworking_sm ~ site, CWM_by_DL_bottom)
SM_var 

SM_fit <- gls(reworking_sm ~ site, data = CWM_by_DL_bottom)
summary(SM_fit)  

## Reworking (updown) 
updown_var <- leveneTest(reworking_updown ~ site, CWM_by_DL_bottom)
updown_var 

updown_fit <- gls(reworking_updown ~ site, weights = varIdent(form = ~ 1 | site), data = CWM_by_DL_bottom)
summary(updown_fit)  



# Plot CWM ----

# Function to calculate standard error 
se <- function(x) sd(x) / sqrt(length(x))

#### By core ----

CWM_values <- gather(CWM_by_core, key = "trait", value = "CWM", 
               diet_Hb:log_body_size_scaled) %>%
  # Calculate mean values for each trait, and standard errors (SE)
  group_by(site, trait) %>% 
  dplyr::summarise(mean_CWM = mean(CWM),
            se_CWM = se(CWM)) %>% 
  # Specify the number of decimal places you'd like in the table
  mutate(across(where(is.numeric), ~round(., 3))) %>% 
  # Rename column headers for table to make them more legible
  dplyr::rename("Site" = "site",
         "Trait" = "trait",
         "CWM" = "mean_CWM",
         "SE" = "se_CWM") %>% 
  # Create table 
  flextable()

tiff("figures/CWM_with_SE.tiff", width = 14, height = 9, units = "in", res = 300)
# Convert to long format and calculate mean and SD for each site/trait category combination 
gather(CWM_by_core, key = "trait", value = "CWM", 
       diet_Hb:log_body_size_scaled) %>%
  # Calculate mean values for each trait, and standard errors (SE)
  group_by(site, trait) %>% 
  dplyr::summarise(mean_CWM = mean(CWM),
            se_CWM = se(CWM)) %>% 
  # Add back column for trait category
  dplyr::mutate(trait_category = case_when(
    str_detect(trait, "diet") ~ "Diet",
    str_detect(trait, "feeding") ~ "Feeding guild",
    str_detect(trait, "body_size") ~ "Body size",
    str_detect(trait, "mobility") ~ "Mobility",
    str_detect(trait, "reworking") ~ "Sediment reworking"
  )) %>% 
  # Plot it!
  ggplot(aes(x = trait, y = mean_CWM, fill = site)) +
  geom_bar(stat = "identity", position = "dodge") + 
  # Make error bars display mean +/- standard error
  geom_errorbar(aes(x = trait, y = mean_CWM, group = site, ymin = mean_CWM - se_CWM, ymax = mean_CWM + se_CWM), 
                position = position_dodge(width = 0.9), width = 0.2) +
  facet_grid(~trait_category, scales = "free", space = "free") + 
  theme_bw(base_size = 18) +
  theme(panel.grid.major = element_blank(), 
        panel.grid.minor = element_blank(),
        axis.title.y = element_text(vjust = 3, size = 18),
        axis.title.x = element_text(vjust = -1, size = 18),
        axis.text.x = element_text(angle = 45, hjust = 1, size = 16),
        legend.position = c(0.8, 0.85)) + 
  scale_y_continuous(expand = c(0, 0, 0, 0.1)) + #so that bars don't float above x-axis + 
  # Change x-axis labels to be more understandable
  scale_x_discrete(labels = c("log_body_size_scaled" = "", 
                              "diet_C" = "Carnivore",
                              "diet_Dt" = "Detritivore",
                              "diet_Hb" = "Herbivore",
                              "feeding_guild_Ff" = "Suspension feeder",
                              "feeding_guild_Gr" = "Grazer",
                              "feeding_guild_Pr" = "Predator",
                              "feeding_guild_Sc" = "Scavenger",
                              "feeding_guild_SD" = "Surface\ndeposit feeder",
                              "feeding_guild_SSD" = "Sub-surface\ndeposit feeder",
                              "mobility" = "",
                              "reworking_epi" = "None",
                              "reworking_bd" = "Biodiffusor",
                              "reworking_sm" = "Surficial modifier",
                              "reworking_updown" = "Up/down conveyor")) + 
  scale_fill_brewer(palette = "Dark2") + 
  labs(x = "Trait modalities", y = "CWM", fill = "Site")
dev.off()


#### By depth layer ----
# 0-2cm on top, 2-10cm on bottom

CWM_values_by_DL <- gather(CWM_by_DL_all, key = "trait", value = "CWM", 
                           diet_Hb:log_body_size_scaled) %>%
  # Calculate mean values for each trait, and standard errors (SE)
  group_by(depth_layer, site, trait) %>% 
  dplyr::summarise(mean_CWM = mean(CWM),
            se_CWM = se(CWM))  %>% 
  # Specify the number of decimal places you'd like in the table
  dplyr::mutate(across(where(is.numeric), ~round(., 3))) %>% 
  # Rename column headers for table to make them more legible
  dplyr::rename("Depth layer" = "depth_layer",
         "Site" = "site",
         "Trait" = "trait",
         "CWM" = "mean_CWM",
         "SE" = "se_CWM") %>% 
  # Create table 
  flextable()

tiff("figures/CWM_two_depth_layers.tiff", width = 14, height = 9, units = "in", res = 300)
gather(CWM_by_DL_all, key = "trait", value = "CWM", 
       diet_Hb:log_body_size_scaled) %>%
  # Calculate mean values for each trait, and standard errors (SE)
  group_by(depth_layer, site, trait) %>% 
  dplyr::summarise(mean_CWM = mean(CWM),
            se_CWM = se(CWM)) %>% 
  # Add back column for trait category
  dplyr::mutate(trait_category = case_when(
    str_detect(trait, "diet") ~ "Diet",
    str_detect(trait, "feeding") ~ "Feeding guild",
    str_detect(trait, "body_size") ~ "Body size",
    str_detect(trait, "mobility") ~ "Mobility",
    str_detect(trait, "reworking") ~ "Sediment reworking"
  )) %>% 
  # Plot it!
  ggplot(aes(x = trait, y = mean_CWM, fill = site)) +
  geom_bar(stat = "identity", position = "dodge") + 
  # Make error bars display mean +/- standard error
  geom_errorbar(aes(x = trait, y = mean_CWM, group = site, ymin = mean_CWM - se_CWM, ymax = mean_CWM + se_CWM), 
                position = position_dodge(width = 0.9), width = 0.2) +
  facet_grid(depth_layer ~ trait_category, scales = "free_x", space = "free") + 
  theme_bw(base_size = 18) +
  theme(panel.grid.major = element_blank(), 
        panel.grid.minor = element_blank(),
        axis.title.y = element_text(vjust = 3, size = 18),
        axis.title.x = element_text(vjust = -1, size = 18),
        axis.text.x = element_text(angle = 45, hjust = 1, size = 16),
        legend.position = "none") + 
  scale_y_continuous(expand = c(0, 0, 0, 0.1)) + #so that bars don't float above x-axis
  # Change x-axis labels to be more understandable
  scale_x_discrete(labels = c("log_body_size_scaled" = "", 
                              "diet_C" = "Carnivore",
                              "diet_Dt" = "Detritivore",
                              "diet_Hb" = "Herbivore",
                              "feeding_guild_Ff" = "Suspension feeder",
                              "feeding_guild_Gr" = "Grazer",
                              "feeding_guild_Pr" = "Predator",
                              "feeding_guild_Sc" = "Scavenger",
                              "feeding_guild_SD" = "Surface\ndeposit feeder",
                              "feeding_guild_SSD" = "Sub-surface\ndeposit feeder",
                              "mobility" = "",
                              "reworking_bd" = "Biodiffusor",
                              "reworking_epi" = "None",
                              "reworking_sm" = "Surficial modifier",
                              "reworking_updown" = "Up/down conveyor")) +
  scale_fill_brewer(palette = "Dark2") + 
  labs(x = "Trait modalities", y = "CWM", fill = "Site")
dev.off()


# CWM - NOT abundance-weighted ----

# Compute values for each core, using a presence/absence data frame (i.e. abundances of taxa are not relevant)
pres_abs <- abundances 
pres_abs[pres_abs != 0] <- 1
pres_abs <- as.matrix(pres_abs)

# Calculate non-abundance weighted CWMs
cores_CWM_not_AbundWeighted <- functcomp(CWM_traits, pres_abs, CWM.type = "all")

# Re-add core_id and site as columns
cores_CWM_not_AbundWeighted <- cores_CWM_not_AbundWeighted %>% 
  mutate(core_id = rownames(cores_CWM_not_AbundWeighted),
         site = str_sub(rownames(cores_CWM_not_AbundWeighted), 1, 2)) %>% 
  # Rename AC (Alien Cove) to NS (Newman Sound)
  mutate(site = case_when(
    site == "AC" ~ "NS",
    site == "NH" ~ "NH",
    site == "SP" ~ "SP"))

write.csv(cores_CWM_not_AbundWeighted, "data/processed/CWM_by_core_not_abund_weighted.csv")


# Shows the average value for a SPECIES/TAXA drawn at random from the community
# All depth layers are pooled here
tiff("figures/CWM_not_weighted.tiff", width = 12, height = 9, units = "in", res = 300)

gather(cores_CWM_not_AbundWeighted, key = "trait", value = "CWM", 
       diet_Hb:log_body_size_scaled) %>%
  mutate(trait_category = c(rep("diet", 9*30), rep("feeding_guild", 18*30), rep("reworking", 12*30), 
                            rep("mobility", 3*30), rep("body_size", 3*30))) %>% 
  ggplot(aes(x = trait, y = CWM, fill = site)) +
  geom_bar(stat = "identity", position = "dodge") + 
  facet_wrap(~trait_category, scales = "free") + 
  theme_bw() +
  theme(panel.grid.major = element_blank(), panel.grid.minor = element_blank(), axis.text.x = element_text(angle = 45, hjust = 1)) + 
  scale_fill_brewer(palette = "Dark2") + 
  # Change x-axis labels to be more understandable
  scale_x_discrete(labels = c("log_body_size_scaled" = "", 
                              "diet_C" = "Carnivore",
                              "diet_Dt" = "Detritivore",
                              "diet_Hb" = "Herbivore",
                              "feeding_guild_Ff" = "Suspension feeder",
                              "feeding_guild_Gr" = "Grazer",
                              "feeding_guild_Pr" = "Predator",
                              "feeding_guild_Sc" = "Scavenger",
                              "feeding_guild_SD" = "Surface\ndeposit feeder",
                              "feeding_guild_SSD" = "Sub-surface\ndeposit feeder",
                              "mobility" = "",
                              "reworking_bd" = "Biodiffusor",
                              "reworking_epi" = "None",
                              "reworking_sm" = "Surficial modifier",
                              "reworking_updown" = "Up/down conveyor")) + 
  # So that bars don't float above x-axis: 
  scale_y_continuous(expand = c(0, 0, 0, 0.1))

dev.off()

#### END ####