## Correlations between diversity indices
## By: Mary Clinton
## Date created: February 12, 2023 
## Date last modified: June 2, 2023 

# Load libraries
library(tidyverse)    # Data wrangling/cleaning
library(ggplot2)      # Generating plots
library(corrplot)     # Correlation plots

# Load data (these indices were calculated with binned taxa)
FD_indices <- read.csv("data/processed/FD_indices.csv")
TD_indices <- read.csv("data/processed/TD_indices.csv")


# Join into one dataframe
FD_indices <- FD_indices %>% 
  dplyr::rename(core_id = X)

all_indices <- FD_indices %>% 
  left_join(TD_indices) %>% 
  select(core_id, FRic, FEve, FDiv, shannon:pielous_evenness)

rownames(all_indices) <- all_indices$core_id
all_indices <- all_indices %>% 
  select(-core_id) %>% 
  dplyr::rename("Shannon" = shannon,
         "Simpson" = simpson,
         "Richness" = richness,
         "Pielou's" = pielous_evenness)


# Data exploration ----
pairs(all_indices)

# Another way to visualize correlations:

panel.cor <- function(x, y, digits = 2, prefix = "", cex.cor, ...){
  usr <- par("usr"); on.exit(par(usr))
  par(usr = c(0, 1, 0, 1))
  r <- abs(cor(x, y, use = "pairwise"))
  txt <- format(c(r, 0.123), digits = digits)[1]
  txt <- paste0(prefix, txt)
  if(missing(cex.cor)) cex.cor <- 2.5
  text(0.5, 0.5, txt, cex = cex.cor)
}

panel.hist <- function(x, ...){
  usr <- par("usr"); on.exit(par(usr))
  par(usr = c(usr[1:2], 0, 1.5) )
  h <- hist(x, plot = FALSE)
  breaks <- h$breaks; nB <- length(breaks)
  y <- h$counts; y <- y/max(y)
  rect(breaks[-nB], 0, breaks[-1], y, 
       col = "lightgrey", ...)
}

# Save figure showing scatter plots & distributions of each diversity index pair
tiff("figures/scatterplots_diversity_indices.tiff", width = 12, height = 9, units = "in", res = 300)
pairs(all_indices, upper.panel = panel.cor, diag.panel = panel.hist, panel = panel.smooth)
dev.off()



# Correlation plot ----

# Calculate correlation coefficients 
correlations <- cor(all_indices)

# Set the colour palette 
col <- colorRampPalette(c("#BB4444", "#EE9988", "#FFFFFF", "#77AADD", "#4477AA"))

# Make correlation plot
tiff("figures/correlation_plot_diversity_indices.tiff", width = 12, height = 9, units = "in", res = 300)
corrplot(correlations, method = "color", type = "upper", col = col(200),   
         # Add correlation coefficient 
         addCoef.col = "black", 
         # Change text colour & rotation angle of labels
         tl.col = "black", tl.srt = 45, 
         # Change font sizes
         number.cex = 2, tl.cex = 1.3, cl.cex = 1.3,
         # Hide correlation coefficient on the principal diagonal 
         diag = FALSE
         )
dev.off()

#### END ####