## Taxonomic and functional distribution by depth layer
## By: Mary Clinton
## Date created: March 27, 2022
## Date last modified:  January 6, 2024

# Load libraries
library(tidyverse)    # Data wrangling/cleaning
library(car)          # Levene's tests
library(nlme)         # GLS models 
library(rstatix)      # Kruskal-Wallis test for Simpson's index
library(vegan)        # Calculating TD indices
library(lme4)         # Linear mixed effects models 
library(pbkrtest)     # Calculating p-values for linear mixed effects models
library(effects)      # Display model results 
library(flextable)    # Create tables that can be copied directly to word documents 
library(broom.mixed)  # Broom for mixed effects models 
library(DHARMa)       # Model diagnostics & model fitting
library(ggeffects)    # Effects plots for models with multiple predictors 
library(glmmTMB)      # Beta mixed effects models 
library(conflicted)   # Allows you to specify which package gets precedence in the case of conflicts (e.g. WoRMS vs. dplyr)

# Resolve package conflicts 
mutate <- dplyr::mutate
select <- dplyr::select
filter <- dplyr::filter
summarise <- dplyr::summarise
rename <- dplyr::rename

# Load functions
source("code/src/remove-outliers-function.R")   # Remove outliers from data frames 
source("code/src/from_villeger/multidimFD.R")   # Calculate FD indices 
source("code/src/boot-resample.R")              # Randomly sample cores from within a site
source("code/src/pub-ready-effects-plots.R")    # Creates publication-ready plots from output of effects package

# Set theme for plots 
theme_MEC <- function () { 
  theme_bw(base_size = 12) + 
    theme(panel.grid.major = element_blank(), panel.grid.minor = element_blank(), 
          axis.line = element_line(colour = "black"), 
          axis.text = element_text(size = 16, face = "plain"), 
          axis.title = element_text(size = 18, face = "plain"),
          legend.text = element_text(size = 16, face = "plain"), 
          legend.title = element_text(size = 18, face = "bold"))
} 
theme_set(theme_MEC())

# Load data
by_depth_layer <- read.csv("data/processed/abundances_by_depthlayer.csv", header = TRUE)
by_depth_layer_for_indices <- read.csv("data/processed/abundances_by_depth_layer_for_calculation_of_indices.csv", header = TRUE)
funct_coord <- read.csv("data/processed/functional_space_coordinates_binned_taxa_for_indices_all_sites.csv", header = TRUE) # Coordinate data (PCs for each taxon) 

# Remove unneeded columns, put taxon columns in alphabetical order & add a column for site
by_depth_layer <- by_depth_layer %>%
  select(core_id, depth_layer, sort(colnames(by_depth_layer)[-c(1, 2)])) %>% 
  mutate(site = str_sub(core_id, 1, 2)) %>% 
  mutate(site = case_when(
    site == "AC" ~ "NS",
    site == "NH" ~ "NH",
    site == "SP" ~ "SP"
  ))

by_depth_layer_for_indices <- by_depth_layer_for_indices %>% 
  select(core_id, depth_layer, sort(colnames(by_depth_layer_for_indices)[-c(1, 2)])) %>% 
  mutate(site = str_sub(core_id, 1, 2)) %>% 
  mutate(site = case_when(
    site == "AC" ~ "NS",
    site == "NH" ~ "NH",
    site == "SP" ~ "SP"
  ))

# Calculate total abundances & proportions ----

# Total abundance of macrofauna in each core & depth layer combination 
abundances_per_DL <- by_depth_layer %>% 
  group_by(site, depth_layer, core_id) %>% 
  summarise(across(.cols = where(is.numeric), sum)) %>% 
  rowwise() %>% 
  mutate(total_fauna = sum(across(Alitta.sp:Tellinidae.indet), na.rm = TRUE)) %>% 
  select(site, depth_layer, total_fauna, core_id)

# Determine mean abundance +/- SD for each site/depth layer combination
abundances_mean_sd <- abundances_per_DL %>% 
  group_by(site, depth_layer) %>% 
  summarise(mean_abundance = mean(total_fauna),
            sd = sd(total_fauna))

# Plot mean abundances by depth layer (error bars = standard deviation)
mean_abundance_plot <- ggplot(data = abundances_mean_sd) +
  geom_bar(aes(x = depth_layer, y = mean_abundance, fill = site), stat = "identity", position = position_dodge()) + 
  geom_errorbar(aes(x = depth_layer, y = mean_abundance, group = site, ymin = mean_abundance - sd, ymax = mean_abundance + sd), 
                position = position_dodge(width = 0.9), width = 0.2) +
  theme_bw(base_size = 20) +
  scale_y_continuous(expand = c(-0.011, 0, 0.025, 0.1)) + #so that bars don't float above x-axis
  scale_fill_brewer(palette = "Dark2") + 
  theme(panel.grid.major = element_blank(),  
        panel.grid.minor = element_blank(),
        axis.title.y = element_text(vjust = 3),
        axis.title.x = element_text(vjust = -1),
        legend.position = c(0.9, 0.7)) + 
  labs(x = "", y = "Abundance of fauna", fill = "Site")

# Now for each core, calculate the proportion of fauna in each depth layer
# Start by determining the total number of fauna (across all depth layers) in each core
total_abund_per_core <- abundances_per_DL %>% 
  group_by(core_id, site) %>% 
  summarise(total_fauna_in_core = sum(total_fauna)) 

# Then calculate mean & SD proportions in each site/depth layer combination
proportion_mean_sd <- full_join(total_abund_per_core, abundances_per_DL) %>% 
  mutate(proportion_fauna = total_fauna / total_fauna_in_core) %>% 
  group_by(site, depth_layer) %>% 
  summarise(mean_proportion = mean(proportion_fauna),
            sd = sd(proportion_fauna))

# Plot mean proportions by depth layer (error bars = standard deviation)
mean_proportion_plot <- ggplot(data = proportion_mean_sd) +
  geom_bar(aes(x = depth_layer, y = mean_proportion, fill = site), stat = "identity", position = position_dodge()) + 
  geom_errorbar(aes(x = depth_layer, y = mean_proportion, group = site, ymin = mean_proportion - sd, ymax = mean_proportion + sd), 
                position = position_dodge(width = 0.9), width = 0.2) +
  theme_bw(base_size = 20) +
  scale_y_continuous(expand = c(-0.008, 0, 0, 0.1)) + #so that bars don't float above x-axis
  scale_fill_brewer(palette = "Dark2") + 
  theme(panel.grid.major = element_blank(),  
        panel.grid.minor = element_blank(),
        axis.title.y = element_text(vjust = 3),
        axis.title.x = element_text(vjust = -1),
        legend.position = "none") + 
  labs(x = "", y = "Proportion of fauna", fill = "Site")

# Figure showing both mean abundance (A) and mean proportion (B) of fauna in each depth layer at each site
tiff("figures/mean_abundance_and_proportions_per_depth_layer.tiff", width = 12, height = 9, units = "in", res = 300)
cowplot::plot_grid(mean_abundance_plot, mean_proportion_plot,
                   labels = LETTERS[1:2],
                   align = "v", axis = "l",
                   ncol = 1)
dev.off()


# Get the total abundance for each taxon at each site/depth layer combination
site_DL_totals <- by_depth_layer %>%
  mutate(site = str_sub(core_id, start = 1, end = 2)) %>% 
  group_by(site, depth_layer) %>% 
  summarise(across(.cols = where(is.numeric), sum))

# Total number of fauna (all taxa combined) in each depth layer at each site
abundance_per_DL <- site_DL_totals %>% 
  rowwise() %>% 
  mutate(total_fauna = sum(across(Alitta.sp:Tellinidae.indet), na.rm = TRUE)) %>% 
  select(site, depth_layer, total_fauna) %>% 
  mutate(site = case_when(
    site == "AC" ~ "NS",
    site == "NH" ~ "NH",
    site == "SP" ~ "SP")) 

# Plot of total number of fauna per depth layer at each site (stacked bar plot)
total_abundance_plot <- ggplot(data = abundance_per_DL) +
  geom_bar(aes(x = depth_layer, y = total_fauna, fill = site), stat = "identity", position = position_dodge()) + 
  theme_bw(base_size = 20) +
  scale_y_continuous(expand = c(0, 0, 0.025, 0.1)) + #so that bars don't float above x-axis
  scale_fill_brewer(palette = "Dark2") + 
  theme(panel.grid.major = element_blank(), 
        panel.grid.minor = element_blank(),
        axis.title.y = element_text(vjust = 3),
        axis.title.x = element_text(vjust = -1),
        legend.position = c(0.9, 0.7)) + 
  labs(x = "", y = "Total abundance", fill = "Site")

# Proportion of fauna in each depth layer, per site
proportion_per_DL <- abundance_per_DL %>% 
  group_by(site) %>% 
  mutate(freq = total_fauna / sum(total_fauna))

# Plot of proportion of fauna in each depth layer, per site
proportions_plot <- ggplot(data = proportion_per_DL) +
  geom_bar(aes(x = depth_layer, y = freq, fill = site), stat = "identity", position = position_dodge()) + 
  theme_bw(base_size = 20) +
  # So that bars don't float above x-axis
  scale_y_continuous(expand = c(0, 0, 0.01, 0.1)) + 
  scale_fill_brewer(palette = "Dark2") +
  theme(panel.grid.major = element_blank(), 
        panel.grid.minor = element_blank(),
        axis.title.y = element_text(vjust = 3),
        axis.title.x = element_text(vjust = -1),
        legend.position = "none") + 
  labs(x = "Depth layer (cm)", y = "Proportion of fauna", fill = "Site")

# Figure showing both total abundance (A) and proportion (B) of fauna in each depth layer at each site
tiff("figures/abundance_and_proportions_per_depth_layer.tiff", width = 12, height = 9, units = "in", res = 300)
cowplot::plot_grid(total_abundance_plot, proportions_plot,
                   labels = LETTERS[1:2],
                   align = "v", axis = "l",
                   ncol = 1)
dev.off()

 
# SPLIT INTO TWO DEPTH LAYERS ONLY (0-2 & 2-10) #
# Here we are working with TD indices so we use the data frame of binned taxa (n = 51)

# Change abundance data frame so that 2-5 cm and 5-10 cm are summed
abund_two_DL <- by_depth_layer_for_indices %>% 
  # Rename depth layers so that 2-5 and 5-10 are both labeled "2-10"
  mutate(depth_layer = case_when(
    depth_layer == "2-5" ~ "2-10",
    depth_layer == "5-10" ~ "2-10",
    depth_layer == "0-2" ~ "0-2"
  )) %>% 
  # Change site names to full names (needed later for plots)
  mutate(site = case_when(
    site == "NS" ~ "Newman Sound",
    site == "SP" ~ "St. Paul's",
    site == "NH" ~ "Neddie's Harbour"
  )) %>% 
  # Sum rows if depth_layer and core_id are the same
  group_by(core_id, depth_layer, site) %>% 
  summarise(across(.cols = where(is.numeric), sum))

# Make row names indicate core ID & depth layer
abund_two_DL <- abund_two_DL %>% 
  mutate(identifier = glue::glue("{core_id}{depth_layer}"))
abund_two_DL <- as.data.frame(abund_two_DL)
rownames(abund_two_DL) <- abund_two_DL$identifier

# Remove unneeded columns so that only abundances remain - this is required to calculate TD indices 
TD_two_DL <- abund_two_DL %>% 
  dplyr::select(-site, -core_id, -depth_layer, -identifier)

# Reorder columns so that they're in alphabetical order
TD_two_DL <- TD_two_DL[ ,order(colnames(TD_two_DL))] 


# Calculate TD indices ----
two_DL_shannon <- diversity(TD_two_DL, "shannon")
two_DL_simpson <- diversity(TD_two_DL, "simpson")
two_DL_richness <- specnumber(TD_two_DL)
two_DL_pielous_evenness <- two_DL_shannon / two_DL_richness

# Create data frame containing all calculated taxonomic diversity indices for 0-2 and 2-10cm depth layers
TD_indices_two_DL <- data.frame(two_DL_shannon, two_DL_simpson, two_DL_richness, two_DL_pielous_evenness)
TD_indices_two_DL <- TD_indices_two_DL %>% 
  mutate(identifier = rownames(TD_indices_two_DL)) %>% 
  full_join(abund_two_DL, by = "identifier") %>% 
  select(site, depth_layer, core_id, two_DL_shannon, two_DL_simpson, two_DL_richness, two_DL_pielous_evenness)

# Save TD indices as csv
write.csv(TD_indices_two_DL, "data/processed/TD_indices_two_depth_layers.csv")


### Plot TD indices ----

shannon_plot_two_DL <- TD_indices_two_DL %>% 
  # In the interest of minimizing white space on the plot, remove the two 2-10cm DLs that contained no macrofauna
  filter(two_DL_shannon > 0) %>% 
  ggplot(aes(x = depth_layer, y = two_DL_shannon, fill = site)) + 
  geom_boxplot(outlier.shape = NA) +
  geom_jitter(position = position_jitterdodge(jitter.width = 0.09), alpha = 0.4, size = 1) + 
  labs(x = "", y = "Shannon-Weiner (H')") +
  theme_bw() + 
  scale_fill_brewer(palette = "Dark2") + 
  theme(panel.grid.major = element_blank(), 
        panel.grid.minor = element_blank(),
        axis.title.y = element_text(vjust = 3),
        axis.title.x = element_text(vjust = -1),
        axis.title = element_text(size = 16),
        axis.text = element_text(size = 14),
        legend.position = "none")

simpson_plot_two_DL <- TD_indices_two_DL %>% 
  # In the interest of minimizing white space on the plot, remove the two 2-10 cm DLs that contained no macrofauna
  filter(two_DL_simpson > 0) %>% 
  ggplot(aes(x = depth_layer, y = two_DL_simpson, fill = site)) + 
  geom_boxplot(outlier.shape = NA) +
  geom_jitter(position = position_jitterdodge(jitter.width = 0.09), alpha = 0.4, size = 1) + 
  labs(x = "", y = "Simpson's (d)") +
  theme_bw() + 
  scale_fill_brewer(palette = "Dark2") + 
  theme(panel.grid.major = element_blank(), 
        panel.grid.minor = element_blank(),
        axis.title.y = element_text(vjust = 3),
        axis.title.x = element_text(vjust = -1),
        axis.title = element_text(size = 16),
        axis.text = element_text(size = 14),
        legend.position = "none")

richness_plot_two_DL <- TD_indices_two_DL %>% 
  ggplot(aes(x = depth_layer, y = two_DL_richness, fill = site)) + 
  geom_boxplot(outlier.shape = NA) +
  geom_jitter(position = position_jitterdodge(jitter.width = 0.09), alpha = 0.4, size = 1) + 
  labs(x = "", y = "Taxonomic richness (S)") +
  theme_bw() + 
  scale_fill_brewer(palette = "Dark2") + 
  theme(panel.grid.major = element_blank(), 
        panel.grid.minor = element_blank(),
        axis.title.y = element_text(vjust = 3),
        axis.title.x = element_text(vjust = -1),
        axis.title = element_text(size = 16),
        axis.text = element_text(size = 14),
        legend.position = "none")

pielous_plot_two_DL <- TD_indices_two_DL %>% 
  # In the interest of minimizing white space on the plot, remove the two 2-10cm DLs that contained no macrofauna
  filter(two_DL_pielous_evenness > 0) %>% 
  ggplot(aes(x = depth_layer, y = two_DL_pielous_evenness, fill = site)) +
  geom_boxplot(outlier.shape = NA) +
  geom_jitter(position = position_jitterdodge(jitter.width = 0.09), alpha = 0.4, size = 1) + 
  labs(x = "", y = "Pielou's Evenness (J')") +
  theme_bw() + 
  scale_fill_brewer(palette = "Dark2") + 
  theme(panel.grid.major = element_blank(), 
        panel.grid.minor = element_blank(),
        axis.title.y = element_text(vjust = 3),
        axis.title.x = element_text(vjust = -1),
        axis.title = element_text(size = 16),
        axis.text = element_text(size = 14),
        legend.position = "none")


# Save plots contrasting 4 taxonomic diversity indices between sites and depth layers
tiff("figures/TD_indices_boxplots_two_depth_layers.tiff", width = 12, height = 9, units = "in", res = 300)
cowplot::plot_grid(shannon_plot_two_DL, simpson_plot_two_DL, richness_plot_two_DL, pielous_plot_two_DL,
                   labels = LETTERS[1:4],
                   align = "v", axis = "l")
dev.off()

## Test for differences (TD) between sites and depth layers ----

#### Shannon ----- 
# Start with a model that includes an interaction term 
lme_shannon <- lmer(two_DL_shannon ~ site + depth_layer + site*depth_layer + (1 | core_id), data = TD_indices_two_DL, REML = FALSE)
Anova(lme_shannon) # Interaction is not significant (p = 0.7) so remove interaction and re-run model

# Model 2: No interaction term
lme_shannon <- lmer(two_DL_shannon ~ site + depth_layer + (1 | core_id), data = TD_indices_two_DL, REML = FALSE)

# Check model fit with DHARMa
# STEP 1) Calculate scaled residuals
lme_shannon_simulationOutput <- simulateResiduals(fittedModel = lme_shannon, plot = F, n = 1000) 

# STEP 2) Plot the scaled residuals 
plot(lme_shannon_simulationOutput) 
plotResiduals(lme_shannon_simulationOutput, form = TD_indices_two_DL$depth_layer) 
plotResiduals(lme_shannon_simulationOutput, form = TD_indices_two_DL$site) 

# STEP 3) Goodness of fit tests
testDispersion(lme_shannon_simulationOutput)
testUniformity(lme_shannon_simulationOutput) 
testOutliers(lme_shannon_simulationOutput)  

# Look at model results
summary(lme_shannon)
lme_shannon_Anova <- Anova(lme_shannon) 

# Effects plot that includes data points
shannon_effects <- ggpredict(lme_shannon, terms = c("site", "depth_layer"))

shannon_by_site_DL_effects_plot <- ggplot(data = TD_indices_two_DL, aes(x = depth_layer, y = two_DL_shannon, colour = site)) + 
  geom_point(aes(x = depth_layer, y = two_DL_shannon),
             position = position_jitterdodge(jitter.width = 0.09), size = 3, alpha = 0.3) + 
  geom_point(data = shannon_effects, aes(x = group, y = predicted, colour = x),
             position = position_dodge(width = 0.75), size = 3) + 
  geom_errorbar(data = shannon_effects, aes(x = group, y = predicted, ymin = conf.low, ymax = conf.high, colour = x), width = 0.1, size = 1,
                position = position_dodge(width = 0.75)) + 
  labs(x = "Depth layer (cm)", y = "Shannon-Weiner (H')") +
  theme(legend.position = c(0.2, 0.1)) +
  scale_colour_brewer(name = "", palette = "Dark2")

# Save plot
ggsave(filename = "figures/shannon_by_site_and_DL_effects_plot.png", plot = shannon_by_site_DL_effects_plot, 
       width = 10, height = 10, units = "in", dpi = 300)


# Because DHARMa flagged an issue regarding outliers, find & remove the outliers (3 smallest values are 0, 0, and 0.3068292)
# Then run the model without these outliers and see if it makes a difference
TD_indices_two_DL %>% 
  dplyr::count(two_DL_shannon)

TD_indices_two_DL_outliers_rm <- TD_indices_two_DL %>% 
  filter(two_DL_shannon > 0.3068292)

# First, start with a model that includes an interaction term 
# Have to use a linear model here because of singularity error with lmer (i.e. core ID variance component is ~zero)
lm_shannon_no_outliers <- lm(two_DL_shannon ~ site + depth_layer + site*depth_layer, data = TD_indices_two_DL_outliers_rm)
Anova(lm_shannon_no_outliers) # Interaction is not significant (p = 0.5) so remove interaction and re-run model...

# Model 2: No interaction term
lm_shannon_no_outliers <- lm(two_DL_shannon ~ site + depth_layer, data = TD_indices_two_DL_outliers_rm)

# Check model fit with DHARMa
# STEP 1) Calculate scaled residuals
lm_shannon_no_outliers_simulationOutput <- simulateResiduals(fittedModel = lm_shannon_no_outliers, plot = F, n = 1000) 

# STEP 2) Plot the scaled residuals 
plot(lm_shannon_no_outliers_simulationOutput) # Outlier test not significant (p = 0.29)

# STEP 3) Goodness of fit tests
testDispersion(lm_shannon_no_outliers_simulationOutput) # Looks fine (p = 0.99)
testUniformity(lm_shannon_no_outliers_simulationOutput) # Also fine (p = 0.53)
testOutliers(lm_shannon_no_outliers_simulationOutput)   # Outliers fine now - not significant 

# Look at model results
summary(lm_shannon_no_outliers) # End result is the same as the model with outliers included...
lm_shannon_no_outliers_Anova <- Anova(lm_shannon_no_outliers) # Again, both site and depth layer have a significant effect on Shannon
# Therefore proceed with the model that includes all data (including the 3 outliers)


# Calculate p-values for Shannon model using pbkrtest package
# This approach uses Kenward-Roger approximation to estimate degrees of freedom & uses the t-distribution to get p-values
# For details, see https://www.r-bloggers.com/2014/02/three-ways-to-get-parameter-specific-p-values-from-lmer/ 
# and Ben Bolker's "GLMM FAQ" https://bbolker.github.io/mixedmodels-misc/glmmFAQ.html 

# Extract coefficients 
coefs_shannon <- data.frame(coef(summary(lme_shannon)))
# Get KR-approximated df
df_KR_shannon <- get_Lb_ddf(lme_shannon, fixef(lme_shannon))
# Get p-values from the t-distribution using the t-values + appoximated df
coefs_shannon$p.KR <- 2 * (1 - pt(abs(coefs_shannon$t.value), df_KR_shannon))
# And view p-values
coefs_shannon


# Model summary table - Fixed effects
broom.mixed::tidy(lme_shannon) %>% 
  # Specify the number of decimal places you'd like in the table
  mutate(across(where(is.numeric), ~round(., 3))) %>% 
  # Remove random effects 
  filter(effect == "fixed") %>% 
  # Remove unneeded columns 
  select(-effect, -group) %>% 
  # Rename column headers for table to make them more legible
  rename("Fixed effects" = "term",
         "Estimate" = "estimate",
         "SE" = "std.error",
         "t-statistic" = "statistic") %>% 
  # Create table 
  flextable()

# Model summary table - Random effects
broom.mixed::tidy(lme_shannon) %>% 
  # Specify the number of decimal places you'd like in the table
  mutate(across(where(is.numeric), ~round(., 3))) %>% 
  # Remove random effects 
  filter(effect == "ran_pars") %>% 
  # Only keep columns we need! 
  select(group, estimate) %>% 
  # Rename column headers for table to make them more legible
  rename("Random effects, ~1|coreID" = "group",
         "SD" = "estimate") %>% 
  # Create table 
  flextable()


# Table showing ANOVA (p-value) component of model output 
broom::tidy(lme_shannon_Anova) %>% 
  # Specify the number of decimal places you'd like in the table
  mutate(across(where(is.numeric), ~round(., 3))) %>% 
  # For very small p-value, replace with "<0.001" for ease of reading
  mutate(p.value = if_else(p.value == 0.000, "< 0.001", as.character(p.value)),
         term = if_else(term == "depth_layer", "depth layer", "site")) %>% 
  # Rename column headers for table to make them more legible
  rename("Term" = "term",
         "Chi Sq." = "statistic",
         "p-value" = "p.value") %>% 
  # Create table 
  flextable()


#### Simpson ----- 
# Because Simpson's index is bounded between 0 and 1, start with a beta mixed effects model
# However there is one row (AC2_MED_C, 2-10 cm) for which Simpson's index is exactly 0 - remove this data point
TD_indices_no_0 <- TD_indices_two_DL %>% 
  filter(two_DL_simpson != 0)

beta_mixedeffects_simpson_int <- glmmTMB(formula = two_DL_simpson ~ depth_layer + site + site*depth_layer + (1 | core_id),
                                     data = TD_indices_no_0, family = beta_family(link="logit"))
Anova(beta_mixedeffects_simpson_int) # Interaction term is not significant (p = 0.07) so remove and re-run

beta_mixedeffects_simpson <- glmmTMB(formula = two_DL_simpson ~ depth_layer + site + (1 | core_id),
                                         data = TD_indices_no_0, family = beta_family(link="logit"))

# Check model fit with DHARMa
# STEP 1) Calculate scaled residuals
beta_mixedeffects_simpson_simulationOutput <- simulateResiduals(fittedModel = beta_mixedeffects_simpson, plot = F, n = 1000)

# STEP 2) Plot the scaled residuals 
plot(beta_mixedeffects_simpson_simulationOutput) 
plotResiduals(beta_mixedeffects_simpson_simulationOutput, form = TD_indices_no_0$depth_layer) 
plotResiduals(beta_mixedeffects_simpson_simulationOutput, form = TD_indices_no_0$site) 

# STEP 3) Goodness of fit tests
testDispersion(beta_mixedeffects_simpson_simulationOutput) 
testUniformity(beta_mixedeffects_simpson_simulationOutput) 
testOutliers(beta_mixedeffects_simpson_simulationOutput)   

# Beta regression is the best fit for these data but there are some borderline violations of the model 
# So we conducted non-parametric tests as well to confirm that the biological inferences we're making are robust
kruskal_test(two_DL_simpson ~ site , data = TD_indices_no_0) 
kruskal_test(two_DL_simpson ~ depth_layer , data = TD_indices_no_0)

# Look at model results
summary(beta_mixedeffects_simpson)
beta_mixed_simpson_Anova <- Anova(beta_mixedeffects_simpson) # Site has a significant effect on Simpson

# Effects plot that includes raw data points
simpson_effects <- ggpredict(beta_mixedeffects_simpson, terms = c("site", "depth_layer"))

# Reorder factor x (aka site) so that points align correctly on the plot below
simpson_effects$x <- ordered(simpson_effects$x, levels = c("Neddie's Harbour", "Newman Sound", "St. Paul's"))

# Effects plot: 
simpson_by_site_DL_effects_plot <- ggplot(data = TD_indices_no_0, aes(x = depth_layer, y = two_DL_simpson, colour = site)) + 
  geom_point(aes(x = depth_layer, y = two_DL_simpson),
             position = position_jitterdodge(jitter.width = 0.09), size = 3, alpha = 0.3) + 
  geom_point(data = simpson_effects, aes(x = group, y = predicted, colour = x),
             position = position_dodge(width = 0.75), size = 3) + 
  geom_errorbar(data = simpson_effects, aes(x = group, y = predicted, ymin = conf.low, ymax = conf.high, colour = x), width = 0.1, size = 1,
                position = position_dodge(width = 0.75)) + 
  labs(x = "Depth layer (cm)", y = "Simpson's Index") +
  theme(legend.position = c(0.2, 0.1)) +
  scale_colour_brewer(name = "", palette = "Dark2")

# Save plot
ggsave(filename = "figures/simpson_by_site_DL_effects_plot.png", plot = simpson_by_site_DL_effects_plot, 
       width = 10, height = 10, units = "in", dpi = 300)

# Model summary table - Fixed effects
broom.mixed::tidy(beta_mixedeffects_simpson) %>% 
  # Specify the number of decimal places you'd like in the table
  mutate(across(where(is.numeric), ~round(., 3))) %>% 
  # Remove random effects 
  filter(effect == "fixed") %>% 
  # Remove unneeded columns 
  select(-effect, -component, -group) %>% 
  # Rename column headers for table to make them more legible
  rename("Fixed effects" = "term",
         "Estimate" = "estimate",
         "SE" = "std.error",
         "t-statistic" = "statistic", 
         "p value" = "p.value") %>% 
  # Create table 
  flextable()

# Model summary table - Random effects
broom.mixed::tidy(beta_mixedeffects_simpson) %>% 
  # Specify the number of decimal places you'd like in the table
  mutate(across(where(is.numeric), ~round(., 3))) %>% 
  # Remove random effects 
  filter(effect == "ran_pars") %>% 
  # Only keep columns we need 
  select(group, estimate) %>% 
  # Rename column headers for table to make them more legible
  rename("Random effects, ~1|coreID" = "group",
         "SD" = "estimate") %>% 
  # Create table 
  flextable()


# Table showing ANOVA (p-value) component of model output 
broom::tidy(beta_mixed_simpson_Anova) %>% 
  # Specify the number of decimal places you'd like in the table
  mutate(across(where(is.numeric), ~round(., 3))) %>% 
  # For very small p-value, replace with "<0.001" for ease of reading
  mutate(p.value = if_else(p.value == 0.000, "< 0.001", as.character(p.value)),
         term = case_when(
           term == "depth_layer" ~ "Depth layer", 
           term == "site" ~ "Site",
           term == "depth_layer:site" ~ "Depth Layer*Site")) %>% 
  # Rename column headers for table to make them more legible
  rename("Term" = "term",
         "Chi Sq." = "statistic",
         "p-value" = "p.value") %>% 
  # Create table 
  flextable()



#### Richness ----- 
# Start with a model that includes an interaction term 
lme_richness_int <- lmer(two_DL_richness ~ site + depth_layer + site*depth_layer + (1 | core_id), data = TD_indices_two_DL)
Anova(lme_richness_int) # Interaction not significant so remove and re-run

lme_richness <- lmer(two_DL_richness ~ site + depth_layer + (1 | core_id), data = TD_indices_two_DL)

# Check model fit with DHARMa
# STEP 1) Calculate scaled residuals
lme_richness_simulationOutput <- simulateResiduals(fittedModel = lme_richness, plot = F, n = 1000)

# STEP 2) Plot the scaled residuals 
plot(lme_richness_simulationOutput) 
plotResiduals(lme_richness_simulationOutput, form = TD_indices_two_DL$depth_layer) 
plotResiduals(lme_richness_simulationOutput, form = TD_indices_two_DL$site) 

# STEP 3) Goodness of fit tests
testDispersion(lme_richness_simulationOutput) 
testUniformity(lme_richness_simulationOutput) 
testOutliers(lme_richness_simulationOutput)   

# Look at model results
summary(lme_richness)
lme_richness_Anova <- Anova(lme_richness)  

# Effects plot that includes actual data points
richness_effects <- ggpredict(lme_richness, terms = c("site", "depth_layer"))

# Reorder factor x (aka site) so that points align correctly on the plot below
richness_effects$x <- ordered(richness_effects$x, levels = c("Neddie's Harbour", "Newman Sound", "St. Paul's"))

richness_by_site_DL_effects_plot <- ggplot(data = TD_indices_two_DL, aes(x = depth_layer, y = two_DL_richness, colour = site)) + 
  geom_point(aes(x = depth_layer, y = two_DL_richness),
             position = position_jitterdodge(jitter.width = 0.09), size = 3, alpha = 0.3) + 
  geom_point(data = richness_effects, aes(x = group, y = predicted, colour = x),
             position = position_dodge(width = 0.75), size = 3) + 
  geom_errorbar(data = richness_effects, aes(x = group, y = predicted, ymin = conf.low, ymax = conf.high, colour = x), width = 0.1, size = 1,
                position = position_dodge(width = 0.75)) + 
  labs(x = "Depth layer (cm)", y = "Richness (S)") +
  theme(legend.position = c(0.2, 0.1)) +
  scale_colour_brewer(name = "", palette = "Dark2")

# Save plot
ggsave(filename = "figures/richness_by_site_DL_effects_plot.png", plot = richness_by_site_DL_effects_plot, 
       width = 10, height = 10, units = "in", dpi = 300)

# Calculate p-values for richness model using pbkrtest package
# This approach uses Kenward-Roger approximation to estimate degrees of freedom & uses the t-distribution to get p-values
# For details, see https://www.r-bloggers.com/2014/02/three-ways-to-get-parameter-specific-p-values-from-lmer/ 
# and Ben Bolker's "GLMM FAQ" https://bbolker.github.io/mixedmodels-misc/glmmFAQ.html 

# Extract coefficients 
coefs_richness <- data.frame(coef(summary(lme_richness)))
# Get KR-approximated df
df_KR_richness <- get_Lb_ddf(lme_richness, fixef(lme_richness))
# Get p-values from the t-distribution using the t-values + appoximated df
coefs_richness$p.KR <- 2 * (1 - pt(abs(coefs_richness$t.value), df_KR_richness))
# And view p-values
coefs_richness

# Model summary table - Fixed effects
broom.mixed::tidy(lme_richness) %>% 
  # Specify the number of decimal places you'd like in the table
  mutate(across(where(is.numeric), ~round(., 3))) %>% 
  # Remove random effects 
  filter(effect == "fixed") %>% 
  # Remove unneeded columns 
  select(-effect, -group) %>% 
  # Rename column headers for table to make them more legible
  rename("Fixed effects" = "term",
         "Estimate" = "estimate",
         "SE" = "std.error",
         "t-statistic" = "statistic") %>% 
  # Create table 
  flextable()

# Model summary table - Random effects
broom.mixed::tidy(lme_richness) %>% 
  # Specify the number of decimal places you'd like in the table
  mutate(across(where(is.numeric), ~round(., 3))) %>% 
  # Remove random effects 
  filter(effect == "ran_pars") %>% 
  # Only keep columns we need! 
  select(group, estimate) %>% 
  # Rename column headers for table to make them more legible
  rename("Random effects, ~1|coreID" = "group",
         "SD" = "estimate") %>% 
  # Create table 
  flextable()


# Table showing ANOVA (p-value) component of model output 
broom::tidy(lme_richness_Anova) %>% 
  # Specify the number of decimal places you'd like in the table
  mutate(across(where(is.numeric), ~round(., 3))) %>% 
  # For very small p-value, replace with "<0.001" for ease of reading
  mutate(p.value = if_else(p.value == 0.000, "< 0.001", as.character(p.value)),
         term = if_else(term == "depth_layer", "depth layer", "site")) %>% 
  # Rename column headers for table to make them more legible
  rename("Term" = "term",
         "Chi Sq." = "statistic",
         "p-value" = "p.value") %>% 
  # Create table 
  flextable()


#### Pielou's Evenness ----- 
# Start with a model that includes an interaction term 
lme_pielous <- lmer(two_DL_pielous_evenness ~ depth_layer + site + depth_layer*site + (1 | core_id), data = TD_indices_two_DL, REML = FALSE)
Anova(lme_pielous) # Interaction is significant (p = 0.047) so leave it in the model 

# Check model fit with DHARMa
# STEP 1) Calculate scaled residuals
lme_pielous_simulationOutput <- simulateResiduals(fittedModel = lme_pielous, plot = F, n = 1000)

# STEP 2) Plot the scaled residuals 
plot(lme_pielous_simulationOutput) 
plotResiduals(lme_pielous_simulationOutput, form = TD_indices_two_DL$depth_layer) 
plotResiduals(lme_pielous_simulationOutput, form = TD_indices_two_DL$site) 

# STEP 3) Goodness of fit tests
testDispersion(lme_pielous_simulationOutput) 
testUniformity(lme_pielous_simulationOutput) 
testOutliers(lme_pielous_simulationOutput)   

# Look at model results
summary(lme_pielous)
lme_pielous_Anova <- Anova(lme_pielous) 

# Effects plot that includes actual data points
pielous_effects <- ggpredict(lme_pielous, terms = c("site", "depth_layer"))

pielous_by_site_DL_effects_plot <- ggplot(data = TD_indices_two_DL, aes(x = depth_layer, y = two_DL_pielous_evenness, colour = site)) + 
  geom_point(aes(x = depth_layer, y = two_DL_pielous_evenness),
             position = position_jitterdodge(jitter.width = 0.09), size = 3, alpha = 0.3) + 
  geom_point(data = pielous_effects, aes(x = group, y = predicted, colour = x),
             position = position_dodge(width = 0.75), size = 3) + 
  geom_errorbar(data = pielous_effects, aes(x = group, y = predicted, ymin = conf.low, ymax = conf.high, colour = x), width = 0.1, size = 1,
                position = position_dodge(width = 0.75)) + 
  labs(x = "Depth layer (cm)", y = "Pielou's Evenness (J')") +
  theme(legend.position = c(0.2, 0.1)) +
  scale_colour_brewer(name = "", palette = "Dark2")

# Save plot
ggsave(filename = "figures/pielous_by_site_and_DL_effects_plot.png", plot = pielous_by_site_DL_effects_plot, 
       width = 10, height = 10, units = "in", dpi = 300)

# Calculate p-values for Pielou's model using pbkrtest package
# This approach uses Kenward-Roger approximation to estimate degrees of freedom & uses the t-distribution to get p-values
# For details, see https://www.r-bloggers.com/2014/02/three-ways-to-get-parameter-specific-p-values-from-lmer/ 
# and Ben Bolker's "GLMM FAQ" https://bbolker.github.io/mixedmodels-misc/glmmFAQ.html 

# Extract coefficients 
coefs_pielous <- data.frame(coef(summary(lme_pielous)))
# Get KR-approximated df
df_KR_pielous <- get_Lb_ddf(lme_pielous, fixef(lme_pielous))
# Get p-values from the t-distribution using the t-values + appoximated df
coefs_pielous$p.KR <- 2 * (1 - pt(abs(coefs_pielous$t.value), df_KR_pielous))
# And view p-values
coefs_pielous

# Model summary table - Fixed effects
broom.mixed::tidy(lme_pielous) %>% 
  # Specify the number of decimal places you'd like in the table
  mutate(across(where(is.numeric), ~round(., 3))) %>% 
  # Remove random effects 
  filter(effect == "fixed") %>% 
  # Remove unneeded columns 
  select(-effect, -group) %>% 
  # Rename column headers for table to make them more legible
  rename("Fixed effects" = "term",
         "Estimate" = "estimate",
         "SE" = "std.error",
         "t-statistic" = "statistic") %>% 
  # Create table 
  flextable()

# Model summary table - Random effects
broom.mixed::tidy(lme_pielous) %>% 
  # Specify the number of decimal places you'd like in the table
  mutate(across(where(is.numeric), ~round(., 3))) %>% 
  # Remove random effects 
  filter(effect == "ran_pars") %>% 
  # Only keep columns we need! 
  select(group, estimate) %>% 
  # Rename column headers for table to make them more legible
  rename("Random effects, ~1|coreID" = "group",
         "SD" = "estimate") %>% 
  # Create table 
  flextable()


# Table showing ANOVA (p-value) component of model output 
broom::tidy(lme_pielous_Anova) %>% 
  # Specify the number of decimal places you'd like in the table
  mutate(across(where(is.numeric), ~round(., 3))) %>% 
  # For very small p-value, replace with "<0.001" for ease of reading
  mutate(p.value = if_else(p.value == 0.000, "< 0.001", as.character(p.value)),
         term = case_when(
           term == "depth_layer" ~ "Depth layer", 
           term == "site" ~ "Site",
           term == "depth_layer:site" ~ "Site:Depth Layer")) %>% 
  # Rename column headers for table to make them more legible
  rename("Term" = "term",
         "Chi Sq." = "statistic",
         "p-value" = "p.value") %>% 
  # Create table 
  flextable()


# Calculate FD indices ---- 

# Remove unneeded columns & make abund_two_DL into a matrix that can be used to calculate FD indices for each core
abund_two_DL_matrix <- abund_two_DL %>% 
  # Remove Lacuna sp. because it only appears once (in NH1_NONE_C2-10) which prevents calculation of FD indices 
  select(-core_id, -depth_layer, -identifier, -site, -Lacuna.sp) %>% 
  filter(rowSums(.) > 0)
abund_two_DL_matrix <- as.matrix(abund_two_DL_matrix)


# Make taxon names the row names, remove unneeded column X, and make funct_coord into a matrix
funct_coord <- funct_coord %>% 
  filter(X != "Lacuna.sp")
rownames(funct_coord) <- funct_coord$X
funct_coord <- funct_coord %>% 
  select(-X) 
funct_coord <- as.matrix(funct_coord)

# Calculate FD indices for each core
FD_indices_two_DL <- multidimFD(funct_coord, abund_two_DL_matrix, check_species_pool = TRUE, verb = TRUE)
FD_indices_two_DL <- as.data.frame(FD_indices_two_DL)

FD_two_DL <- FD_indices_two_DL %>% 
  mutate(identifier = rownames(FD_indices_two_DL)) %>% 
  full_join(abund_two_DL, by = "identifier") %>% 
  select(Nb_sp, Tot_weight, FRic, FDiv, FEve, core_id, depth_layer, site)

# Write data frame to a csv 
write.csv(FD_two_DL, "data/processed/FD_indices_two_depth_layers.csv")


### Plot FD indices ----

FRic_plot_two_DL <- FD_two_DL %>% 
  ggplot(aes(x = depth_layer, y = FRic, fill = site)) + 
  geom_boxplot(outlier.shape = NA) +
  geom_jitter(position = position_jitterdodge(jitter.width = 0.09), alpha = 0.4, size = 1) +
  labs(x = "", y = "Functional richness (FRic)") +
  theme_bw() + 
  scale_fill_brewer(palette = "Dark2") + 
  theme(panel.grid.major = element_blank(), 
        panel.grid.minor = element_blank(),
        axis.title.y = element_text(vjust = 3),
        axis.title.x = element_text(vjust = -1),
        axis.title = element_text(size = 16),
        axis.text = element_text(size = 14),
        legend.position = "none")

FEve_plot_two_DL <- FD_two_DL %>% 
  ggplot(aes(x = depth_layer, y = FEve, fill = site)) + 
  geom_boxplot(outlier.shape = NA) +
  geom_jitter(position = position_jitterdodge(jitter.width = 0.09), alpha = 0.4, size = 1) +
  labs(x = "", y = "Functional evenness (FEve)") +
  theme_bw() + 
  scale_fill_brewer(palette = "Dark2") + 
  theme(panel.grid.major = element_blank(), 
        panel.grid.minor = element_blank(),
        axis.title.y = element_text(vjust = 3),
        axis.title.x = element_text(vjust = -1),
        axis.title = element_text(size = 16),
        axis.text = element_text(size = 14),
        legend.position = "none")

FDiv_plot_two_DL <- FD_two_DL %>% 
  ggplot(aes(x = depth_layer, y = FDiv, fill = site)) + 
  geom_boxplot(outlier.shape = NA) +
  geom_jitter(position = position_jitterdodge(jitter.width = 0.09), alpha = 0.4, size = 1) +
  labs(x = "", y = "Functional divergence (FDiv)") +
  theme_bw() + 
  scale_fill_brewer(palette = "Dark2") + 
  theme(panel.grid.major = element_blank(), 
        panel.grid.minor = element_blank(),
        axis.title.y = element_text(vjust = 3),
        axis.title.x = element_text(vjust = -1),
        axis.title = element_text(size = 16),
        axis.text = element_text(size = 14),
        legend.position = "none")

# Finally, make a plot with a legend that can be shared by all diversity index plots 
plot_for_legend_purposes <-  ggplot(FD_two_DL, aes(x = depth_layer, y = FDiv, fill = site)) + 
  geom_boxplot(outlier.shape = NA) +
  geom_jitter(position = position_jitterdodge(jitter.width = 0.09), alpha = 0.4, size = 1) +
  labs(x = "", y = "Functional divergence (FDiv)") +
  theme_bw() + 
  scale_fill_brewer(palette = "Dark2", name = "Site") + 
  theme(panel.grid.major = element_blank(), 
        panel.grid.minor = element_blank(),
        legend.position = "right",
        legend.text = element_text(size = 14),
        legend.title = element_text(size = 16),
        legend.key.size = unit(1, "cm"))

# Extract the legend and add it to the multipanel plots below 
legend <- cowplot::get_legend(
  # Create some space to the left of the legend
  plot_for_legend_purposes + theme(legend.box.margin = margin(0, 0, 0, 12))
)



# Save plots contrasting these 3 taxonomic diversity indices between sites and depth layers
tiff("figures/FD_indices_boxplots_two_depth_layers.tiff", width = 12, height = 9, units = "in", res = 300)
cowplot::plot_grid(FRic_plot_two_DL, FEve_plot_two_DL, FDiv_plot_two_DL, legend,
                   labels = LETTERS[1:3],
                   align = "v", axis = "l")
dev.off()

# Save plots contrasting 4 taxonomic diversity indices and 3 functional diversity indices between the 2 depth layers
tiff("figures/TD_and_FD_indices_boxplots_two_depth_layers.tiff", width = 12, height = 9, units = "in", res = 300)
cowplot::plot_grid(richness_plot_two_DL, pielous_plot_two_DL, shannon_plot_two_DL, simpson_plot_two_DL,
                   FRic_plot_two_DL, FEve_plot_two_DL, FDiv_plot_two_DL, legend,
                   labels = LETTERS[1:7],
                   align = "v", axis = "l",
                   ncol = 4)
dev.off()


### Test for differences (FD) between sites and depth layers ----

#### FRic ----- 

# First, remove the rows for which FRic could not be calculated 
FD_two_DL_NA_rm <- FD_two_DL %>% 
  drop_na(FRic)
range(FD_two_DL_NA_rm$FRic) #FRic is bounded between 0 and 1, so will start with a beta mixed effects model

# Start with a model that includes interaction and random effect 
beta_mixedeffects_FRic <- glmmTMB(formula = FRic ~ depth_layer + site + site*depth_layer + (1 | core_id),
                                     data = FD_two_DL_NA_rm, family = beta_family(link="logit"))
Anova(beta_mixedeffects_FRic) # Interaction term is significant (p = 0.006) so leave model as is


# Check model fit with DHARMa
# STEP 1) Calculate scaled residuals
beta_mixedeffects_FRic_simulationOutput <- simulateResiduals(fittedModel = beta_mixedeffects_FRic, plot = F)

# STEP 2) Plot the scaled residuals 
plot(beta_mixedeffects_FRic_simulationOutput) 
plotResiduals(beta_mixedeffects_FRic_simulationOutput, form = FD_two_DL_NA_rm$depth_layer) 
plotResiduals(beta_mixedeffects_FRic_simulationOutput, form = FD_two_DL_NA_rm$site) 

# STEP 3) Goodness of fit tests
testDispersion(beta_mixedeffects_FRic_simulationOutput)
testUniformity(beta_mixedeffects_FRic_simulationOutput)
testOutliers(beta_mixedeffects_FRic_simulationOutput) 

# Look at model results
summary(beta_mixedeffects_FRic)
beta_mixed_FRic_Anova <- Anova(beta_mixedeffects_FRic) 

# Effects plot that includes raw data points
FRic_effects <- ggpredict(beta_mixedeffects_FRic, terms = c("site", "depth_layer"))

# Reorder factor x (aka site) so that points align correctly on the plot below
FRic_effects$x <- ordered(FRic_effects$x, levels = c("Neddie's Harbour", "Newman Sound", "St. Paul's"))

FRic_by_site_DL_effects_plot <- ggplot(data = FD_two_DL_NA_rm, aes(x = depth_layer, y = FRic, colour = site)) + 
  geom_point(aes(x = depth_layer, y = FRic),
             position = position_jitterdodge(jitter.width = 0.09), size = 3, alpha = 0.3) + 
  geom_point(data = FRic_effects, aes(x = group, y = predicted, colour = x),
             position = position_dodge(width = 0.75), size = 3) + 
  geom_errorbar(data = FRic_effects, aes(x = group, y = predicted, ymin = conf.low, ymax = conf.high, colour = x), width = 0.1, size = 1,
                position = position_dodge(width = 0.75)) + 
  labs(x = "Depth layer (cm)", y = "Functional richness (FRic)") +
  theme(legend.position = c(0.8, 0.9)) +
  scale_colour_brewer(name = "", palette = "Dark2")

# Save plot
ggsave(filename = "figures/FRic_by_site_DL_effects_plot.png", plot = FRic_by_site_DL_effects_plot, 
       width = 10, height = 10, units = "in", dpi = 300)

# Model summary table - Fixed effects
broom.mixed::tidy(beta_mixedeffects_FRic) %>% 
  # Specify the number of decimal places you'd like in the table
  mutate(across(where(is.numeric), ~round(., 3))) %>%
  # For very small p-value, replace with "<0.001" for ease of reading
  mutate(p.value = if_else(p.value == 0.000, "< 0.001", as.character(p.value))) %>% 
  # Remove random effects 
  filter(effect == "fixed") %>% 
  # Remove unneeded columns 
  select(-effect, -component, -group) %>% 
  # Rename column headers for table to make them more legible
  rename("Fixed effects" = "term",
         "Estimate" = "estimate",
         "SE" = "std.error",
         "t-statistic" = "statistic", 
         "p-value" = "p.value") %>% 
  # Create table 
  flextable()

# Model summary table - Random effects 
broom.mixed::tidy(beta_mixedeffects_FRic) %>% 
  # Specify the number of decimal places you'd like in the table
  mutate(across(where(is.numeric), ~round(., 3))) %>% 
  # Remove random effects 
  filter(effect == "ran_pars") %>% 
  # Only keep columns we need! 
  select(group, estimate) %>% 
  # Rename column headers for table to make them more legible
  rename("Random effects, ~1|coreID" = "group",
         "SD" = "estimate") %>% 
  # Create table 
  flextable()


# Table showing ANOVA (p-value) component of model output 
broom::tidy(beta_mixed_FRic_Anova) %>% 
  # Specify the number of decimal places you'd like in the table
  mutate(across(where(is.numeric), ~round(., 3))) %>% 
  # For very small p-value, replace with "<0.001" for ease of reading
  mutate(p.value = if_else(p.value == 0.000, "< 0.001", as.character(p.value))) %>% 
  # Rename column headers for table to make them more legible
  rename("Term" = "term",
         "Chi Sq." = "statistic",
         "p-value" = "p.value") %>% 
  # Create table 
  flextable()


#### FEve ----- 

# First, remove the rows for which FRic could not be calculated 
FD_two_DL_FEveNA_rm <- FD_two_DL %>% 
  drop_na(FEve)
range(FD_two_DL_FEveNA_rm$FEve) #FEve is bounded between 0 and 1, so will start with a beta mixed effects model

# Start with a model that includes interaction and random effect 
beta_mixedeffects_FEve <- glmmTMB(formula = FEve ~ depth_layer + site + site*depth_layer + (1 | core_id),
                                  data = FD_two_DL_FEveNA_rm, family = beta_family(link = "logit"))
Anova(beta_mixedeffects_FEve) # Interaction term is significant (p = 0.005) so leave model as is


# Check model fit with DHARMa
# STEP 1) Calculate scaled residuals 
beta_mixedeffects_FEve_simulationOutput <- simulateResiduals(fittedModel = beta_mixedeffects_FEve, plot = F)

# STEP 2) Plot the scaled residuals 
plot(beta_mixedeffects_FEve_simulationOutput) 
plotResiduals(beta_mixedeffects_FEve_simulationOutput, form = FD_two_DL_FEveNA_rm$depth_layer) 
plotResiduals(beta_mixedeffects_FEve_simulationOutput, form = FD_two_DL_FEveNA_rm$site) 

# STEP 3) Goodness of fit tests
testDispersion(beta_mixedeffects_FEve_simulationOutput) 
testUniformity(beta_mixedeffects_FEve_simulationOutput) 
testOutliers(beta_mixedeffects_FEve_simulationOutput)   

# Look at model results
summary(beta_mixedeffects_FEve)
beta_mixed_FEve_Anova <- Anova(beta_mixedeffects_FEve)

# Effects plot that includes raw data points
FEve_effects <- ggpredict(beta_mixedeffects_FEve, terms = c("site", "depth_layer"))

# Reorder factor x (aka site) so that points align correctly on the plot below
FEve_effects$x <- ordered(FEve_effects$x, levels = c("Neddie's Harbour", "Newman Sound", "St. Paul's"))

FEve_by_site_DL_effects_plot <- ggplot(data = FD_two_DL_FEveNA_rm, aes(x = depth_layer, y = FEve, colour = site)) + 
  geom_point(aes(x = depth_layer, y = FEve),
             position = position_jitterdodge(jitter.width = 0.09), size = 3, alpha = 0.3) + 
  geom_point(data = FEve_effects, aes(x = group, y = predicted, colour = x),
             position = position_dodge(width = 0.75), size = 3) + 
  geom_errorbar(data = FEve_effects, aes(x = group, y = predicted, ymin = conf.low, ymax = conf.high, colour = x), width = 0.1, size = 1,
                position = position_dodge(width = 0.75)) + 
  labs(x = "Depth layer (cm)", y = "Functional evenness (FEve)") +
  theme(legend.position = c(0.2, 0.1)) +
  scale_colour_brewer(name = "", palette = "Dark2")

# Save plot
ggsave(filename = "figures/FEve_by_site_DL_effects_plot.png", plot = FEve_by_site_DL_effects_plot, 
       width = 10, height = 10, units = "in", dpi = 300)

# Model summary table - Fixed effects
broom.mixed::tidy(beta_mixedeffects_FEve) %>% 
  # Specify the number of decimal places you'd like in the table
  mutate(across(where(is.numeric), ~round(., 3))) %>%
  # For very small p-value, replace with "<0.001" for ease of reading
  mutate(p.value = if_else(p.value == 0.000, "< 0.001", as.character(p.value))) %>% 
  # Remove random effects 
  filter(effect == "fixed") %>% 
  # Remove unneeded columns 
  select(-effect, -component, -group) %>% 
  # Rename column headers for table to make them more legible
  rename("Fixed effects" = "term",
         "Estimate" = "estimate",
         "SE" = "std.error",
         "t-statistic" = "statistic", 
         "p-value" = "p.value") %>% 
  # Create table 
  flextable()

# Model summary table - Random effects
broom.mixed::tidy(beta_mixedeffects_FEve) %>% 
  # Specify the number of decimal places you'd like in the table
  mutate(across(where(is.numeric), ~round(., 3))) %>% 
  # Remove random effects 
  filter(effect == "ran_pars") %>% 
  # Only keep columns we need! 
  select(group, estimate) %>% 
  # Rename column headers for table to make them more legible
  rename("Random effects, ~1|coreID" = "group",
         "SD" = "estimate") %>% 
  # Create table 
  flextable()

# Table showing ANOVA (p-value) component of model output 
broom::tidy(beta_mixed_FEve_Anova) %>% 
  # Specify the number of decimal places you'd like in the table
  mutate(across(where(is.numeric), ~round(., 3))) %>% 
  # For very small p-value, replace with "<0.001" for ease of reading
  mutate(p.value = if_else(p.value == 0.000, "< 0.001", as.character(p.value))) %>% 
  # Rename column headers for table to make them more legible
  rename("Term" = "term",
         "Chi Sq." = "statistic",
         "p-value" = "p.value") %>% 
  # Create table 
  flextable()


#### FDiv ----

# First, remove the rows for which FRic could not be calculated 
FD_two_DL_FDivNA_rm <- FD_two_DL %>% 
  drop_na(FDiv)
range(FD_two_DL_FDivNA_rm$FDiv) #FDiv is bounded between 0 and 1, so will start with a beta mixed effects model

# Start with a model that includes interaction and random effect 
beta_mixedeffects_FDiv <- glmmTMB(formula = FDiv ~ depth_layer + site + site*depth_layer + (1 | core_id),
                                  data = FD_two_DL_FDivNA_rm, family = beta_family(link = "logit"))
Anova(beta_mixedeffects_FDiv) # Interaction term is significant

# Check model fit with DHARMa
# STEP 1) Calculate scaled residuals
beta_mixedeffects_FDiv_simulationOutput <- simulateResiduals(fittedModel = beta_mixedeffects_FDiv, plot = F, n = 690)

# STEP 2) Plot the scaled residuals 
plot(beta_mixedeffects_FDiv_simulationOutput) 
plotResiduals(beta_mixedeffects_FDiv_simulationOutput, form = FD_two_DL_FDivNA_rm$depth_layer) 
plotResiduals(beta_mixedeffects_FDiv_simulationOutput, form = FD_two_DL_FDivNA_rm$site) 

# STEP 3) Goodness of fit tests
testDispersion(beta_mixedeffects_FDiv_simulationOutput) 
testUniformity(beta_mixedeffects_FDiv_simulationOutput) 
testOutliers(beta_mixedeffects_FDiv_simulationOutput)   

# Look at model results
summary(beta_mixedeffects_FDiv)
beta_mixed_FDiv_Anova <- Anova(beta_mixedeffects_FDiv) 

# Effects plot that includes raw data points
FDiv_effects <- ggpredict(beta_mixedeffects_FDiv, terms = c("site", "depth_layer"))

# Reorder factor x (aka site) so that points align correctly on the plot below
FDiv_effects$x <- ordered(FDiv_effects$x, levels = c("Neddie's Harbour", "Newman Sound", "St. Paul's"))

FDiv_by_site_DL_effects_plot <- ggplot(data = FD_two_DL_FDivNA_rm, aes(x = depth_layer, y = FDiv, colour = site)) + 
  geom_point(aes(x = depth_layer, y = FDiv),
             position = position_jitterdodge(jitter.width = 0.09), size = 3, alpha = 0.4) + 
  geom_point(data = FDiv_effects, aes(x = group, y = predicted, colour = x),
             position = position_dodge(width = 0.75), size = 3) + 
  geom_errorbar(data = FDiv_effects, aes(x = group, y = predicted, ymin = conf.low, ymax = conf.high, colour = x), width = 0.1, size = 1,
                position = position_dodge(width = 0.75)) + 
  labs(x = "Depth layer (cm)", y = "Functional diversity (FDiv)") +
  theme(legend.position = c(0.2, 0.1)) +
  scale_colour_brewer(name = "", palette = "Dark2")

# Save plot
ggsave(filename = "figures/FDiv_by_site_DL_effects_plot.png", plot = FDiv_by_site_DL_effects_plot, 
       width = 10, height = 10, units = "in", dpi = 300)

# Model summary table - Fixed effects
broom.mixed::tidy(beta_mixedeffects_FDiv) %>% 
  # Specify the number of decimal places you'd like in the table
  mutate(across(where(is.numeric), ~round(., 3))) %>%
  # For very small p-value, replace with "<0.001" for ease of reading
  mutate(p.value = if_else(p.value == 0.000, "< 0.001", as.character(p.value))) %>% 
  # Remove random effects 
  filter(effect == "fixed") %>% 
  # Remove unneeded columns 
  select(-effect, -component, -group) %>% 
  # Rename column headers for table to make them more legible
  rename("Fixed effects" = "term",
         "Estimate" = "estimate",
         "SE" = "std.error",
         "t-statistic" = "statistic", 
         "p-value" = "p.value") %>% 
  # Create table 
  flextable()

# Model summary table - Random effects
broom.mixed::tidy(beta_mixedeffects_FDiv) %>% 
  # Specify the number of decimal places you'd like in the table
  mutate(across(where(is.numeric), ~round(., 3))) %>% 
  # Remove random effects 
  filter(effect == "ran_pars") %>% 
  # Only keep columns we need! 
  select(group, estimate) %>% 
  # Rename column headers for table to make them more legible
  rename("Random effects, ~1|coreID" = "group",
         "SD" = "estimate") %>% 
  # Create table 
  flextable()

# Table showing ANOVA (p-value) component of model output 
broom::tidy(beta_mixed_FDiv_Anova) %>% 
  # Specify the number of decimal places you'd like in the table
  mutate(across(where(is.numeric), ~round(., 3))) %>% 
  # For very small p-value, replace with "<0.001" for ease of reading
  mutate(p.value = if_else(p.value == 0.000, "< 0.001", as.character(p.value))) %>% 
  # Rename column headers for table to make them more legible
  rename("Term" = "term",
         "Chi Sq." = "statistic",
         "p-value" = "p.value") %>% 
  # Create table 
  flextable()


# Summary tables (TD & FD) ----
# Average & SD for each diversity index for each of the two depth layers

# Summary table for TD indices
TD_summary <- TD_indices_two_DL %>% 
  select(site, depth_layer, two_DL_shannon, two_DL_simpson, two_DL_richness, two_DL_pielous_evenness) %>% 
  group_by(site, depth_layer) %>% 
  summarise(mean = across(two_DL_shannon:two_DL_pielous_evenness, ~mean(., na.rm = TRUE)),
            sd = across(two_DL_shannon:two_DL_pielous_evenness, ~sd(., na.rm = TRUE)))

# Summary table for FD indices
FD_summary <- FD_two_DL %>% 
  select(site, depth_layer, FRic, FDiv, FEve) %>% 
  group_by(site, depth_layer) %>% 
  summarise(mean = across(FRic:FEve, ~mean(., na.rm = TRUE)),
            sd = across(FRic:FEve, ~sd(., na.rm = TRUE)))


# Compare indices between depth layers -----

TD_indices_DL_comparison <- TD_indices_two_DL %>% 
  pivot_longer(where(is.numeric), names_to = "index", values_to = "value") %>% 
  pivot_wider(names_from = depth_layer, values_from = value) %>% 
  mutate(index = str_remove(index, "two_DL_"))

FD_indices_DL_comparison <- FD_two_DL %>% 
  pivot_longer(where(is.numeric), names_to = "index", values_to = "value") %>% 
  pivot_wider(names_from = depth_layer, values_from = value) %>% 
  mutate(index = str_remove(index, "two_DL_"))%>% 
  filter(!index %in% c("Nb_sp", "Tot_weight"))

all_indices_DL_comparison <- full_join(TD_indices_DL_comparison, FD_indices_DL_comparison)

# Wilcoxon Rank Sign Test  ----
# This is like t-test but non-parametric because not all indices are normally distributed
df_w <- map(unique(all_indices_DL_comparison$site), function(site) {
  df <- all_indices_DL_comparison %>% 
    filter(site == {{ site }})
  
  map(unique(df$index), function(index) {
    df2 <- df %>% 
      filter(index == {{ index }})
    
    broom::tidy(wilcox.test(df2$`0-2`, df2$`2-10`))
    
  }) %>% 
    set_names(nm = unique(df$index)) %>% 
    bind_rows(.id = "index")
  
}) %>% 
  set_names(nm = unique(all_indices_DL_comparison$site)) %>% 
  bind_rows(.id = "site")

# Format table that includes p-values and test statistic outputs for each DL pair 
wilcoxon_all_indices <- df_w %>% 
  select(site, index, statistic, p.value) %>% 
  pivot_wider(names_from = site, values_from = c(statistic, p.value)) %>% 
  mutate(across(where(is.numeric), ~ round(., 4))) %>% 
  select(index, contains("Neddie's Harbour"), contains("Newman Sound"), contains("St. Paul's"))

flextable(wilcoxon_all_indices) %>% 
  add_header_row(top = TRUE,
                 values = c("", "Neddie's Harbour", "Newman Sound", "St. Paul's"),
                 colwidths = c(1, 2, 2, 2))


#### END ####