## Rare species
## By: Mary Clinton
## Date created: March 28, 2022
## Date last modified: June 3, 2023

# Load libraries
library(tidyverse) # Data wrangling/cleaning

# Load data 
abundances <- read.csv("data/processed/abundances_by_core.csv", header = TRUE)
binned_abundances <- read.csv("data/processed/abundances_by_core_for_calculation_of_indices.csv", header = TRUE)

# Prep data 
# Add columns for site and collection_number
abundances <- abundances %>%   
  mutate(site = str_sub(core_id, 1, 2),
         collection_number = str_sub(core_id, 1, 3)) %>% 
  select(-X)

binned_abundances <- binned_abundances %>%   
  mutate(site = str_sub(core_id, 1, 2),
         collection_number = str_sub(core_id, 1, 3)) %>% 
  select(-X)


# THRESHOLD-BASED DEFINTION OF RARE SPP. ----
### Define and filter ----

# Rare = taxa represented by no more than 5 individuals at a given site

# Filter out rare species at each site, based on the definition of rarity
rare_abundances <- map_df(c("AC", "NH", "SP"), function(x) {
  # This chunk gets the names of all rare taxa and saves them in rare_spp
  rare_spp <- abundances %>% 
    # Filter each specific site
    filter(site == x) %>% 
    # Group by site, while keeping other columns
    group_by(site, .add = TRUE) %>% 
    # Sum total abundance for each taxa within each site
    summarise(across(.cols = where(is.numeric), sum)) %>% 
    # Convert to long format to make it easier to filter rare species
    pivot_longer(cols = where(is.numeric), names_to = "taxa", values_to = "abundance") %>% 
    # Define rarity and keep only the rows that meet that criteria
    filter(abundance < 6 & abundance > 0) %>% 
    # Pull out taxon names for rare species
    pull(taxa)
  
  # Filter the original data frame so that it only contains taxa listed in rare_spp
  abundances %>% 
    filter(site == x) %>% 
    select(site, collection_number, contains(rare_spp)) %>% 
    group_by(collection_number) %>% 
    mutate(across(.cols = rare_spp, ~sum(., na.rm = TRUE))) %>% 
    distinct
  
})


### Heat map ----

rare_abundances %>% 
  mutate(site = case_when(
    site == "AC" ~ "NS",
    site == "NH" ~ "NH",
    site == "SP" ~ "SP")) %>% 
  mutate(collection_number = case_when(
    collection_number == "AC1" ~ "NS1",
    collection_number == "AC2" ~ "NS2",
    collection_number == "AC3" ~ "NS3",
    TRUE ~ collection_number
  )) %>% 
  # Convert to long format to make it easier to plot
  pivot_longer(cols = where(is.numeric), names_to = "taxa", values_to = "abundance") %>% 
  # Add a column to the data frame so that taxa can be ordered in the plot by shared/not shared
  mutate(order_index = case_when(
    site == "NH" & !is.na(abundance) ~ "3",
    site == "NS" & !is.na(abundance) ~ "4",
    site == "SP" & !is.na(abundance) ~ "2",
    TRUE ~ "1"
  )) %>% 
  # Plot
  ggplot() + 
  # Plot taxa by collection number, ordered by whether the taxa are shared between sites
  geom_tile(aes(x = collection_number, y = fct_reorder(taxa, as.numeric(order_index)), fill = abundance)) +
  scale_fill_distiller(type = "seq", palette = "Blues", direction = 1) +
  scale_x_discrete(expand = c(0, 0, 0, 0.1)) +
  labs(x = "Collection ID", y = "Taxa", fill = "Abundance") +
  theme_minimal(base_size = 20) + 
  theme(panel.border = element_rect(size = 1, fill = NA),
        panel.grid = element_blank(), 
        axis.title.y = element_text(vjust = 3),
        axis.title.x = element_text(vjust = -1))



# PERCENTAGE-BASED DEFINTION OF RARE SPP. ----

#### Define and filter ----

# Rare = taxa that make up < 1% of the total macrofauna at a given site 

# Filter out rare species at each site, based on the definition of rarity
rare_abundances_percent <- map_df(c("AC", "NH", "SP"), function(x) {
  # This chunk gets the names of all rare taxa and saves them in rare_spp
  rare_spp <- abundances %>% 
    # Filter each specific site
    filter(site == x) %>% 
    # Group by site, while keeping other columns
    group_by(site, .add = TRUE) %>% 
    # Sum total abundance for each taxa within each site
    summarise(across(.cols = where(is.numeric), sum)) %>% 
    # Add a column to the data frame so that taxa can be ordered in the plot by shared/not shared
    mutate(most_abund = case_when(
      site == "AC" ~ "1338", 
      site == "NH" ~ "1874",
      site == "SP" ~ "2656")) %>% 
    # Convert to long format to make it easier to filter rare species
    pivot_longer(cols = where(is.numeric), names_to = "taxa", values_to = "abundance") %>% 
    # Define rarity and keep only the rows that meet that criteria
    filter(abundance < 0.01 * as.numeric(most_abund)) %>% 
    # Pull out taxon names for rare species
    pull(taxa)
  
  # Filter the original data frame so that it only contains taxa listed in rare_spp
  abundances %>% 
    filter(site == x) %>% 
    select(site, collection_number, contains(rare_spp)) %>% 
    group_by(collection_number) %>% 
    mutate(across(.cols = rare_spp, ~sum(., na.rm = TRUE))) %>% 
    distinct
  
})


#### Heat map ----

rare_abundances_percent %>% 
  mutate(site = case_when(
    site == "AC" ~ "NS",
    site == "NH" ~ "NH",
    site == "SP" ~ "SP")) %>% 
  mutate(collection_number = case_when(
    collection_number == "AC1" ~ "NS1",
    collection_number == "AC2" ~ "NS2",
    collection_number == "AC3" ~ "NS3",
    TRUE ~ collection_number
  )) %>%
  # Convert to long format to make it easier to plot
  pivot_longer(cols = where(is.numeric), names_to = "taxa", values_to = "abundance") %>% 
  # Add a column to the data frame so that taxa can be ordered in the plot by shared/not shared
  mutate(order_index = case_when(
    site == "NH" & !is.na(abundance) ~ "3",
    site == "NS" & !is.na(abundance) ~ "4",
    site == "SP" & !is.na(abundance) ~ "2",
    TRUE ~ "1"
  )) %>% 
  # Plot 
  ggplot() + 
  # Plot taxa by collection number, ordered by whether the taxa are shared between sites
  geom_tile(aes(x = collection_number, y = fct_reorder(taxa, as.numeric(order_index)), fill = abundance)) +
  scale_fill_distiller(type = "seq", palette = "Blues", direction = 1) +
  scale_x_discrete(expand = c(0, 0, 0, 0.1)) +
  labs(x = "Collection ID", y = "Taxa", fill = "Abundance") +
  theme_minimal(base_size = 15) + 
  theme(panel.border = element_rect(size = 1, fill = NA),
        panel.grid = element_blank(), 
        axis.title.y = element_text(vjust = 3),
        axis.title.x = element_text(vjust = -1))


# PATCHINESS DEFINITION ----
#### Define and filter ----

# Rare = taxa that appear in fewer than 3 cores at a given site 

# Filter out rare species at each site, based on the definition of rarity
patchy <- map_df(c("AC", "NH", "SP"), function(x) {
  # This chunk gets the names of all rare taxa and saves them in rare_spp
  patchy_spp <- abundances %>% 
    mutate(across(.cols = where(is.numeric), ~ ifelse(. > 0, 1, 0))) %>% 
    # Filter each specific site
    filter(site == x) %>% 
    # Group by site, while keeping other columns
    group_by(site, .add = TRUE) %>% 
    summarise(across(.cols = where(is.numeric), sum)) %>% 
    # Convert to long format to make it easier to filter rare species
    pivot_longer(cols = where(is.numeric), names_to = "taxa", values_to = "num_cores") %>% 
    # Define rarity and keep only the rows that meet that criteria
    filter(num_cores < 3 & num_cores > 0) %>% 
    # Pull out taxon names for rare species
    pull(taxa)
    
    # Filter the original data frame so that it only contains taxa listed in rare_spp
  abundances %>% 
    filter(site == x) %>% 
    select(site, collection_number, contains(patchy_spp)) %>% 
    group_by(collection_number) %>% 
    mutate(across(.cols = patchy_spp, ~sum(., na.rm = TRUE))) %>% 
    distinct
  
})


### Heat map ----

patchy %>% 
  mutate(site = case_when(
    site == "AC" ~ "NS",
    site == "NH" ~ "NH",
    site == "SP" ~ "SP")) %>% 
  mutate(collection_number = case_when(
    collection_number == "AC1" ~ "NS1",
    collection_number == "AC2" ~ "NS2",
    collection_number == "AC3" ~ "NS3",
    TRUE ~ collection_number
  )) %>% 
  # Convert to long format to make it easier to plot
  pivot_longer(cols = where(is.numeric), names_to = "taxa", values_to = "abundance") %>% 
  # Add a column to the data frame so that taxa can be ordered in the plot by shared/not shared
  mutate(order_index = case_when(
    site == "NH" & !is.na(abundance) ~ "3",
    site == "NS" & !is.na(abundance) ~ "4",
    site == "SP" & !is.na(abundance) ~ "2",
    TRUE ~ "1"
  )) %>%
  # Plot
  ggplot() + 
  # Plot taxa by collection number, ordered by whether the taxa are shared between sites
  geom_tile(aes(x = collection_number, y = fct_reorder(taxa, as.numeric(order_index)), fill = abundance)) +
  scale_fill_distiller(type = "seq", palette = "Blues", direction = 1) +
  scale_x_discrete(expand = c(0, 0, 0, 0.1)) +
  labs(x = "Collection ID", y = "Taxa", fill = "Abundance") +
  theme_minimal(base_size = 20) + 
  theme(panel.border = element_rect(size = 1, fill = NA),
        panel.grid = element_blank(), 
        axis.title.y = element_text(vjust = 3),
        axis.title.x = element_text(vjust = -1))


# PATCHINESS + ABUNDANCE THRESHOLD ----

### Define and filter ----

# Rare = taxa represented by no more than 5 individuals AND who appear in fewer than 3 cores at a given site

# Filter out rare species at each site, based on the definition of rarity
patchy_and_rare <- map_df(c("AC", "NH", "SP"), function(x) {
  # This chunk gets the names of all the patchy taxa and saves them in patchy_spp
  patchy_spp <- abundances %>% 
    mutate(across(.cols = where(is.numeric), ~ ifelse(. > 0, 1, 0))) %>% 
    # Filter each specific site
    filter(site == x) %>% 
    # Group by site, while keeping other columns
    group_by(site, .add = TRUE) %>% 
    summarise(across(.cols = where(is.numeric), sum)) %>% 
    # Convert to long format to make it easier to filter rare species
    pivot_longer(cols = where(is.numeric), names_to = "taxa", values_to = "num_cores") %>% 
    # Define rarity and keep only the rows that meet that criteria
    filter(num_cores < 3 & num_cores > 0) %>% 
    # Pull out taxon names for rare species
    pull(taxa)
  
  # This chunk gets the names of all rare taxa and saves them in rare_spp
  rare_spp <- abundances %>% 
    # Filter each specific site
    filter(site == x) %>% 
    # Group by site, while keeping other columns
    group_by(site, .add = TRUE) %>% 
    # Sum total abundance for each taxa within each site
    summarise(across(.cols = where(is.numeric), sum)) %>% 
    # Convert to long format to make it easier to filter rare species
    pivot_longer(cols = where(is.numeric), names_to = "taxa", values_to = "abundance") %>% 
    # Define rarity and keep only the rows that meet that criteria
    filter(abundance < 6 & abundance > 0) %>% 
    # Pull out taxon names for rare species
    pull(taxa)
  
  # This creates a vector of all taxa that are both patchy and rare
  patchy_and_rare <- intersect(patchy_spp, rare_spp)
  
  # Filter the original data frame so that it only contains taxa listed in rare_spp
  abundances %>% 
    filter(site == x) %>% 
    select(site, collection_number, contains(patchy_and_rare)) %>% 
    group_by(collection_number) %>% 
    mutate(across(.cols = patchy_and_rare, ~sum(., na.rm = TRUE))) %>% 
    distinct
  
})

### Heat map ----

patchy_and_rare %>% 
  mutate(site = case_when(
    site == "AC" ~ "NS",
    site == "NH" ~ "NH",
    site == "SP" ~ "SP")) %>% 
  mutate(collection_number = case_when(
    collection_number == "AC1" ~ "NS1",
    collection_number == "AC2" ~ "NS2",
    collection_number == "AC3" ~ "NS3",
    TRUE ~ collection_number
  )) %>% 
  # Convert to long format to make it easier to plot
  pivot_longer(cols = where(is.numeric), names_to = "taxa", values_to = "abundance") %>% 
  # Add a column to the data frame so that taxa can be ordered in the plot by shared/not shared
  mutate(order_index = case_when(
    site == "NH" & !is.na(abundance) ~ "2",
    site == "NS" & !is.na(abundance) ~ "3",
    site == "SP" & !is.na(abundance) ~ "4",
    TRUE ~ "1"
  )) %>% 
  # Plot
  ggplot() + 
  # Plot taxa by collection number, ordered by whether the taxa are shared between sites
  geom_tile(aes(x = collection_number, y = reorder(taxa, as.numeric(order_index)), fill = abundance)) +
  scale_fill_distiller(type = "seq", palette = "YlOrRd", direction = 1) +
  scale_x_discrete(expand = c(0, 0, 0, 0.1)) +
  labs(x = "Collection ID", y = "Taxa", fill = "Abundance") +
  theme_minimal(base_size = 20) + 
  theme(panel.border = element_rect(size = 1, fill = NA),
        panel.grid = element_blank(), 
        axis.title.y = element_text(vjust = 3),
        axis.title.x = element_text(vjust = -1))


# PATCHINESS + PERCENTAGE THRESHOLD* ----

### Define and filter ----

# Rare = taxa represented by no more than 5 individuals (for NS & SP) or no more than 4 individuals for NH
# AND who appear in < 10% of cores at a given site

# Filter out rare species at each site, based on the definition of rarity
patchy_and_percent <- map_df(c("AC", "NH", "SP"), function(x) {
  # This chunk gets the names of all the patchy taxa and saves them in patchy_spp
  patchy_spp <- abundances %>% 
    # Convert abundances to presence/absence (1/0)
    mutate(across(.cols = where(is.numeric), ~ ifelse(. > 0, 1, 0))) %>% 
    # Filter each specific site
    filter(site == x) %>% 
    # Group by site, while keeping other columns the same
    group_by(site, .add = TRUE) %>% 
    summarise(across(.cols = where(is.numeric), sum)) %>% 
    # Add column to data frame that indicates the total number of cores collected at that site
    mutate(total_cores = case_when(
      site == "AC" ~ "33",
      site == "NH" ~ "24",
      site == "SP" ~ "33"
    )) %>% 
    # Convert to long format to make it easier to filter rare species
    pivot_longer(cols = where(is.numeric), names_to = "taxa", values_to = "num_cores") %>% 
    # Define rarity and keep only the rows that meet that criteria
    filter(num_cores < 0.1 * as.numeric(total_cores)) %>% 
    # Pull out taxon names for rare species
    pull(taxa)
  
  # This chunk gets the names of all rare taxa and saves them in rare_spp
  rare_spp <- abundances %>% 
    # Filter each specific site
    filter(site == x) %>% 
    # Group by site, while keeping other columns
    group_by(site, .add = TRUE) %>% 
    # Sum total abundance for each taxa within each site
    summarise(across(.cols = where(is.numeric), sum)) %>% 
    # Convert to long format to make it easier to filter rare species
    pivot_longer(cols = where(is.numeric), names_to = "taxa", values_to = "abundance") %>% 
    # Define rarity and keep only the rows that meet that criteria
    filter(abundance < 6 & abundance != 0) %>% 
    # Pull out taxon names for rare species
    pull(taxa)
  
  # This creates a vector of all taxa that are both patchy and rare
  patchy_and_percent <- intersect(patchy_spp, rare_spp)
  
  # Filter the original data frame so that it only contains taxa listed in rare_spp
  abundances %>% 
    filter(site == x) %>% 
    select(site, collection_number, contains(patchy_and_percent)) %>% 
    group_by(collection_number) %>% 
    mutate(across(.cols = patchy_and_percent, ~sum(., na.rm = TRUE))) %>% 
    distinct
  
})

### Heat map ----

patchy_percent_plot <- patchy_and_percent %>% 
  mutate(site = case_when(
    site == "AC" ~ "NS",
    site == "NH" ~ "NH",
    site == "SP" ~ "SP")) %>% 
  mutate(collection_number = case_when(
    collection_number == "AC1" ~ "NS1",
    collection_number == "AC2" ~ "NS2",
    collection_number == "AC3" ~ "NS3",
    TRUE ~ collection_number
  )) %>% 
  # Convert to long format to make it easier to plot
  pivot_longer(cols = where(is.numeric), names_to = "taxa", values_to = "abundance") %>% 
  # Add a column to the data frame so that taxa can be ordered in the plot by shared/not shared
  mutate(order_index = case_when(
    site == "NH" & !is.na(abundance) ~ "2",
    site == "NS" & !is.na(abundance) ~ "3",
    site == "SP" & !is.na(abundance) ~ "4",
    TRUE ~ "1"
  )) %>% 
  # Plot
  ggplot() + 
  # Plot taxa by collection number, ordered by whether the taxa are shared between sites
  geom_tile(aes(x = collection_number, y = reorder(taxa, as.numeric(order_index)), fill = abundance)) +
  scale_fill_distiller(type = "seq", palette = "YlOrRd", direction = 1) +
  scale_x_discrete(expand = c(0, 0, 0, 0.1)) +
  labs(x = "Collection ID", y = "Taxa", fill = "Abundance") +
  theme_minimal(base_size = 20) + 
  theme(panel.border = element_rect(size = 1, fill = NA),
        panel.grid = element_blank(), 
        axis.title.y = element_text(vjust = 3),
        axis.title.x = element_text(vjust = -1))

# Save plot
tiff("figures/rarity_heatmap_patchy_percentage.tiff", width = 12, height = 9, units = "in", res = 300)
patchy_percent_plot
dev.off()


# Binned taxa: PATCHINESS + PERCENTAGE THRESHOLD ----
# This is the definition used in final version of Clinton et al. (in revision)

### Define and filter ----

# Rare = taxa represented by no more than 5 individuals AND who appear in < 10% of cores at a given site

# Filter out rare species at each site, based on the definition of rarity
binned_patchy_and_percent <- map_df(c("AC", "NH", "SP"), function(x) {
  # This chunk gets the names of all the patchy taxa and saves them in patchy_spp
  patchy_spp <- binned_abundances %>% 
    mutate(across(.cols = where(is.numeric), ~ ifelse(. > 0, 1, 0))) %>% 
    # Filter each specific site
    filter(site == x) %>% 
    # Group by site, while keeping other columns
    group_by(site, .add = TRUE) %>% 
    summarise(across(.cols = where(is.numeric), sum)) %>% 
    # Add column to data frame that indicates the total number of cores collected at that site
    mutate(total_cores = case_when(
      site == "AC" ~ "33",
      site == "NH" ~ "24",
      site == "SP" ~ "33"
    )) %>% 
    # Convert to long format to make it easier to filter rare species
    pivot_longer(cols = where(is.numeric), names_to = "taxa", values_to = "num_cores") %>% 
    # Define rarity and keep only the rows that meet that criteria
    filter(num_cores < 0.1 * as.numeric(total_cores)) %>% 
    # Pull out taxon names for rare species
    pull(taxa)
  
  # This chunk gets the names of all rare taxa and saves them in rare_spp
  rare_spp <- binned_abundances %>% 
    # Filter each specific site
    filter(site == x) %>% 
    # Group by site, while keeping other columns
    group_by(site, .add = TRUE) %>% 
    # Sum total abundance for each taxa within each site
    summarise(across(.cols = where(is.numeric), sum)) %>% 
    # Convert to long format to make it easier to filter rare species
    pivot_longer(cols = where(is.numeric), names_to = "taxa", values_to = "abundance") %>% 
    # Define rarity and keep only the rows that meet that criteria
    filter(abundance < 6 & abundance != 0) %>% 
    # Pull out taxon names for rare species
    pull(taxa)
  
  # This creates a vector of all taxa that are both patchy and rare
  patchy_and_percent <- intersect(patchy_spp, rare_spp)
  
  # Filter the original data frame so that it only contains taxa listed in rare_spp
  binned_abundances %>% 
    filter(site == x) %>% 
    select(site, collection_number, contains(patchy_and_percent)) %>% 
    group_by(collection_number) %>% 
    mutate(across(.cols = patchy_and_percent, ~sum(., na.rm = TRUE))) %>% 
    distinct
  
})

### Heat map ----

binned_patchy_percent_plot <- binned_patchy_and_percent %>% 
  mutate(site = case_when(
    site == "AC" ~ "NS",
    site == "NH" ~ "NH",
    site == "SP" ~ "SP")) %>% 
  mutate(collection_number = case_when(
    collection_number == "AC1" ~ "NS1",
    collection_number == "AC2" ~ "NS2",
    collection_number == "AC3" ~ "NS3",
    TRUE ~ collection_number
  )) %>% 
  # Convert to long format to make it easier to plot
  pivot_longer(cols = where(is.numeric), names_to = "taxa", values_to = "abundance") %>% 
  # Add a column to the data frame so that taxa can be ordered in the plot by shared/not shared
  mutate(order_index = case_when(
    site == "NH" & !is.na(abundance) ~ "2",
    site == "NS" & !is.na(abundance) ~ "3",
    site == "SP" & !is.na(abundance) ~ "4",
    TRUE ~ "1"
  )) %>% 
  # Remove period from taxon names between Genus and species
  mutate(taxa = str_replace_all(taxa, "[.]", " ")) %>% 
  mutate(taxa = case_when(
    str_detect(taxa, "sp") ~ paste0(taxa, "."), 
    str_detect(taxa, "indet") ~ paste0(taxa, "."), 
    TRUE ~ taxa
  )) %>% 
  # Plot
  ggplot() + 
  # Plot taxa by collection number, ordered by whether the taxa are shared between sites
  geom_tile(aes(x = collection_number, y = reorder(taxa, as.numeric(order_index)), fill = abundance)) +
  scale_fill_distiller(type = "seq", palette = "YlOrRd", direction = 1) +
  scale_x_discrete(expand = c(0, 0, 0, 0.1)) +
  labs(x = "Collection ID", y = "Taxa", fill = "Abundance") +
  theme_minimal(base_size = 20) + 
  theme(panel.border = element_rect(size = 1, fill = NA),
        panel.grid = element_blank(), 
        axis.title.y = element_text(vjust = 3),
        axis.title.x = element_text(vjust = -1))

# Save plot
tiff("figures/rarity_heatmap_patchy_percentage_binned_taxa.tiff", width = 12, height = 9, units = "in", res = 300)
binned_patchy_percent_plot
dev.off()
