## Power analysis 
## By: Mary Clinton
## Date created: March 31, 2023
## Date last modified: February 9, 2024

# Load packages 
library(tidyverse)  # Data wrangling 
library(cowplot)    # Multi-panel plots
library(flextable)  # Publication-ready summary tables
library(glmmTMB)    # Beta mixed effects models 
library(car)        # Anova
library(lme4)       # Mixed effects models

# Set theme for plots 
theme_MEC <- function () { 
  theme_bw(base_size = 12) + 
    theme(panel.grid.major = element_blank(), panel.grid.minor = element_blank(), 
          axis.line = element_line(colour = "black"), 
          axis.text = element_text(size = 16, face = "plain"), 
          axis.title = element_text(size = 18, face = "plain"),
          legend.text = element_text(size = 16, face = "plain"), 
          legend.title = element_text(size = 18, face = "bold"))
} 
theme_set(theme_MEC())

# Load data 
TD_indices <- read.csv("data/processed/TD_indices.csv")
FD_indices <- read.csv("data/processed/FD_indices.csv")
TD_indices_two_DL <- read.csv("data/processed/TD_indices_two_depth_layers.csv")
FD_indices_two_DL <- read.csv("data/processed/FD_indices_two_depth_layers.csv")

# Prep data 
# Join taxonomic diversity and functional diversity indices into one data frame
all_indices <- TD_indices %>%
  left_join(FD_indices) %>% 
  select(site, core_id, shannon, simpson, richness, pielous_evenness, FRic, FEve, FDiv)

all_indices_two_DL <- TD_indices_two_DL %>% 
  rename(shannon = two_DL_shannon,
         simpson = two_DL_simpson,
         richness = two_DL_richness,
         pielous_evenness = two_DL_pielous_evenness) %>% 
  left_join(FD_indices_two_DL) %>% 
  select(site, core_id, depth_layer, shannon, simpson, richness, pielous_evenness, FRic, FEve, FDiv)
  
# By core ----

# Function to randomly subset x cores from each site 
sample_cores <- function(.data, .n) {
  slice_sample(.data, n = .n, by = site) %>% 
    group_by(site) %>% 
    summarise(across(where(is.numeric), ~mean(., na.rm = TRUE)))
}

# Set the number of samples to take for each subset 
num_samples <- c(3, 5, 10, 15, 20)

# Randomly sample X cores from each site & repeat 10,000 times 
# Then return the mean + SD for each diversity index 
set.seed(123)

sampled_diversity_indices <- purrr::map(num_samples, function(num) {
  replicate(10000, sample_cores(all_indices, .n = num), simplify = FALSE) %>% 
    # Combine all 1000 samples into a single data frame 
    bind_rows(., .id = "iteration_number") %>% 
    group_by(site) %>% 
    summarise(mean = across(where(is.numeric), ~mean(., na.rm = TRUE)),
              sd = across(where(is.numeric), ~sd(., na.rm = TRUE))) %>%
    unnest(cols = c(mean, sd), names_sep = "_")
  
}) %>% 
  # Name each list element after the # of cores subset 
  set_names(., nm = glue::glue("subset_{num_samples}")) %>% 
  bind_rows(., .id = "subset") %>% 
  mutate(subset_number = as.numeric(str_extract(subset, "\\d+")))

# Save this output so it doesn't have to be run every time 
saveRDS(sampled_diversity_indices, "data/power/sampled-diversity-indices.rds")

# Summary table (means +/- SDs for all indices)
sampled_diversity_indices %>% 
  select(-subset_number) %>% 
  rename("mean_pielous" = "mean_pielous_evenness",
         "sd_pielous" = "sd_pielous_evenness") %>% 
  pivot_longer(cols = where(is.numeric), 
               names_to = c("statistic", "index"), 
               values_to = "value",
               names_sep = "_") %>% 
  pivot_wider(names_from = statistic, values_from = value) %>% 
  mutate(mean_sd = paste(round(mean, 3), "+/-", round(sd, 3))) %>% 
  select(-mean, -sd) %>% 
  pivot_wider(names_from = index, values_from = mean_sd) %>% 
  flextable::as_grouped_data(groups = "subset") %>% 
  flextable::flextable()


# Use iterated data frame (mean of means & sd of means) to plot each index 
# for each site/subset combination
mean_columns <- colnames(sampled_diversity_indices)[str_detect(colnames(sampled_diversity_indices), "mean")]
sd_columns <- colnames(sampled_diversity_indices)[str_detect(colnames(sampled_diversity_indices), "sd")]
y_axis_labels <- c("Shannon-Wiener (H')", "Simpson's (d)", "Taxonomic richness (S)", "Pielou's evenness (J')",
                   "Functional richness (FRic)", "Functional evenness (FEve)", "Functional divergence (FDiv)")


# First, make a plot with a legend they can all share 

plot_for_legend_purposes <- sampled_diversity_indices %>% 
  ggplot() + 
  geom_errorbar(aes(x = subset_number, y = mean_shannon,
                    ymin = mean_shannon - sd_shannon, ymax = mean_shannon + sd_shannon),
                width = 0.3, colour = "grey70") + 
  geom_ribbon(aes(x = subset_number,
                  ymin = mean_shannon - sd_shannon,
                  ymax = mean_shannon + sd_shannon,
                  fill = site), alpha = 0.2) + 
  geom_point(aes(x = subset_number, y = mean_shannon, colour = site), size = 2) + 
  scale_colour_brewer(palette = "Dark2") + 
  scale_fill_brewer(palette = "Dark2") + 
  scale_x_continuous(breaks = c(3, 5, 10, 15, 20)) + 
  labs(x = " ", fill = "Site", colour = "Site")

# Extract the legend and add it to the multipanel plots below 
legend <- cowplot::get_legend(
  # Create some space to the left of the legend
  plot_for_legend_purposes + theme(legend.box.margin = margin(0, 0, 0, 12)))


# Now make the plot
subset_plots <- purrr::map(1:length(mean_columns), function(index) {
  index_mean <- mean_columns[index]
  index_SD <- sd_columns[index]
  y_label <- y_axis_labels[index]
  
  sampled_diversity_indices %>% 
    ggplot() + 
    # Plot SD error bars 
    geom_errorbar(aes(x = subset_number, y = .data[[index_mean]], 
                      ymin = .data[[index_mean]] - .data[[index_SD]], ymax = .data[[index_mean]] + .data[[index_SD]]),
                  width = 0.8,
                  colour = "grey70") + 
    geom_ribbon(aes(x = subset_number,
                    ymin = .data[[index_mean]] - .data[[index_SD]],
                    ymax = .data[[index_mean]] + .data[[index_SD]],
                    fill = site), alpha = 0.2) +
    # Plot mean values as a coloured point
    geom_point(aes(x = subset_number, y = .data[[index_mean]], colour = site), size = 2) + 
    scale_colour_brewer(palette = "Dark2") + 
    scale_fill_brewer(palette = "Dark2") + 
    scale_x_continuous(breaks = c(3, 5, 10, 15, 20)) + 
    theme(legend.position = "none") + 
    labs(x = " ", y = y_label, fill = "Site", colour = "Site")
})

# Add a "plot" (the shared legend) to the list of plots
subset_plots[[8]] <- legend

#Make multi-panel plot with all indices 
all_subset_plots <- cowplot::plot_grid(plotlist = list(subset_plots[[3]], subset_plots[[4]], subset_plots[[1]], subset_plots[[2]],
                                                    subset_plots[[5]], subset_plots[[6]], subset_plots[[7]], subset_plots[[8]]), 
                                                    labels = LETTERS[1:7], align = "v", axis = "l", ncol = 4) 

all_subset_plots_common_xlab <- ggdraw(add_sub(all_subset_plots, "Number of cores", 
                                               vpadding = grid::unit(0, "lines"), y = 6, x = 0.5, vjust = 4.5, 
                                               size = 18))

# Save subset plot
tiff("figures/subsets_plot_all_sites.tiff", width = 12, height = 9, units = "in", res = 300)
all_subset_plots_common_xlab
dev.off()


# By depth layer ----

# Re-arrange data frame so that each core is a single row, with indices for each DL as columns
all_indices_two_DL_wide <- all_indices_two_DL %>% 
  pivot_wider(names_from = depth_layer, values_from = shannon:FDiv)


# Randomly sample cores
# Set the number of samples to take for each subset 
num_samples <- c(3, 5, 10, 15, 20)

# Randomly sample X cores from each site & repeat 10,000 times 
# Then return the mean + SD for each diversity index 
set.seed(123)

sampled_diversity_indices_DL <- purrr::map(num_samples, function(num) {
  replicate(10000, sample_cores(all_indices_two_DL_wide, .n = num), simplify = FALSE) %>% 
    # Combine all 1000 samples into a single data frame 
    bind_rows(., .id = "iteration_number") %>% 
    group_by(site) %>% 
    summarise(mean = across(where(is.numeric), ~mean(., na.rm = TRUE)),
              sd = across(where(is.numeric), ~sd(., na.rm = TRUE))) %>%
    unnest(cols = c(mean, sd), names_sep = "_")
  
}) %>% 
  # Name each list element after the # of cores subset 
  set_names(., nm = glue::glue("subset_{num_samples}")) %>% 
  bind_rows(., .id = "subset") %>% 
  mutate(subset_number = as.numeric(str_extract(subset, "\\d+")))

# Save this output so it doesn't have to be run every time 
saveRDS(sampled_diversity_indices_DL, "data/power/sampled-diversity-indices-DL.rds")

# Depth layer plots ----
# Fiddle with the depth-layer data frame so we get a column for depth layer
# and columns for each statistic_index combination
sampled_diversity_indices_DL_plot <- sampled_diversity_indices_DL %>% 
  select(-subset_number) %>%
  # Rename Pielou's evenness columns because there are too many underscores 
  rename("mean_pielous_0-2" = "mean_pielous_evenness_0-2",
         "sd_pielous_0-2" = "sd_pielous_evenness_0-2",
         "mean_pielous_2-10" = "mean_pielous_evenness_2-10",
         "sd_pielous_2-10" = "sd_pielous_evenness_2-10") %>% 
  pivot_longer(cols = where(is.numeric),
               names_to = c("statistic", "index", "depth_layer"),
               values_to = "value",
               names_sep = "_") %>% 
  pivot_wider(names_from = c("statistic", "index"),
              values_from = value) %>% 
  mutate(subset_number = as.numeric(str_extract(subset, "\\d+")),
         site_dl = paste0(site, depth_layer, sep = "_"))

# Use iterated data frame (mean of means & sd of means) to plot each index 
mean_columns_DL <- colnames(sampled_diversity_indices_DL_plot)[str_detect(colnames(sampled_diversity_indices_DL_plot), "mean")]
sd_columns_DL <- colnames(sampled_diversity_indices_DL_plot)[str_detect(colnames(sampled_diversity_indices_DL_plot), "sd")]


# Plots, faceted by depth layer ----

subset_plots_by_DL <- purrr::map(1:length(mean_columns_DL), function(index) {
  index_mean <- mean_columns_DL[index]
  index_SD <- sd_columns_DL[index]
  y_label <- y_axis_labels[index]
  
  sampled_diversity_indices_DL_plot %>% 
    ggplot() + 
    # Plot SD error bars 
    geom_errorbar(aes(x = subset_number, y = .data[[index_mean]], 
                      ymin = .data[[index_mean]] - .data[[index_SD]], ymax = .data[[index_mean]] + .data[[index_SD]]),
                  width = 0.8,
                  colour = "grey70") + 
    # Here, we will the ribbon by the site_dl variable, so that we can manually
    # specify the colours
    geom_ribbon(aes(x = subset_number,
                    ymin = .data[[index_mean]] - .data[[index_SD]],
                    ymax = .data[[index_mean]] + .data[[index_SD]],
                    fill = site), alpha = 0.2) +
    # Plot mean values as a coloured point
    geom_point(aes(x = subset_number, 
                   y = .data[[index_mean]], 
                   colour = site, 
                   shape = depth_layer), size = 2) + 
    facet_wrap(~depth_layer) + 
    scale_colour_brewer(palette = "Dark2") + 
    scale_fill_brewer(palette = "Dark2") + 
    scale_x_continuous(breaks = c(3, 5, 10, 15, 20)) + 
    theme(legend.position = "none",
          strip.text = element_text(size = 12)) + 
    labs(x = " ", y = y_label)
  
}) 

# Add a "plot" (the shared legend) to the list of plots
subset_plots_by_DL[[8]] <- legend
  
# Make multi-panel plot with all indices 
all_subset_plots_by_DL <- cowplot::plot_grid(plotlist = list(subset_plots_by_DL[[3]], subset_plots_by_DL[[4]], subset_plots_by_DL[[1]], subset_plots_by_DL[[2]],
                                                             subset_plots_by_DL[[5]], subset_plots_by_DL[[6]], subset_plots_by_DL[[7]], subset_plots_by_DL[[8]]), 
                                             labels = LETTERS[1:7], align = "v", axis = "l", ncol = 2)

all_subset_plots_by_DL_common_xlab <-  ggdraw(add_sub(all_subset_plots_by_DL, "Number of cores", 
                                                      vpadding = grid::unit(0, "lines"), y = 6, x = 0.5, vjust = 4.5, 
                                                      size = 18))

# Save subset by DL plot
tiff("figures/subsets_plot_all_depth_layers.tiff", width = 12, height = 16, units = "in", res = 300)
all_subset_plots_by_DL_common_xlab
dev.off()


# Models: INDEX ~ SITE + DEPTH LAYER ----

# Function to randomly subset x cores from each site 
sample_cores_for_models <- function(.data, .n) {
  .data %>% 
    pivot_wider(names_from = depth_layer, values_from = shannon:FDiv) %>% 
    slice_sample(n = .n, by = site) %>% 
    rename("pielous_0-2" = "pielous_evenness_0-2",
           "pielous_2-10" = "pielous_evenness_2-10") %>% 
    pivot_longer(cols = where(is.numeric), 
                 names_to = c("index", "depth_layer"), 
                 values_to = "value",
                 names_sep = "_") %>% 
    pivot_wider(names_from = index, values_from = value)
    
}


## Model fitting/sampling: ----

# Note: TD indices do not need the drop_na() pre-processing step, so use the original sample_cores_for_models() function.

# Define functions:
fit_shannon <- function(.data, .num_samples) {
  sample_cores_for_models(.data, .n = .num_samples) %>% 
    lmer(shannon ~ site + depth_layer + (1 | core_id), data = ., REML = FALSE) %>% 
    Anova() %>% 
    broom::tidy()
}

fit_simpson <- function(.data, .num_samples) {
  .data %>% 
    filter(simpson != 0) %>% 
    sample_cores_for_models(., .n = .num_samples) %>% 
    glmmTMB(formula = simpson ~ depth_layer + site + (1 | core_id),
            data = ., family = beta_family(link="logit")) %>% 
    Anova() %>% 
    broom::tidy()
}

fit_richness <- function(.data, .num_samples) {
  sample_cores_for_models(.data, .n = .num_samples) %>% 
    lmer(richness ~ site + depth_layer + (1 | core_id), data = .) %>% 
    Anova() %>% 
    broom::tidy()
}

fit_pielous <- function(.data, .num_samples) {
  sample_cores_for_models(.data, .n = .num_samples) %>% 
    lmer(pielous ~ depth_layer + site + depth_layer*site + (1 | core_id), 
         data = ., REML = FALSE) %>% 
    Anova() %>% 
    broom::tidy()
}

fit_FRic <- function(.data, .num_samples) {
  .data %>% 
    pivot_wider(names_from = depth_layer, values_from = shannon:FDiv) %>% 
    drop_na(`FRic_0-2`, `FRic_2-10`) %>% 
    slice_sample(., n = .num_samples, by = site) %>% 
    rename("pielous_0-2" = "pielous_evenness_0-2",
           "pielous_2-10" = "pielous_evenness_2-10") %>% 
    pivot_longer(cols = where(is.numeric), 
                 names_to = c("index", "depth_layer"), 
                 values_to = "value",
                 names_sep = "_") %>% 
    pivot_wider(names_from = index, values_from = value) %>% 
    glmmTMB(formula = FRic ~ depth_layer + site + site*depth_layer + (1 | core_id),
            data = ., family = beta_family(link="logit")) %>% 
    Anova() %>% 
    broom::tidy()
}


fit_FEve <- function(.data, .num_samples) {
  .data %>% 
    pivot_wider(names_from = depth_layer, values_from = shannon:FDiv) %>% 
    drop_na(`FEve_0-2`, `FEve_2-10`) %>% 
    slice_sample(., n = .num_samples, by = site) %>% 
    rename("pielous_0-2" = "pielous_evenness_0-2",
           "pielous_2-10" = "pielous_evenness_2-10") %>% 
    pivot_longer(cols = where(is.numeric), 
                 names_to = c("index", "depth_layer"), 
                 values_to = "value",
                 names_sep = "_") %>% 
    pivot_wider(names_from = index, values_from = value) %>% 
    glmmTMB(formula = FEve ~ depth_layer + site + site*depth_layer + (1 | core_id),
            data = ., family = beta_family(link = "logit")) %>% 
    Anova() %>% 
    broom::tidy()
}

fit_FDiv <- function(.data, .num_samples) {
  .data %>% 
    pivot_wider(names_from = depth_layer, values_from = shannon:FDiv) %>% 
    drop_na(`FDiv_0-2`, `FDiv_2-10`) %>% 
    slice_sample(., n = .num_samples, by = site) %>% 
    rename("pielous_0-2" = "pielous_evenness_0-2",
           "pielous_2-10" = "pielous_evenness_2-10") %>% 
    pivot_longer(cols = where(is.numeric), 
                 names_to = c("index", "depth_layer"), 
                 values_to = "value",
                 names_sep = "_") %>% 
    pivot_wider(names_from = index, values_from = value) %>% 
    glmmTMB(formula = FDiv ~ depth_layer + site + site*depth_layer + (1 | core_id),
            data = ., family = beta_family(link = "logit")) %>% 
    Anova() %>% 
    broom::tidy()
}


fit_models <- function(.sample_data, .n = 10) {
  shannon <- try(fit_shannon(.data = .sample_data, .num_samples = .n))
  simpson <- try(fit_simpson(.data = .sample_data, .num_samples = .n))
  richness <- try(fit_richness(.data = .sample_data, .num_samples = .n))
  pielous <- try(fit_pielous(.data = .sample_data, .num_samples = .n))
  FRic <- try(fit_FRic(.data = .sample_data, .num_samples = .n))
  FEve <- try(fit_FEve(.data = .sample_data, .num_samples = .n))
  FDiv <- try(fit_FDiv(.data = .sample_data, .num_samples = .n))
  
  return(
    list(
      shannon = shannon,
      simpson = simpson,
      richness = richness,
      pielous = pielous,
      FRic = FRic,
      FEve = FEve,
      FDiv = FDiv
    )
  )
  
}

# Set the number of samples to take for each subset 
num_samples <- c(3, 5, 10, 15, 20)

# Set the number of iterations to run 
num_iterations <- 1000

# Randomly sample X cores from each site & repeat 1000 times 
# Then return the mean + SD for each diversity index 
set.seed(123)
start_time <- Sys.time()
sampled_diversity_indices_models <- purrr::map(num_samples, function(num, n_iter = num_iterations) {
  replicate(n_iter, fit_models(all_indices_two_DL, .n = num), simplify = FALSE) %>% 
    # Combine all 1000 samples into a single data frame 
    set_names(., nm = glue::glue("iteration {1:n_iter}"))
  
}) %>% 
  # Name each list element after the # of cores subset 
  set_names(., nm = glue::glue("subset_{num_samples}"))

end_time <- Sys.time()
end_time - start_time # Running 1000 took 5.3 hours 

# Save this
saveRDS(sampled_diversity_indices_models, 
        paste0("data/power/sampled-diversity-indices-models_", 
        num_iterations, "-iterations.rds")
)


# Post-process results ----
sampled_diversity_indices <- readRDS("data/power/sampled-diversity-indices.rds")
sampled_diversity_indices_DL <- readRDS("data/power/sampled-diversity-indices-DL.rds")
sampled_diversity_indices_models <- readRDS("data/power/sampled-diversity-indices-models_1000-iterations.rds")


# 1. Get model summary tables

sampled_diversity_indices_models %>% 
  pluck("subset_3") %>% 
  pluck("iteration 1") %>% 
  bind_rows(.id = "index")

# For each number of cores that was randomly sampled...
model_summary_tables <- purrr::map(num_samples, function(num) {
  
  # Retrieve the list of data for that subset number
  sampled_diversity_indices_models %>% 
    pluck(glue::glue("subset_{num}")) %>% 
    
    # Then, for each iteration in the subset number...
    purrr::map(., function(iteration) {
      
      # Retrieve the list of model summary tables for the iteration
      bind_rows(iteration, .id = "index")
      
    }) %>% 
    set_names(., nm = glue::glue("iteration {1:num_iterations}")) %>% 
    bind_rows(.id = "iteration")
  
}) %>% 
  set_names(., nm = glue::glue("subset {num_samples}")) %>% 
  bind_rows(.id = "num_samples")


# 2. Get the number of times a significant p-value was detected
model_summary_tables_processed <- model_summary_tables %>% 
  # Create a variable to indicate whether the p-value was significant or not + indicate whether the model failed
  mutate(significant = case_when(
    p.value < 0.05 ~ "significant",
    p.value >= 0.05 ~ "non_significant",
    is.na(p.value) ~ "failed model"
  )) %>% 
  # For each model term, for each index, for # of cores sampled
  group_by(num_samples, index, term) %>% 
  # Count the number of significant values, non-significant values, and failed models
  dplyr::count(significant) %>% 
  # Calculate proportion of significant, non-significant, and failed models
  # Out of the total models run
  mutate(proportion = n / num_iterations) %>% 
  # Make the data frame easier to read
  pivot_wider(names_from = significant, values_from = c(n, proportion)) %>% 
  # Change NAs to 0s
  mutate(across(where(is.numeric), ~if_else(is.na(.), 0, .)))

# Table of each index, term, and proportion of significant/non-significant tests 
model_summary_tables_processed %>%
  mutate(num_samples = str_remove(num_samples, "subset ")) %>% 
  mutate(term = case_when(
    term == "depth_layer" ~ "Depth layer",
    term == "depth_layer:site" ~ "Depth layer:Site",
    term == "site" ~ "Site"
  )) %>% 
  # Display proportion as percentage (0-100)
  mutate(proportion_significant = proportion_significant * 100) %>% 
  mutate(proportion_non_significant = proportion_non_significant *100) %>% 
  # Select which columns to display
  select(num_samples, index, term, proportion_non_significant, proportion_significant) %>% 
  # Group by number of cores subset
  flextable::as_grouped_data(groups = "num_samples") %>% 
  # Rename column headers for table to make them more legible
  rename("Number of cores" = "num_samples",
         "Index" = "index",
         "Model term" = "term",
         "Non-significant" = "proportion_non_significant",
         "Significant" = "proportion_significant") %>% 
  # Make table! 
  flextable()

# Plot that shows the proportion of significant tests (for each index & # of cores)
model_summary_tables_processed %>% 
  mutate(num_cores = as.numeric(str_extract(num_samples, "\\d+"))) %>% 
  ggplot() + 
  geom_point(aes(x = num_cores, y = proportion_significant, colour = term), size = 2) + 
  geom_line(
    aes(x = num_cores, y = proportion_significant, colour = term)) + 
  facet_wrap(~index) + 
  scale_colour_brewer(palette = "Dark2")


# Plot that shows proportion of BOTH significant AND non-significant tests for each index/# of cores
significance_figure <- model_summary_tables_processed %>% 
  pivot_longer(cols = contains("proportion"), 
               names_to = "significance",
               values_to = "proportion") %>% 
  mutate(num_cores = as.numeric(str_extract(num_samples, "\\d+"))) %>% 
  mutate(term = case_when(
    term == "depth_layer" ~  "Depth layer", 
    term == "depth_layer:site" ~ "Depth layer:Site",
    term == "site" ~ "Site"
  )) %>% 
  mutate(index = ifelse(index %in% c("pielous", "richness", "shannon", "simpson"), str_to_sentence(index), index)) %>%
  filter(significance != "proportion_failed model",
         !is.na(term)) %>% 
  mutate(significance = str_to_sentence(str_remove(significance, "proportion_"))) %>% 
  ggplot() + 
  geom_point(
    aes(x = num_cores, y = proportion, colour = significance), size = 2) + 
  geom_line(
    aes(x = num_cores, y = proportion, colour = significance)) + 
  # Add dashed line at 0.8 (80%) as reference for "target" power 
  geom_hline(yintercept = 0.8, linetype = "dotted") + 
  facet_grid(index ~ term) + 
  scale_colour_brewer(palette = "Dark2", direction = -1, name = " ") + 
  scale_x_continuous(breaks = c(3, 5, 10, 15, 20)) +
  theme(legend.position = "bottom",
        axis.text.y = element_text(size = 12), 
        strip.text = element_text(size = 12)) +
  labs(x = "Number of cores", y = "Proportion", colour = "Significance")

# Same figure as above, but with model terms on y-axis for conference presentations in PowerPoint format
significance_figure_wide <- model_summary_tables_processed %>% 
  pivot_longer(cols = contains("proportion"), 
               names_to = "significance",
               values_to = "proportion") %>% 
  mutate(num_cores = as.numeric(str_extract(num_samples, "\\d+"))) %>% 
  mutate(term = case_when(
    term == "depth_layer" ~  "Depth layer", 
    term == "depth_layer:site" ~ "Depth layer:Site",
    term == "site" ~ "Site"
  )) %>% 
  mutate(index = ifelse(index %in% c("pielous", "richness", "shannon", "simpson"), str_to_sentence(index), index)) %>%
  filter(significance != "proportion_failed model",
         !is.na(term)) %>% 
  mutate(significance = str_to_sentence(str_remove(significance, "proportion_"))) %>% 
  ggplot() + 
  geom_point(
    aes(x = num_cores, y = proportion, colour = significance), size = 3) + 
  geom_line(
    aes(x = num_cores, y = proportion, colour = significance)) + 
  # Add dashed line at 0.8 (80%) as reference for "target" power 
  geom_hline(yintercept = 0.8, linetype = "dotted") + 
  facet_grid(term ~ index) + 
  scale_colour_manual(values = c("#DC3220", "#005AB5")) + 
  scale_x_continuous(breaks = c(3, 5, 10, 15, 20)) +
  theme(legend.position = "bottom",
        axis.text.y = element_text(size = 12), 
        strip.text = element_text(size = 12)) +
  labs(x = "Number of cores", y = "Proportion", colour = "Significance")


# Save plots 
# For manuscript: 
tiff("figures/significance_figure.tiff", width = 9, height = 12, units = "in", res = 300)
significance_figure
dev.off()

# For conference presentations: 
tiff("figures/significance_figure_for_PPT.tiff", width = 12, height = 7, units = "in", res = 300)
significance_figure_wide
dev.off()
