#' Function to create publication-ready plots from output of effects package
#'
#' @param indices_df Data frame containing raw data used to fit .model
#' @param .model Fitted model object
#' @param diversity_index_name Character string denoting column name of interest in indices_df
#' @param .y_label Character string that describes the diversity index being plotted
#' @param is_beta Boolean flag that indicates whether or not model is beta regression. Default = FALSE.
#'
#' @return An effects plot 
#' @export 
#'
#' @examples 


pub_effects_plot <- function(.model, indices_df, diversity_index_name, .y_label, is_beta = FALSE){
  
  # Get the model effects
  model_effects <- effect(term = "site", mod = .model)  
  
  if (is_beta) {
    # Create a data frame with information needed to create the effects plot AND transform beta regression from link-scale to response scale
    effects_df <- data.frame(
      site = model_effects$x,
      diversity_index = 1 / (1 + exp(-model_effects$fit)),
      conf_low = 1 / (1 + exp(-model_effects$lower)),
      conf_high = 1 / (1 + exp(-model_effects$upper))
    )
    
  } else {
    # Create a data frame with information needed to create the effects plot
    effects_df <- data.frame(
      site = model_effects$x,
      diversity_index = model_effects$fit,
      conf_low = model_effects$lower,
      conf_high = model_effects$upper
    )
  }
  
  # Plot it
  effects_plot <- effects_df %>% 
    ggplot() +
    # Plot mean index with error bars representing 95% CI
    geom_point(aes(x = site, y = diversity_index), size = 2.2) + 
    geom_errorbar(aes(x = site, y = diversity_index, ymin = conf_low, ymax = conf_high), width = 0.1, size = 0.6) +
    # Plot data points (index) for each core
    geom_jitter(data = indices_df, aes(x = site, y = .data[[diversity_index_name]]), alpha = 0.2, width = 0.1) +
    theme_MEC() +
    labs(x = "", y = .y_label) 
  
  return(effects_plot)
  
}
